@@ -1,5 +1,5 @@
 #/*##########################################################################
-# Copyright (C) 2004-2010 European Synchrotron Radiation Facility
+# Copyright (C) 2004-2012 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMCA X-ray Fluorescence Toolkit developed at
 # the ESRF by the Beamline Instrumentation Software Support (BLISS) group.
@@ -346,12 +346,14 @@ class ColormapDialog(qt.QDialog):
                                  self.__y[i])
 
         self.c.replot()
-        if DEBUG:print "Slider asking to update colormap"
+        if DEBUG:
+            print("Slider asking to update colormap")
         #self._update()
         self.sendColormap()
 
     def _update(self):
-        if DEBUG: print "colormap _update called"
+        if DEBUG:
+            print("colormap _update called")
         self.marge = (abs(self.dataMax) + abs(self.dataMin)) / 6.0
         self.minmd = self.dataMin - self.marge
         self.maxpd = self.dataMax + self.marge
@@ -370,16 +372,30 @@ class ColormapDialog(qt.QDialog):
         self.sendColormap()
 
     def buttonGroupChange(self, val):
-        self.colormapType = val
-        if DEBUG: print "buttonGroup asking to update colormap"
+        if DEBUG:
+            print("buttonGroup asking to update colormap")
+        self.setColormapType(val, update=True)
         self._update()
 
+    def setColormapType(self, val, update=False):
+        self.colormapType = val
+        if QTVERSION > '4.0.0':
+            if self.colormapType == 1:
+                self.buttonGroup.button(1).setChecked(True)
+            elif self.colormapType == 2:
+                self.buttonGroup.button(2).setChecked(True)
+            else:
+                self.colormapType = 0
+                self.buttonGroup.button(0).setChecked(True)
+        if update:
+            self._update()
+
     def chval(self, ddict):
         if ddict['event'] == 'markerMoving':
             if ddict['marker'] in self.markers:
                 markerIndex = self.markers.index(ddict['marker'])
             else:
-                print "Unknown marker"
+                print("Unknown marker")
                 return
         else:
             return
@@ -395,7 +411,7 @@ class ColormapDialog(qt.QDialog):
             if ddict['marker'] in self.markers:
                 markerIndex = self.markers.index(ddict['marker'])
             else:
-                print "Unknown marker"
+                print("Unknown marker")
                 return
         else:
             return
@@ -432,7 +448,7 @@ class ColormapDialog(qt.QDialog):
 
     def setAutoscale(self, val):
         if DEBUG:
-            print "setAutoscale called", val
+            print("setAutoscale called", val)
         if val:
             if QTVERSION < '4.0.0':
                 self.autoScaleButton.setOn(True)
@@ -534,9 +550,11 @@ class ColormapDialog(qt.QDialog):
     change only the displayed min value
     """
     def setDisplayedMinValue(self, val):
+        val = float(val)
         self.minValue = val
         self.minText.setText("%g"%val)
         self.__x[1] = val
+        self.c.setMarkerXPos(self.c.markersdict[self.markers[1]]['marker'], val)
         self.c.newCurve("ConstrainedCurve", self.__x, self.__y)
 
     # MAXIMUM
@@ -567,6 +585,7 @@ class ColormapDialog(qt.QDialog):
     change only the displayed max value
     """
     def setDisplayedMaxValue(self, val):
+        val = float(val)
         self.maxValue = val
         self.maxText.setText("%g"%val)
         self.__x[2] = val
@@ -592,23 +611,26 @@ class ColormapDialog(qt.QDialog):
     send 'ColormapChanged' signal
     """
     def sendColormap(self):
-        if DEBUG:print "sending colormap"
+        if DEBUG:
+            print("sending colormap")
         #prevent unexpected behaviour because of bad limits
         if self.minValue > self.maxValue:
             vmax = self.minValue
+            vmin = self.maxValue
         else:
             vmax = self.maxValue
+            vmin = self.minValue
         try:
             if QTVERSION < '4.0.0':
                 self.emit(qt.PYSIGNAL("ColormapChanged"),
                         (self.colormapIndex, self.autoscale,
-                         self.minValue, vmax,
+                         vmin, vmax,
                          self.dataMin, self.dataMax,
                          self.colormapType))
             else:
                 self.emit(qt.SIGNAL("ColormapChanged"),
                         self.colormapIndex, self.autoscale,
-                        self.minValue, vmax,
+                        vmin, vmax,
                         self.dataMin, self.dataMax,
                         self.colormapType)
             
