@@ -1,5 +1,5 @@
 #/*##########################################################################
-# Copyright (C) 2004-2007 European Synchrotron Radiation Facility
+# Copyright (C) 2004-2010 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMCA X-ray Fluorescence Toolkit developed at
 # the ESRF by the Beamline Instrumentation Software Support (BLISS) group.
@@ -39,7 +39,7 @@ class ConcentrationsConversion:
 
         result = concentrations
         #the header
-        if result.has_key('mmolar'):
+        if 'mmolar' in result:
             mmolarflaglist = [False, True]
         else:
             mmolarflaglist = [False]
@@ -59,7 +59,7 @@ class ConcentrationsConversion:
                 labels = ['Element','Group','Fit Area','Sigma Area', 'Mass fraction']
             
             #the table
-            if result.has_key('layerlist'):
+            if 'layerlist' in result:
                 if type(result['layerlist']) != type([]):
                     result['layerlist'] = [result['layerlist']]
                 for label in result['layerlist']:
@@ -94,7 +94,7 @@ class ConcentrationsConversion:
                     fields = [element,group0,fitarea,sigmaarea,area,fraction]
                 else:
                     fields = [element,group0,fitarea,sigmaarea,fraction]
-                if result.has_key('layerlist'):
+                if 'layerlist' in result:
                     for layer in result['layerlist']:
                         if result[layer]['mass fraction'][group] < 0.0:
                             fraction   = "Unknown"
@@ -129,7 +129,7 @@ class ConcentrationsConversion:
         if concentrations is None:return text
         result =concentrations       
         #the table
-        if result.has_key('mmolar'):
+        if 'mmolar' in result:
             mmolarflaglist = [False, True]
         else:
             mmolarflaglist = [False]
@@ -138,7 +138,7 @@ class ConcentrationsConversion:
                 labels = ['Element','Group','Fit_Area','Sigma_Area', 'mM_Concentration']
             else:
                 labels = ['Element','Group','Fit_Area','Sigma_Area', 'Mass_fraction']
-            if result.has_key('layerlist'):
+            if 'layerlist' in result:
                 if type(result['layerlist']) != type([]):
                     result['layerlist'] = [result['layerlist']]
                 for label in result['layerlist']:
@@ -160,7 +160,7 @@ class ConcentrationsConversion:
                     fields = [element,group0,fitarea,sigmaarea,area,fraction]
                 else:
                     fields = [element,group0,fitarea,sigmaarea,fraction]
-                if result.has_key('layerlist'):
+                if 'layerlist' in result:
                     for layer in result['layerlist']:
                         if result[layer]['mass fraction'][group] < 0.0:
                             fraction   = "Unknown"
@@ -208,7 +208,7 @@ class ConcentrationsTool:
         else: self.fitresult = fitresult
         if config is None: config = self.config
         else:self.config=config
-        if not self.config.has_key('usemultilayersecondary'):
+        if not ('usemultilayersecondary' in self.config):
             self.config['usemultilayersecondary']= 0
         secondary = self.config['usemultilayersecondary']
         #get attenuators and matrix from fit
@@ -240,7 +240,7 @@ class ConcentrationsTool:
                     attenuators.append(fitresult['result']['config']['attenuators']\
                                                                 [attenuator][1:])
         if matrix is None:
-            raise ValueError, "Invalid or undefined sample matrix"
+            raise ValueError("Invalid or undefined sample matrix")
         
         if matrix[0].upper() == "MULTILAYER":
             layerlist = fitresult['result']['config']['multilayer'].keys()
@@ -250,17 +250,17 @@ class ConcentrationsTool:
                     if multilayer is None:multilayer=[]
                     multilayer.append(fitresult['result']['config']['multilayer'][layer][1:])
                     if not Elements.isValidMaterial(multilayer[-1][0]):
-                        raise ValueError,"Material %s is not defined" % multilayer[-1][0]    
+                        raise ValueError("Material %s is not defined" % multilayer[-1][0])
         
         else:
             layerlist = ["Layer0"]
             multilayer= [matrix]
             if not Elements.isValidMaterial(matrix[0]):
-                raise ValueError,"Material %s is not defined" % matrix[0]
+                raise ValueError("Material %s is not defined" % matrix[0])
         energyList = fitresult['result']['config']['fit']['energy']
         if energyList is None:
-            raise ValueError, "Invalid energy"
-        if type(energyList) != types.ListType:
+            raise ValueError("Invalid energy")
+        if type(energyList) != type([]):
             energyList    = [energyList]
             flagList   = [1]
             weightList = [1.0]
@@ -275,31 +275,32 @@ class ConcentrationsTool:
             if flagList[idx]:
                 energy = energyList[idx]
                 if energy is None:
-                    raise ValueError,\
-                          "Energy %d isn't a valid energy" % idx
+                    raise ValueError(\
+                          "Energy %d isn't a valid energy" % idx)
                 if energy <= 0.001:
-                    raise ValueError,\
-                          "Energy %d with value %f isn't a valid energy" % (idx,
-                                                                        energy)
+                    raise ValueError(\
+                          "Energy %d with value %f isn't a valid energy" %\
+                          (idx, energy))
                 if weightList[idx] is None:
-                    raise ValueError,\
-                          "Weight %d isn't a valid weight" % idx
+                    raise ValueError(\
+                          "Weight %d isn't a valid weight" % idx)
                 if weightList [idx] < 0.0:
-                    raise ValueError,\
-                          "Weight %d with value %f isn't a valid weight" % (idx,
-                                                                weightList[idx])
+                    raise ValueError(\
+                          "Weight %d with value %f isn't a valid weight" %\
+                          (idx, weightList[idx]))
                 finalEnergy.append(energy)
                 finalWeight.append(weightList[idx])
                 finalFlag.append(1)
         totalWeight = sum(weightList)
-        if totalWeight == 0.0:raise ValueError,"Sum of energy weights is 0.0"
+        if totalWeight == 0.0:
+            raise ValueError("Sum of energy weights is 0.0")
         weightList = [x/totalWeight for x in finalWeight]
         energyList = finalEnergy
         flagList   = finalFlag
 
         #get elements list from fit, not from matrix
         groupsList = fitresult['result']['groups'] * 1
-        if type(groupsList) != types.ListType:
+        if type(groupsList) != type([]):
             groupsList = [groupsList]
         
         todelete = []
@@ -337,7 +338,8 @@ class ConcentrationsTool:
                 pseudomatrix = multilayer[ilayer]
                 eleDict = Elements.getMaterialMassFractions([pseudomatrix[0]], [1.0])
                 if eleDict == {}:
-                    raise ValueError, "Invalid layer material %s" % pseudomatrix[0]
+                    raise ValueError(\
+                        "Invalid layer material %s" % pseudomatrix[0])
                 keys = eleDict.keys()
                 for ele in keys:
                     for group in newelements:
@@ -404,12 +406,13 @@ class ConcentrationsTool:
                     for ele in elements:
                         if key == ele:
                             present.append(key)
-                            if not referenceLayerDict.has_key(ele):referenceLayerDict[ele] = []
+                            if not (ele in referenceLayerDict):
+                                referenceLayerDict[ele] = []
                             referenceLayerDict[ele].append(ilayer)                                
             if len(present) == 0:
                 text  = "Matrix must contain at least one fitted element\n"
                 text += "in order to estimate flux and efficiency from it."
-                raise ValueError,text
+                raise ValueError(text)
             referenceElement = config['reference'].replace(' ',"")
             if len(referenceElement) and (referenceElement.upper() != 'AUTO'):
                 if Elements.isValidFormula(referenceElement):
@@ -420,14 +423,14 @@ class ConcentrationsTool:
                         referenceElement = referenceElement.upper()[0]
                     if not (referenceElement in elements):
                         text = "Element %s not among fitted elements" % referenceElement
-                        raise ValueError,text
+                        raise ValueError(text)
                     elif not (referenceElement in present):
                         text = "Element %s not among matrix elements" % referenceElement
-                        raise ValueError,text
+                        raise ValueError(text)
                     referenceLayers  = referenceLayerDict[referenceElement]
                 else:
                     text = "Element %s not a valid element" % referenceElement
-                    raise ValueError,text
+                    raise ValueError(text)
             elif len(present) == 1:
                 referenceElement = present[0]
                 referenceLayers  = referenceLayerDict[referenceElement]
@@ -460,7 +463,8 @@ class ConcentrationsTool:
                     theoretical  += materialComposition[ilayer][referenceElement] * \
                                     fluolist[ilayer][referenceElement]['rates'][transitions]
             if theoretical <= 0.0:
-                raise ValueError,"Theoretical rate is almost 0.0 Impossible to determine flux"
+                raise ValueError(\
+                    "Theoretical rate is almost 0.0 Impossible to determine flux")
             else:
                 flux = fitresult['result'][group]['fitarea'] / theoretical
         else:
@@ -485,7 +489,7 @@ class ConcentrationsTool:
         dict['groups'] = groupsList
         dict['elements'] = elements
         dict['mass fraction'] = {}
-        if config.has_key('mmolarflag'):
+        if 'mmolarflag' in config:
             if config['mmolarflag']:
                 dict['mmolar'] = {}
         else:
@@ -500,7 +504,7 @@ class ConcentrationsTool:
             element = item[0]
             transitions = item[1] + " xrays"
             if element in fluo.keys():
-                if fluo[element].has_key(transitions):
+                if transitions in fluo[element]:
                     #this SHOULD be with concentration one
                     theoretical = fluo[element]['rates'][transitions] * 1.0
                     expected = theoretical * flux * solidangle
@@ -552,7 +556,7 @@ class ConcentrationsTool:
                         element = item[0]
                         transitions = item[1] + " xrays"
                         if element in fluo.keys():
-                            if fluo[element].has_key(transitions):
+                            if transitions in fluo[element]:
                                 theoretical = fluo[element]['rates'][transitions] * 1
                                 expected = theoretical * flux * solidangle
                                 if expected > 0.0:
@@ -648,8 +652,8 @@ if __name__ == "__main__":
             d.read(file)
             for material in d['result']['config']['materials'].keys():
                 Elements.Material[material] = copy.deepcopy(d['result']['config']['materials'][material])
-            print tool.processFitResult(fitresult=d, elementsfrommatrix=True)
+            print(tool.processFitResult(fitresult=d, elementsfrommatrix=True))
     else:
-        print "Usage:"
-        print "ConcentrationsTool [--flux=xxxx --area=xxxx] fitresultfile"    
-    
+        print("Usage:")
+        print("ConcentrationsTool [--flux=xxxx --area=xxxx] fitresultfile")
+
