@@ -1,5 +1,5 @@
 #/*##########################################################################
-# Copyright (C) 2004-2006 European Synchrotron Radiation Facility
+# Copyright (C) 2004-2010 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMCA X-ray Fluorescence Toolkit developed at
 # the ESRF by the Beamline Instrumentation Software Support (BLISS) group.
@@ -35,7 +35,6 @@ __revision__ = "$Revision: 1.8 $"
 ################################################################################  
 #import fast_EdfFile as EdfFile
 import EdfFile
-import string
 ################################################################################
 
 SOURCE_TYPE = "EdfFile"
@@ -59,9 +58,9 @@ class EdfFileLayer:
         self.GetData   = self.LoadSource
 
     def GetPageInfo(self,index={}):
-        if index.has_key('SourceName'):
+        if 'SourceName' in index:
             self.SetSource(index['SourceName'])
-            if index.has_key('Key'):
+            if 'Key' in index:
                 info=self.GetData(index['Key'])   
                 return info[0]
 
@@ -84,19 +83,19 @@ class EdfFileLayer:
             else:
                 if (type(source_name) == type([])):
                     if DEBUG:
-                        print "List of files"
+                        print("List of files")
                     self.Source=[]
                     for name in source_name:
                         try:
                             self.Source.append(EdfFile.EdfFile(name,fastedf=self.fastedf))
                         except:
-                            #print "EdfFileLayer.SetSource: Error trying to read EDF file %s" % name
+                            #print("EdfFileLayer.SetSource: Error trying to read EDF file %s" % name)
                             self.Source.append( None)                
                 else:
                     try:
                         self.Source = EdfFile.EdfFile(source_name, fastedf=self.fastedf)
                     except:
-                        #print "EdfFileLayer.SetSource: Error trying to read EDF file" 
+                        #print("EdfFileLayer.SetSource: Error trying to read EDF file")
                         self.Source=None
         else:
             self.Source=None
@@ -197,7 +196,7 @@ class EdfFileLayer:
                     index = int(index)-1
                     image = int(image)-1                    
                 except:
-                    print "Error trying to interpret key =",key
+                    print("Error trying to interpret key = %s" % key)
                     return {}
                 source = self.Source[index]
                 NumImages=source.GetNumImages()
@@ -250,7 +249,7 @@ class EdfFileLayer:
             f = 1
             sumrequested = 0
             if type(key0) == type({}):
-                if key0.has_key('Key'):
+                if 'Key' in key0:
                     key = key0['Key']              
             if type(key0) == type(''):
                 if len(key0.split(".")) == 2:
@@ -272,7 +271,8 @@ class EdfFileLayer:
                         key = "%d.%d" % (f,i)
             else:
                 i = key0
-                if i >= numimages: raise "EdfFileData: index out of bounds"
+                if i >= numimages:
+                    raise IndexError("EdfFileData: index out of bounds")
                 imgcount   =0
                 f=0
                 for source in self.Source:
@@ -298,17 +298,17 @@ class EdfFileLayer:
                 if info["DataType"]=="UnsignedShort":array=self.Source[f-1].GetData(i-1,"SignedLong",Pos=edf_pos,Size=edf_size)
                 elif info["DataType"]=="UnsignedLong":array=self.Source[f-1].GetData(i-1,"DoubleValue",Pos=edf_pos,Size=edf_size)
                 else: array=self.Source[f-1].GetData(i-1,Pos=edf_pos,Size=edf_size)
-                if info.has_key('Channel0'):
+                if 'Channel0' in info:
                     info['Channel0'] = int(float(info['Channel0']))
-                elif info.has_key('MCA start ch'):
+                elif 'MCA start ch' in info:
                     info['Channel0'] = int(float(info['MCA start ch']))
                 else:
                     info['Channel0'] = 0
-                if not info.has_key('McaCalib'):
-                    if info.has_key('MCA a') and info.has_key('MCA b') and info.has_key('MCA c'):
-                        info['McaCalib'] = [string.atof(info['MCA a']),
-                                            string.atof(info['MCA b']),
-                                            string.atof(info['MCA c'])]
+                if not ('McaCalib' in info):
+                    if 'MCA a' in info and 'MCA b' in info and 'MCA c' in info:
+                        info['McaCalib'] = [float(info['MCA a']),
+                                            float(info['MCA b']),
+                                            float(info['MCA c'])]
             else:
                 # this is not correct, I assume info
                 # is the same for all sources
@@ -316,17 +316,17 @@ class EdfFileLayer:
                 i=1
                 info.update(self.Source[f-1].GetStaticHeader(i-1))
                 info.update(self.Source[f-1].GetHeader(i-1))
-                if info.has_key('Channel0'):
+                if 'Channel0' in info:
                     info['Channel0'] = int(float(info['Channel0']))
-                elif info.has_key('MCA start ch'):
+                elif 'MCA start ch' in info:
                     info['Channel0'] = int(float(info['MCA start ch']))
                 else:
                     info['Channel0'] = 0
-                if not info.has_key('McaCalib'):
-                    if info.has_key('MCA a') and info.has_key('MCA b') and info.has_key('MCA c'):
-                        info['McaCalib'] = [string.atof(info['MCA a']),
-                                            string.atof(info['MCA b']),
-                                            string.atof(info['MCA c'])]
+                if not ('McaCalib' in info):
+                    if 'MCA a' in info and 'MCA b' in info and 'MCA c' in info:
+                        info['McaCalib'] = [float(info['MCA a']),
+                                            float(info['MCA b']),
+                                            float(info['MCA c'])]
                 f=0
                 for source in self.Source:
                     for i in range(source.GetNumImages()):
@@ -340,14 +340,14 @@ class EdfFileLayer:
                         else:
                             array += array0 
                     f+=1
-            if info.has_key('McaCalib'):
+            if 'McaCalib' in info:
                 if type(info['McaCalib']) == type(" "):
                     info['McaCalib'] = info['McaCalib'].replace("[","")
                     info['McaCalib'] = info['McaCalib'].replace("]","")
                     cala, calb, calc = info['McaCalib'].split(",")
-                    info['McaCalib'] = [string.atof(cala),
-                                        string.atof(calb),
-                                        string.atof(calc)]
+                    info['McaCalib'] = [float(cala),
+                                        float(calb),
+                                        float(calc)]
                 
             output.append([info,array])
             #AS self.AppendPage(info,array)
@@ -393,13 +393,14 @@ class EdfFileLayer:
         output = []
         for key in key_list:
             if type(key) == type({}):
-                if key.has_key('Key'):
+                if 'Key' in key:
                     key = key['Key']              
             if type(key) == type(''):
                 i=int(key)
             else:
                 i = key
-            if i >= numimages: raise "EdfFileData: index out of bounds"
+            if i >= numimages:
+                raise IndexError("EdfFileData: index out of bounds")
             info={}
             info["SourceType"]=SOURCE_TYPE
             info["SourceName"]=self.SourceName
@@ -412,15 +413,15 @@ class EdfFileLayer:
             if info["DataType"]=="UnsignedShort":array=self.Source.GetData(i,"SignedLong",Pos=edf_pos,Size=edf_size)
             elif info["DataType"]=="UnsignedLong":array=self.Source.GetData(i,"DoubleValue",Pos=edf_pos,Size=edf_size)
             else: array=self.Source.GetData(i,Pos=edf_pos,Size=edf_size)
-            if info.has_key('MCA start ch'):
+            if 'MCA start ch' in info:
                 info['Channel0'] = int(info['MCA start ch'])
             else:
                 info['Channel0'] = 0
-            if not info.has_key('McaCalib'):
-                if info.has_key('MCA a') and info.has_key('MCA b') and info.has_key('MCA c'):
-                    info['McaCalib'] = [string.atof(info['MCA a']),
-                                        string.atof(info['MCA b']),
-                                        string.atof(info['MCA c'])]                    
+            if not ('McaCalib' in info):
+                if 'MCA a' in info and 'MCA b' in info and 'MCA c' in info:
+                    info['McaCalib'] = [float(info['MCA a']),
+                                        float(info['MCA b']),
+                                        float(info['MCA c'])]                    
             output.append([info,array])
             #AS self.AppendPage(info,array)
         if len(output) == 1:
@@ -440,29 +441,26 @@ if __name__ == "__main__":
         fast = int(sys.argv[3])
         obj=EdfFileLayer(fastedf=fast)
         if not obj.SetSource([filename]):
-            print "ERROR: cannot open file", filename
+            print("ERROR: cannot open file %s" % filename)
             sys.exit()
         #obj.LoadSource(key)
     except:
-        print "Usage: EdfFileData.py <filename> <image> <fastflag>"
+        print("Usage: EdfFileData.py <filename> <image> <fastflag>")
         sys.exit()
-    print obj.GetSourceInfo()    
+    print(obj.GetSourceInfo())
     for i in range(1):
         #this works obj.LoadSource("%d" % i)
         import time
-        print "Full"
+        print("Full")
         e=time.time()
         info,data = obj.LoadSource(key)
-        print "elapsed = ",time.time()-e
-        print "selection"
+        print("elapsed = ",time.time()-e)
+        print("selection")
         e=time.time()
         info,data = obj.LoadSource(key,pos=(0,0),size=(90,0))
-        print "elapsed = ",time.time()-e
-        print info
+        print("elapsed = ",time.time()-e)
+        print(info)
         #print obj.GetPageInfo("%d" % i)
         #print obj.GetPageInfo(i)
         #print obj.GetPageInfo({'Key':i})        
         #print obj.GetPageArray(i)
-    
-
-        
