@@ -1,5 +1,5 @@
 #/*##########################################################################
-# Copyright (C) 2004-2010 European Synchrotron Radiation Facility
+# Copyright (C) 2004-2011 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMCA X-ray Fluorescence Toolkit developed at
 # the ESRF by the Beamline Instrumentation Software Support (BLISS) group.
@@ -26,6 +26,10 @@
 #############################################################################*/
 __author__ = "V.A. Sole - ESRF BLISS Group"
 import PyMcaQt as qt
+if hasattr(qt, "QString"):
+    QString = qt.QString
+else:
+    QString = str
 from PyMca_Icons import IconDict
 import MaskImageWidget
 import sys
@@ -52,10 +56,13 @@ class ExternalImagesWindow(MaskImageWidget.MaskImageWidget):
         ddict['usetab'] = False
         ddict.update(kw)
         ddict['standalonesave'] = False
-        if kw.has_key('dynamic'):
+        if 'dynamic' in kw:
             del ddict['dynamic']
-        if kw.has_key('crop'):
+        if 'crop' in kw:
             del ddict['crop']
+        if 'depthselection' in kw:
+            del ddict['depthselection']
+        self._depthSelection = kw.get('depthselection', False)
         MaskImageWidget.MaskImageWidget.__init__(self, *var, **ddict) 
         self.slider = qt.QSlider(self)
         self.slider.setOrientation(qt.Qt.Horizontal)
@@ -77,13 +84,13 @@ class ExternalImagesWindow(MaskImageWidget.MaskImageWidget):
                          qt.SIGNAL("clicked()"), 
                          self._saveToolButtonSignal)
             self._saveMenu = qt.QMenu()
-            self._saveMenu.addAction(qt.QString("Image Data"),
+            self._saveMenu.addAction(QString("Image Data"),
                                      self.saveImageList)
-            self._saveMenu.addAction(qt.QString("Standard Graphics"),
+            self._saveMenu.addAction(QString("Standard Graphics"),
                                      self.graphWidget._saveIconSignal)
             if QTVERSION > '4.0.0':
                 if MATPLOTLIB:
-                    self._saveMenu.addAction(qt.QString("Matplotlib") ,
+                    self._saveMenu.addAction(QString("Matplotlib") ,
                                      self._saveMatplotlibImage)
 
         dynamic = kw.get("dynamic", False)
@@ -94,7 +101,7 @@ class ExternalImagesWindow(MaskImageWidget.MaskImageWidget):
             self.cropIcon = qt.QIcon(qt.QPixmap(IconDict["crop"]))
             infotext = "Crop image to the currently zoomed window"
             cropPosition = 6
-            #if kw.has_key('imageicons'):
+            #if 'imageicons' in kw:
             #    if not kw['imageicons']:
             #        cropPosition = 6
             self.cropButton = self.graphWidget._addToolButton(\
@@ -107,12 +114,17 @@ class ExternalImagesWindow(MaskImageWidget.MaskImageWidget):
             infotext = "Flip image and data, not the scale."
             self.graphWidget.hFlipToolButton.setToolTip('Flip image')
             self._flipMenu = qt.QMenu()
-            self._flipMenu.addAction(qt.QString("Flip Image and Vertical Scale"),
+            self._flipMenu.addAction(QString("Flip Image and Vertical Scale"),
                                      self.__hFlipIconSignal)
-            self._flipMenu.addAction(qt.QString("Flip Image Left-Right"),
+            self._flipMenu.addAction(QString("Flip Image Left-Right"),
                                      self._flipLeftRight)
-            self._flipMenu.addAction(qt.QString("Flip Image Up-Down"),
-                                     self._flipUpDown)        
+            self._flipMenu.addAction(QString("Flip Image Up-Down"),
+                                     self._flipUpDown)
+        else:
+            self.connect(self.graphWidget.hFlipToolButton,
+                 qt.SIGNAL("clicked()"),
+                 self.__hFlipIconSignal)
+
 
     def sizeHint(self):
         return qt.QSize(400, 400)
@@ -367,6 +379,39 @@ class ExternalImagesWindow(MaskImageWidget.MaskImageWidget):
         else:
             self.showImage(0)
 
+    def _updateProfileCurve(self, ddict):
+        if not self._depthSelection:
+            return MaskImageWidget.MaskImageWidget._updateProfileCurve(self,
+                                                                       ddict)
+        nImages = len(self.imageNames)
+        for i in range(nImages):
+            image=self.imageList[i]
+            overlay = False
+            if i == 0:
+                overlay = MaskImageWidget.OVERLAY_DRAW
+                replace = True
+                if len(self.imageNames) == 1:
+                    replot = True
+                else:
+                    replot = False
+            elif i == (nImages -1):
+                replot = True
+                replace=False
+            else:
+                replot = False
+                replace= False
+            curve = self._getProfileCurve(ddict, image=image, overlay=overlay)
+            if curve is None:
+                return
+            xdata, ydata, legend, info = curve
+            newLegend = self.imageNames[i]+ " " + legend 
+            self._profileSelectionWindow.addCurve(xdata, ydata,
+                                                  legend=newLegend,
+                                                  info=info,
+                                                  replot=replot,
+                                                  replace=replace)
+
+
 def test2():
     app = qt.QApplication([])
     qt.QObject.connect(app,
@@ -380,7 +425,7 @@ def test2():
     ret = dialog.exec_()
     if ret:
         dialog.close()
-        print dialog.getParameters()
+        print(dialog.getParameters())
     #app.exec_()
 
 def test():
@@ -390,7 +435,7 @@ def test():
                        app,
                        qt.SLOT('quit()'))
     if len(sys.argv) > 1:
-        if sys.argv[1][-3:].upper() == 'EDF':
+        if sys.argv[1][-3:].upper() in ['EDF', 'CCD']:
             container = ExternalImagesWindow(selection=False,
                                              colormap=True,
                                              imageicons=False,
@@ -410,7 +455,7 @@ def test():
         container.setImageData(data)
     container.show()
     def theSlot(ddict):
-        print ddict['event']
+        print(ddict['event'])
 
     if QTVERSION < '4.0.0':
         qt.QObject.connect(container,
