@@ -1,5 +1,5 @@
 #/*##########################################################################
-# Copyright (C) 2004-2007 European Synchrotron Radiation Facility
+# Copyright (C) 2004-2011 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMCA X-ray Fluorescence Toolkit developed at
 # the ESRF by the Beamline Instrumentation Software Support (BLISS) group.
@@ -41,9 +41,11 @@ CIGNORED    = 7
 
 ONED = 0
 
-def LeastSquaresFit(model, parameters0, data=None, maxiter = 100,constrains=[],
+def LeastSquaresFit(model, parameters0, data=None, maxiter = 100,constrains=None,
                         weightflag = 0,model_deriv=None,deltachi=None,fulloutput=0,
                         xdata=None,ydata=None,sigmadata=None,linear=None):
+    if constrains is None:
+        constrains = []
     parameters = array(parameters0).astype(Float)
     if linear is None:linear=0
     if deltachi is None:
@@ -55,7 +57,7 @@ def LeastSquaresFit(model, parameters0, data=None, maxiter = 100,constrains=[],
     #SimplePlot.plot([data[:,0],data[:,1]],yname='Received data')
     else:
         if xdata is None:
-            x=array(map(lambda y:y[0],data))
+            x=array([y[0] for y in data])
         else:
             x=xdata
     if linear:
@@ -85,17 +87,17 @@ def LeastSquaresFit(model, parameters0, data=None, maxiter = 100,constrains=[],
                                     ydata=ydata,
                                     sigmadata=sigmadata)
         except TypeError:
-            print "You should reconsider how to write your function"
-            raise TypeError
+            print("You should reconsider how to write your function")
+            raise TypeError("You should reconsider how to write your function")
     else:
-            return RestreinedLeastSquaresFit(model,parameters0,
-                                    data,maxiter,
-                                    constrains,weightflag,model_deriv=model_deriv,
-                                    deltachi=deltachi,
-                                    fulloutput=fulloutput,
-                                    xdata=xdata,
-                                    ydata=ydata,
-                                    sigmadata=sigmadata)
+        return RestreinedLeastSquaresFit(model,parameters0,
+                                data,maxiter,
+                                constrains,weightflag,model_deriv=model_deriv,
+                                deltachi=deltachi,
+                                fulloutput=fulloutput,
+                                xdata=xdata,
+                                ydata=ydata,
+                                sigmadata=sigmadata)
 
 def LinearLeastSquaresFit(model0,parameters0,data0,maxiter,
                                 constrains0,weightflag,model_deriv=None,deltachi=0.01,fulloutput=0,
@@ -144,15 +146,15 @@ def LinearLeastSquaresFit(model0,parameters0,data0,maxiter,
             else:
                #I should raise an exception
                 #constrains[0][i] = 0
-                raise ValueError,"Unknown constraint %s" % constrains[0][i]
+                raise ValueError("Unknown constraint %s" % constrains[0][i])
         if (constrains[0][i] == CQUOTED):
-            raise ValueError, "Linear fit cannot handle quoted constraint"
+            raise ValueError("Linear fit cannot handle quoted constraint")
     # make a local copy of the function for an easy speed up ...
     model = model0
     parameters = array(parameters0)
     if data0 is not None:
-        selfx = array(map(lambda x:x[0],data0))
-        selfy = array(map(lambda x:x[1],data0))
+        selfx = array([x[0] for x in data0])
+        selfy = array([x[1] for x in data0])
     else:
         selfx = xdata
         selfy = ydata
@@ -260,7 +262,7 @@ def RestreinedLeastSquaresFit(model0,parameters0,data0,maxiter,
             else:
                #I should raise an exception
                 #constrains[0][i] = 0
-                raise ValueError,"Unknown constraint %s" % constrains[0][i]
+                raise ValueError("Unknown constraint %s" % constrains[0][i])
     # make a local copy of the function for an easy speed up ...
     model = model0
     parameters = array(parameters0)
@@ -276,8 +278,8 @@ def RestreinedLeastSquaresFit(model0,parameters0,data0,maxiter,
         selfy = data [:,1]
     else:
         if data0 is not None:
-            selfx = array(map(lambda x:x[0],data0))
-            selfy = array(map(lambda x:x[1],data0))
+            selfx = array([x[0] for x in data0])
+            selfy = array([x[1] for x in data0])
         else:
             selfx = xdata
             selfy = ydata
@@ -301,7 +303,7 @@ def RestreinedLeastSquaresFit(model0,parameters0,data0,maxiter,
                     dummy = abs(data [:,2])
                 else:
                     if data0 is not None:
-                        dummy = abs(array(map(lambda x:x[2],data0)))
+                        dummy = abs(array([x[2] for x in data0]))
                     else:
                         dummy = abs(array(sigmadata))
                 selfweight = 1.0 / (dummy + equal(dummy,0))
@@ -371,9 +373,9 @@ def RestreinedLeastSquaresFit(model0,parameters0,data0,maxiter,
                                     B * sin(arcsin((fitparam[i] - A)/B)+ \
                                     deltapar [0] [i])
                     else:
-                        print "Error processing constrained fit"
-                        print "Parameter limits are",pmin,' and ',pmax
-                        print "A = ",A,"B = ",B
+                        print("Error processing constrained fit")
+                        print("Parameter limits are",pmin,' and ',pmax)
+                        print("A = ",A,"B = ",B)
                 newpar [free_index[i]] = pwork [0] [i]
             newpar=array(getparameters(newpar,constrains))
             workpar = take(newpar,noigno)
@@ -444,6 +446,11 @@ def ChisqAlphaBeta(model0, parameters, x,y,weight, constrains,model_deriv=None,l
                     derivfactor.append(B*cos(help0))
                 free_index.append(i)
                 n_free += 1
+            elif (pmax-pmin) > 0:
+                print("WARNING: Quoted parameter outside boundaries")
+                print("Initial value = %f" % parameters[i])
+                print("Limits are %f and %f" % (pmax, pmin))
+                print("Parameter will be kept at its starting value")
     fitparam = array(fitparam, Float)
     alpha = zeros((n_free, n_free),Float)
     beta = zeros((1,n_free),Float)
@@ -624,12 +631,20 @@ def test(npoints):
     data = concatenate((xx, yy, sy),1)
     parameters = [0.0,1.0,900.0, 25., 10]
     stime = time.time()
-    fittedpar, chisq, sigmapar = LeastSquaresFit(gauss,parameters,data)
+    if 0:
+        #old fashion
+        fittedpar, chisq, sigmapar = LeastSquaresFit(gauss,parameters,data)
+    else:
+        #easier to handle
+        fittedpar, chisq, sigmapar = LeastSquaresFit(gauss,parameters,
+                                                     xdata=xx.reshape((-1,)),
+                                                     ydata=yy.reshape((-1,)),
+                                                     sigmadata=sy.reshape((-1,)))
     etime = time.time()
-    print "Took ",etime - stime, "seconds"
-    print "chi square  = ",chisq
-    print "Fitted pars = ",fittedpar
-    print "Sigma pars  = ",sigmapar
+    print("Took ",etime - stime, "seconds")
+    print("chi square  = ",chisq)
+    print("Fitted pars = ",fittedpar)
+    print("Sigma pars  = ",sigmapar)
 
 
 if __name__ == "__main__":
