@@ -1,5 +1,5 @@
 #/*##########################################################################
-# Copyright (C) 2004-2010 European Synchrotron Radiation Facility
+# Copyright (C) 2004-2012 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMCA X-ray Fluorescence Toolkit developed at
 # the ESRF by the Beamline Instrumentation Software Support (BLISS) group.
@@ -25,8 +25,11 @@
 # is a problem for you.
 #############################################################################*/
 import posixpath
-import DataObject
 import h5py
+try:
+    from PyMca import DataObject
+except:
+    import DataObject
 try:
     from PyMca import NexusDataSource
 except:
@@ -43,7 +46,8 @@ class HDF5Stack1D(DataObject.DataObject):
         DataObject.DataObject.__init__(self)
 
         #the data type of the generated stack
-        self.__dtype = dtype
+        self.__dtype0 = dtype 
+        self.__dtype  = dtype
 
         if filelist is not None:
             if selection is not None:
@@ -91,8 +95,15 @@ class HDF5Stack1D(DataObject.DataObject):
                 mSelection = None
         else:
             mSelection = None
+
+        #deal with the pathological case where the scanlist corresponds to a selected top level dataset
+        if len(entryNames) == 0:
+            if scanlist is not None:
+                if len(scanlist) == 1:
+                    if scanlist[0] == ySelection:
+                        scanlist = None
             
-        if scanlist is None:
+        if scanlist in [None, []]:
             #if the scanlist is None, it is assumed we are interested on all
             #the scans containing the selection, not that all the scans
             #contain the selection.
@@ -140,21 +151,24 @@ class HDF5Stack1D(DataObject.DataObject):
                     scanlist.append("")
         else:
             try:
-                number, order = map(int, scanlist[0].split("."))
+                number, order = [int(x) for x in scanlist[0].split(".")]
                 JUST_KEYS = True
             except:
                 JUST_KEYS = False
             if not JUST_KEYS:
                 for scan in scanlist:
-                    if scan not in entryNames:
-                        raise ValueError, "Entry %s not in file"
-
+                    if scan.startswith("/"):
+                        t = scan[1:]
+                    else:
+                        t = scan
+                    if t not in entryNames:
+                        raise ValueError("Entry %s not in file" % scan)
         
         nFiles = len(filelist)
         nScans = len(scanlist)
         if JUST_KEYS:
             if not nScans:
-                raise IOError, "No entry contains the required data"
+                raise IOError("No entry contains the required data")
 
         #Now is to decide the number of mca ...
         #I assume all the scans contain the same number of mca
@@ -163,9 +177,9 @@ class HDF5Stack1D(DataObject.DataObject):
             if mSelection is not None:
                 mpath = "/" + entryNames[int(scanlist[0].split(".")[-1])-1] + mSelection
         else:
-            path = "/" + scanlist[0] + ySelection
+            path = scanlist[0] +  ySelection
             if mSelection is not None:
-                mpath = "/" + scanlist[0] + mSelection
+                mpath = scanlist[0] + mSelection
         yDataset = tmpHdf[path]
 
         if self.__dtype is None:
@@ -179,16 +193,39 @@ class HDF5Stack1D(DataObject.DataObject):
         dim0, dim1, mcaDim = self.getDimensions(nFiles, nScans, shape,
                                                 index=mcaIndex)
         try:
+            if self.__dtype in [numpy.float32, numpy.int32]:
+                bytefactor = 4
+            elif self.__dtype in [numpy.int16, numpy.uint16]:
+                bytefactor = 2
+            elif self.__dtype in [numpy.int8, numpy.uint8]:
+                bytefactor = 1
+            else:
+                bytefactor = 8
+
+            neededMegaBytes = nFiles * dim0 * dim1 * mcaDim * bytefactor/(1024*1024.)
+            if (neededMegaBytes > 2000) and (nFiles == 1) and (len(shape) == 3):
+                if self.__dtype0 is None:
+                    if (bytefactor == 8) and (neededMegaBytes <4000):
+                        #try reading as float32
+                        self.__dtype = numpy.float32
+                    else:
+                        raise MemoryError("Force dynamic loading")
+                else:
+                    raise MemoryError("Force dynamic loading")
             self.data = numpy.zeros((dim0, dim1, mcaDim), self.__dtype)
             DONE = False
         except (MemoryError, ValueError):
             #some versions report ValueError instead of MemoryError
             if (nFiles == 1) and (len(shape) == 3):
-                print "Attempting dynamic loading"
+                print("Attempting dynamic loading")
                 self.data = yDataset
                 if mSelection is not None:
                     mDataset = tmpHdf[mpath]
                     self.monitor = mDataset
+                if h5py.version.version < '2.0':
+                    #prevent automatic closing keeping a reference
+                    #to the open file
+                    self._fileReference = hdfStack
                 DONE = True
             else:
                 #what to do if the number of dimensions is only 2?
@@ -205,7 +242,7 @@ class HDF5Stack1D(DataObject.DataObject):
                 self.onBegin(dim0)
             self.incrProgressBar=0
             for hdf in hdfStack._sourceObjectList:
-                entryNames = hdf["/"].keys()
+                entryNames = list(hdf["/"].keys())
                 for scan in scanlist:
                     if JUST_KEYS:
                         entryName = entryNames[int(scan.split(".")[-1])-1]
@@ -253,12 +290,13 @@ class HDF5Stack1D(DataObject.DataObject):
                                 case = 1
                                 mDataset.shape = nMcaInYDataset, mcaDim
                             if case == -1:
-                                raise ValueError, "I do not know how to handle this monitor data"
+                                raise ValueError(\
+                                    "I do not know how to handle this monitor data")
                         if (len(yDataset.shape) == 3) and\
                            (dim1 == yDataset.shape[1]):
                             mca = 0
                             deltaI = int(yDataset.shape[1]/dim1)
-                            for ii in xrange(yDataset.shape[0]):
+                            for ii in range(yDataset.shape[0]):
                                 i = int(n/dim1)
                                 yData = yDataset[ii:(ii+1)]
                                 yData.shape = -1, mcaDim
@@ -301,14 +339,18 @@ class HDF5Stack1D(DataObject.DataObject):
                             nMonitorData = 1
                             for  v in mDataset.shape:
                                 nMonitorData *= v
-                            if nMonitorData == nMcaInYDataset:
+                            if nMonitorData == yDataset.shape[0]:
+                                case = 3
+                                mDataset.shape = yDataset.shape[0]
+                            elif nMonitorData == nMcaInYDataset:
                                 mDataset.shape = nMcaInYDataset
                                 case = 0
                             #elif nMonitorData == (yDataset.shape[1] * yDataset.shape[2]):
                             #    case = 1
                             #    mDataset.shape = yDataset.shape[1], yDataset.shape[2]
                             if case == -1:
-                                raise ValueError, "I do not know how to handle this monitor data"
+                                raise ValueError(\
+                                    "I do not know how to handle this monitor data")
                         if IN_MEMORY:
                             yDataset.shape = mcaDim, -1
                         if len(yDataset.shape) != 3:
@@ -328,21 +370,28 @@ class HDF5Stack1D(DataObject.DataObject):
                                         self.data[i, j, :] = yData/mDataset[mca]
                                     elif case == 1:
                                         self.data[i, j, :]  = yData/mDataset[:, mca]
+                                    elif case == 3:
+                                        self.data[i, j, :]  = yData/mDataset
                                 else:
                                     self.data[i, j, :] = yData
                                 n += 1
                         else:
-                            #dynamic stack of images to be read as MCA
-                            for nImage in xrange(yDataset.shape[0]):
+                            #stack of images to be read as MCA
+                            for nImage in range(yDataset.shape[0]):
                                 tmp = yDataset[nImage:(nImage+1)]
                                 if len(tmp.shape) == 3:
                                     i = int(n/dim1)
                                     j = n % dim1
-                                    for ii in xrange(tmp.shape[1]):
-                                        for jj in xrange(tmp.shape[2]):
-                                            self.data[i+ii, j+jj, nImage] = tmp[0, ii, jj]
+                                    if 0:
+                                        #this loop is extremely SLOW!!!(and useless)
+                                        for ii in range(tmp.shape[1]):
+                                            for jj in range(tmp.shape[2]):
+                                                self.data[i+ii, j+jj, nImage] = tmp[0, ii, jj]
+                                    else:
+                                        self.data[i:i+tmp.shape[1],
+                                                  j:j+tmp.shape[2], nImage] = tmp[0]
                             if mSelection is not None:
-                                for mca in range(nMcaInDataSet):
+                                for mca in range(yDataset.shape[0]):
                                     i = int(n/dim1)
                                     j = n % dim1
                                     yData = self.data[i, j, :]
@@ -388,11 +437,11 @@ class HDF5Stack1D(DataObject.DataObject):
         if index == -1:
             index = len(shape) - 1
         if DEBUG:
-            print "INDEX = ", index
+            print("INDEX = %d" % index)
         #figure out the shape of the stack
         if len(shape) == 0:
             #a scalar?
-            raise ValueError, "Selection corresponds to a scalar"
+            raise ValueError("Selection corresponds to a scalar")
         elif len(shape) == 1:
             #nchannels
             nMca = 1
@@ -410,7 +459,7 @@ class HDF5Stack1D(DataObject.DataObject):
             elif index == 0:
                 nMca = shape[1] * shape[2]
             else:
-                raise IndexError, "Only first and last dimensions handled"
+                raise IndexError("Only first and last dimensions handled")
         else:
             nMca = 1
             for i in range(len(shape)):
@@ -420,8 +469,8 @@ class HDF5Stack1D(DataObject.DataObject):
                 
         mcaDim = shape[index]
         if DEBUG:
-            print "nMca = ", nMca
-            print "mcaDim = ", mcaDim
+            print("nMca = %d" % nMca)
+            print("mcaDim = ", mcaDim)
 
         # HDF allows to work directly from the files without loading
         # them into memory.
@@ -483,7 +532,7 @@ class HDF5Stack1D(DataObject.DataObject):
             dim1 = nMca * nScans
         else:
             #I should not reach this point
-            raise ValueError, "Unhandled case"
+            raise ValueError("Unhandled case")
 
         return dim0, dim1, shape[index]
 
