@@ -2,25 +2,78 @@
 """
 from __future__ import with_statement
 import operator
+import sys
 import os
 import shutil
 import posixpath
 import gc
+from operator import itemgetter
 
 import PyQt4.QtCore as QtCore
 import PyQt4.QtGui as QtGui
 
-try:
-    import PyMca.phynx as phynx
-except:
-    #I should never reach here
-    try:
-        from xpaxs.io import phynx
-    except ImportError:
-        import phynx
+if hasattr(QtCore, 'QStringList'):
+    MyQVariant = QtCore.QVariant
+else:
+    def MyQVariant(x=None):
+        return x
 
+import h5py
+phynx = h5py
 import weakref
 
+DEBUG = 0
+
+#sorting method
+def h5py_sorting(object_list):
+    sorting_list = ['start_time', 'end_time', 'name']
+    n = len(object_list)
+    if n < 2:
+        return object_list
+
+    # This implementation only sorts entries
+    if posixpath.dirname(object_list[0].name) != "/":
+        return object_list
+
+    names = list(object_list[0].keys())
+
+    sorting_key = None
+    for key in sorting_list:
+        if key in names:
+            sorting_key = key
+            break
+        
+    if sorting_key is None:
+        if 'name' in sorting_list:
+            sorting_key = 'name'
+        else:
+            return object_list
+
+    try:
+        if sorting_key != 'name':
+            sorting_list = [(o[sorting_key].value, o)
+                           for o in object_list]
+            sorted_list = sorted(sorting_list, key=itemgetter(0))
+            return [x[1] for x in sorted_list]
+
+        if sorting_key == 'name':
+            sorting_list = [(_get_number_list(o.name),o)
+                           for o in object_list]
+            sorting_list.sort()
+            return [x[1] for x in sorting_list]
+    except:
+        #The only way to reach this point is to have different
+        #structures among the different entries. In that case
+        #defaults to the unfiltered case
+        print("WARNING: Default ordering")
+        print("Probably all entries do not have the key %s" % sorting_key)
+        return object_list
+
+def _get_number_list(txt):
+    rexpr = '[/a-zA-Z:-]'
+    nbs= [float(w) for w in re.split(rexpr, txt) if w not in ['',' ']]
+    return nbs
+
 class QRLock(QtCore.QMutex):
 
     """
@@ -90,9 +143,18 @@ class H5NodeProxy(object):
         if not self._children:
             # obtaining the lock here is necessary, otherwise application can
             # freeze if navigating tree while data is processing
-            with self.file.plock:
+            if 1: #with self.file.plock:
+                tmpList = list(self.getNode(self.name).values())
+                try:
+                    finalList = h5py_sorting(tmpList)
+                except:
+                    #one cannot afford any error
+                    if DEBUG:
+                        raise
+                    else:
+                        finalList = tmpList
                 self._children = [H5NodeProxy(self.file, i, self)
-                                  for i in self.getNode(self.name).values()]
+                                  for i in finalList]
         return self._children
 
     @property
@@ -109,7 +171,7 @@ class H5NodeProxy(object):
 
     @property
     def row(self):
-        with self.file.plock:
+        if 1:#with self.file.plock:
             try:
                 return self.parent.children.index(self)
             except ValueError:
@@ -142,7 +204,7 @@ class H5NodeProxy(object):
 
 
     def __init__(self, ffile, node, parent=None):
-        with ffile.plock:
+        if 1:#with ffile.plock:
             self._file = ffile
             self._parent = parent
             self._name = node.name
@@ -153,7 +215,18 @@ class H5NodeProxy(object):
                 self._name = posixpath.basename(node.name)
             """
             self._type = type(node).__name__
-            self._hasChildren = isinstance(node, phynx.Group)
+            self._hasChildren = isinstance(node, h5py.Group)
+            if hasattr(node, 'attrs'):
+                attrs = list(node.attrs)
+                for cname in ['class', 'NX_class']:
+                    if cname in attrs:
+                        if sys.version <'3.0':
+                            _type = "%s" % node.attrs[cname]
+                        else:
+                            _type = node.attrs[cname].decode('utf=8')
+                        self._type = _type
+                        break
+                        #self._type = _type[2].upper() + _type[3:]
             self._children = []
             if hasattr(node, 'dtype'):
                 self._dtype = str(node.dtype)
@@ -229,44 +302,36 @@ class FileModel(QtCore.QAbstractItemModel):
 
     def data(self, index, role):
         if role != QtCore.Qt.DisplayRole:
-            return QtCore.QVariant()
+            return MyQVariant()
         item = self.getProxyFromIndex(index)
         column = index.column()
         if column == 0:
-            """
-            # I would expect the title to be the proper
-            # thing to show ...
-            if hasattr(item, 'type'):
-                if item.type == "Entry":
-                    children = item.children
-                    names = [posixpath.basename(o.name) for o in children]
-                    if "title" in names:
-                        idx = names.index("title")
-                        children[idx].getNode().value[0]
-                        return QtCore.QVariant(children[idx].getNode().value[0])
-            """
             if isinstance(item, H5FileProxy):
-                return QtCore.QVariant(os.path.basename(item.file.filename))
+                return MyQVariant(os.path.basename(item.file.filename))
             else:
-                showtitle = False
-                if showtitle:
-                    if hasattr(item, 'type'):
-                        if item.type == "Entry":
-                            children = item.children
-                            names = [posixpath.basename(o.name) for o in children]
-                            if "title" in names:
-                                idx = names.index("title")
-                                children[idx].getNode().value[0]
-                                return QtCore.QVariant(children[idx].getNode().value[0])
-                    return QtCore.QVariant(posixpath.basename(item.name))
-                return QtCore.QVariant(posixpath.basename(item.name))
+                return MyQVariant(posixpath.basename(item.name))
         if column == 1:
-            return QtCore.QVariant(item.type)
+            showtitle = True
+            if showtitle:
+                if hasattr(item, 'type'):
+                    if item.type in ["Entry", "NXentry"]:
+                        children = item.children
+                        names = [posixpath.basename(o.name) for o in children]
+                        if "title" in names:
+                            idx = names.index("title")
+                            if len(children[idx].getNode().shape):
+                                #stored as an array of strings!!!
+                                #return just the first item
+                                return MyQVariant("%s" % children[idx].getNode().value[0])
+                            else:
+                                #stored as a string
+                                return MyQVariant("%s" % children[idx].getNode().value)
+            return MyQVariant(item.type)
         if column == 2:
-            return QtCore.QVariant(item.shape)
+            return MyQVariant(item.shape)
         if column == 3:
-            return QtCore.QVariant(item.dtype)
-        return QtCore.QVariant()
+            return MyQVariant(item.dtype)
+        return MyQVariant()
 
     def getNodeFromIndex(self, index):
         try:
@@ -290,9 +355,9 @@ class FileModel(QtCore.QAbstractItemModel):
     def headerData(self, section, orientation, role):
         if orientation == QtCore.Qt.Horizontal and \
                 role == QtCore.Qt.DisplayRole:
-            return QtCore.QVariant(self.rootItem.header[section])
+            return MyQVariant(self.rootItem.header[section])
 
-        return QtCore.QVariant()
+        return MyQVariant()
 
     def hasIndex(self, row, column, parent):
         parentItem = self.getProxyFromIndex(parent)
@@ -334,8 +399,7 @@ class FileModel(QtCore.QAbstractItemModel):
                 ddict['filename'] = filename
                 self.emit(QtCore.SIGNAL('fileUpdated'), ddict)
                 return item.file
-        #phynxFile = phynx.File(filename, 'a', lock=QRLock())
-        phynxFile = phynx.File(filename, 'r', lock=QRLock())
+        phynxFile = phynx.File(filename, 'r')
         if weakreference:
             def phynxFileInstanceDistroyed(weakrefObject):
                 idx = self.rootItem._identifiers.index(id(weakrefObject))
@@ -546,17 +610,17 @@ if __name__ == "__main__":
     import sys
     app = QtGui.QApplication(sys.argv)
     if len(sys.argv) < 2:
-        print "Usage:"
-        print "python HDF5Widget.py path_to_hdf5_file_name"
+        print("Usage:")
+        print("python HDF5Widget.py path_to_hdf5_file_name")
         sys.exit(0)
     fileModel = FileModel()
     fileView = HDF5Widget(fileModel)
     #fileModel.openFile('/home/darren/temp/PSI.hdf')
     phynxFile = fileModel.openFile(sys.argv[1])
     def mySlot(ddict):
-        print ddict
+        print(ddict)
         if ddict['type'].lower() in ['dataset']:
-            print phynxFile[ddict['name']].dtype, phynxFile[ddict['name']].shape
+            print(phynxFile[ddict['name']].dtype, phynxFile[ddict['name']].shape)
     QtCore.QObject.connect(fileView, QtCore.SIGNAL("HDF5WidgetSignal"), mySlot)
     fileView.show()
     sys.exit(app.exec_())
