@@ -1,7 +1,6 @@
 #!/usr/bin/env python
-__revision__ = "$Revision: 1.12 $"
 #/*##########################################################################
-# Copyright (C) 2004-2009 European Synchrotron Radiation Facility
+# Copyright (C) 2004-2011 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMCA X-ray Fluorescence Toolkit developed at
 # the ESRF by the Beamline Instrumentation Software Support (BLISS) group.
@@ -26,6 +25,7 @@ __revision__ = "$Revision: 1.12 $"
 # Please contact the ESRF industrial unit (industry@esrf.fr) if this license
 # is a problem for you.
 #############################################################################*/
+__revision__ = "$Revision: 1.13 $"
 import sys
 import os
 import PyMcaQt as qt
@@ -151,7 +151,8 @@ class Mca2EdfGUI(qt.QWidget):
         if True or self.__goodFileList(filelist):
             text = ""
             oldtype = None
-            filelist.sort()
+            #respect initial file list choice
+            #filelist.sort()
             for file in filelist:
                 text += "%s\n" % file
             self.fileList = filelist
@@ -355,8 +356,8 @@ class Mca2EdfBatch(qt.QThread):
                             self.__ncols = len(y0)
                             image = Numeric.zeros((self.__nrows,self.__ncols),Numeric.Float)
                         if self.__ncols !=  len(y0):
-                            print "spectrum has different number of columns"
-                            print "skipping it"
+                            print("spectrum has different number of columns")
+                            print("skipping it")
                         else:
                             image[counter,:] = y0[:]
                             if (counter+1) == self.filestep:
@@ -366,19 +367,20 @@ class Mca2EdfBatch(qt.QThread):
                                 else:
                                     title = key0
                                 if 1:
-                                    dict={}
-                                    if mcainfo.has_key('Channel0'):
-                                        dict['MCA start ch'] = int(mcainfo['Channel0'])
-                                    if mcainfo.has_key('McaCalib'):
-                                        dict['MCA a'] = mcainfo['McaCalib'][0]
-                                        dict['MCA b'] = mcainfo['McaCalib'][1]
-                                        dict['MCA c'] = mcainfo['McaCalib'][2]
+                                    ddict={}
+                                    if 'Channel0' in mcainfo:
+                                        ddict['MCA start ch'] =\
+                                                   int(mcainfo['Channel0'])
+                                    if 'McaCalib' in mcainfo:
+                                        ddict['MCA a'] = mcainfo['McaCalib'][0]
+                                        ddict['MCA b'] = mcainfo['McaCalib'][1]
+                                        ddict['MCA c'] = mcainfo['McaCalib'][2]
                                 else:
-                                    dict = mcainfo
-                                dict['Title'] = title
+                                    ddict = mcainfo
+                                ddict['Title'] = title
                                 edfname = os.path.join(self.outputdir,title.replace(" ","_")+".edf")
                                 edfout  = EdfFile.EdfFile(edfname)
-                                edfout.WriteImage (dict , image, Append=0)
+                                edfout.WriteImage (ddict , image, Append=0)
                                 counter = 0
                             else:
                                 counter += 1
@@ -472,8 +474,8 @@ class Mca2EdfWindow(qt.QWidget):
         elif event.dict['event'] == 'batchResumed':self.onResume()
 
         else:
-            print "Unhandled event",event 
-                                                
+            print("Unhandled event %s" % event)
+                                
 
     def onNewFile(self, file, filelist):
         indexlist = range(0,len(filelist))
