@@ -1,5 +1,5 @@
 #/*##########################################################################
-# Copyright (C) 2004-2010 European Synchrotron Radiation Facility
+# Copyright (C) 2004-2012 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMCA X-ray Fluorescence Toolkit developed at
 # the ESRF by the Beamline Instrumentation Software Support (BLISS) group.
@@ -33,18 +33,15 @@ import types
 import h5py
 import re
 import posixpath
+phynx = h5py
 
-try:
-    import PyMca.phynx as phynx
-except ImportError:
-    try:
-        import phynx
-    except ImportError:
-        from xpaxs.io import phynx
+if sys.version > '2.9':
+    basestring = str
 
 SOURCE_TYPE = "HDF5"
 DEBUG = 0
 
+#sorting method
 def h5py_sorting(object_list):
     sorting_list = ['start_time', 'end_time', 'name']
     n = len(object_list)
@@ -55,7 +52,7 @@ def h5py_sorting(object_list):
     if posixpath.dirname(object_list[0].name) != "/":
         return object_list
 
-    names = object_list[0].keys()
+    names = list(object_list[0].keys())
 
     sorting_key = None
     for key in sorting_list:
@@ -68,13 +65,13 @@ def h5py_sorting(object_list):
             sorting_key = 'name'
         else:
             return object_list
-        
+
     try:
         if sorting_key != 'name':
             sorting_list = [(o[sorting_key].value, o)
                            for o in object_list]
-            sorting_list.sort()
-            return [x[1] for x in sorting_list]
+            sorted_list = sorted(sorting_list, key=itemgetter(0))
+            return [x[1] for x in sorted_list]
 
         if sorting_key == 'name':
             sorting_list = [(_get_number_list(o.name),o)
@@ -88,7 +85,7 @@ def h5py_sorting(object_list):
         print("WARNING: Default ordering")
         print("Probably all entries do not have the key %s" % sorting_key)
         return object_list
-
+    
 def _get_number_list(txt):
     rexpr = '[/a-zA-Z:-]'
     nbs= [float(w) for w in re.split(rexpr, txt) if w not in ['',' ']]
@@ -138,15 +135,15 @@ def get_family_pattern(filelist):
     return rootname
 
 
-class NexusDataSource:
+class NexusDataSource(object):
     def __init__(self,nameInput):
-        if type(nameInput) == types.ListType:
+        if type(nameInput) == type([]):
             nameList = nameInput
         else:
             nameList = [nameInput]
         self.sourceName = []
         for name in nameList:
-            if type(name) != types.StringType:
+            if not isinstance(name, basestring):
                 if not isinstance(name, phynx.File):
                     text = "Constructor needs string as first argument"
                     raise TypeError(text)
@@ -156,9 +153,12 @@ class NexusDataSource:
             self.sourceName.append(name)
         self.sourceType = SOURCE_TYPE
         self.__sourceNameList = self.sourceName
+        self._sourceObjectList=[]
         self.refresh()
         
     def refresh(self):
+        for instance in self._sourceObjectList:
+            instance.close()
         self._sourceObjectList=[]
         FAMILY = False
         for name in self.__sourceNameList:
@@ -167,20 +167,12 @@ class NexusDataSource:
                 continue
             if not os.path.exists(name):
                 if '%' in name:
-                    try:
-                        phynxInstance = phynx.File(name, 'r',
-                           driver='family',
-                           lock=None,
-                           sorted_with=h5py_sorting)
-                    except TypeError:
-                        phynxInstance = phynx.File(name, 'r',
-                                               driver='family',
-                                               lock=None)
+                   phynxInstance = phynx.File(name, 'r',
+                                              driver='family')
                 else:
-                    raise IOError, "File %s does not exists" % name
+                    raise IOError("File %s does not exists" % name)
             try:
-                phynxInstance = phynx.File(name, 'r', lock=None,
-                                           sorted_with=h5py_sorting)
+                phynxInstance = phynx.File(name, 'r')
             except IOError:
                 if 'FAMILY DRIVER' in sys.exc_info()[1].args[0].upper():
                     FAMILY = True
@@ -188,14 +180,15 @@ class NexusDataSource:
                     raise
             except TypeError:
                 try:
-                    phynxInstance = phynx.File(name, 'r', lock=None)
+                    phynxInstance = phynx.File(name, 'r')
                 except IOError:
                     if 'FAMILY DRIVER' in sys.exc_info()[1].args[0].upper():
                         FAMILY = True
                     else:
                         raise
             if FAMILY and (len(self._sourceObjectList) > 0):
-                raise IOError, "Mixing segmented and non-segmented HDF5 files not supported yet"
+                txt = "Mixing segmented and non-segmented HDF5 files not supported yet"
+                raise IOError(txt)
             elif FAMILY:
                 break
             phynxInstance._sourceName = name
@@ -203,16 +196,10 @@ class NexusDataSource:
         if FAMILY:
             pattern = get_family_pattern(self.__sourceNameList)
             if '%' in pattern:
-                try:
-                    phynxInstance = phynx.File(pattern, 'r',
-                                            driver='family', 
-                                            lock=None,
-                                           sorted_with=h5py_sorting)
-                except TypeError:
-                    phynxInstance = phynx.File(pattern, 'r', 
-                                            driver='family',lock=None)
+                phynxInstance = phynx.File(pattern, 'r',
+                                            driver='family')
             else:
-                raise IOError, "Cannot set of HDF5 files"
+                raise IOError("Cannot read set of HDF5 files")
             self.sourceName   = [pattern]
             self.__sourceNameList = [pattern]
             self._sourceObjectList=[phynxInstance]
@@ -237,7 +224,7 @@ class NexusDataSource:
             i+=1
             nEntries = len(sourceObject["/"].keys())
             for n in range(nEntries):
-                SourceInfo["KeyList"].append("%d.%d" % (i,n+1))   
+                SourceInfo["KeyList"].append("%d.%d" % (i,n+1))
         SourceInfo["Size"]=len(SourceInfo["KeyList"])
         return SourceInfo
         
@@ -247,7 +234,7 @@ class NexusDataSource:
         else:
             #should we raise a KeyError?
             if DEBUG:
-                print "Error key not in list "
+                print("Error key not in list ")
             return {}
     
     def __getKeyInfo(self,key):
@@ -258,7 +245,7 @@ class NexusDataSource:
         except:
             #should we rise an error?
             if DEBUG:
-                print "Error trying to interpret key =",key
+                print("Error trying to interpret key = %s" % key)
             return {}
 
         sourceObject = self._sourceObjectList[index]
@@ -278,7 +265,7 @@ class NexusDataSource:
         selection: a dictionnary generated via QNexusWidget
         """
         if selection is not None:
-            if selection.has_key('sourcename'):
+            if 'sourcename' in selection:
                 filename  = selection['sourcename']
                 entry     = selection['entry']
                 fileIndex  = self.__sourceNameList.index(filename)
@@ -286,7 +273,7 @@ class NexusDataSource:
                 if entry == "/":
                     entryIndex = 0
                 else:
-                    entryIndex = phynxFile["/"].keys().index(entry[1:])
+                    entryIndex = list(phynxFile["/"].keys()).index(entry[1:])
             else:
                 key_split = key.split(".")
                 fileIndex = int(key_split[0])-1
@@ -296,15 +283,17 @@ class NexusDataSource:
             actual_key = "%d.%d" % (fileIndex+1, entryIndex+1)
             if actual_key != key:
                 if entry != "/":
-                    print "Warning selection keys do not match"
+                    print("Warning selection keys do not match")
         else:
+            #Probably I should find the acual entry following h5py_ordering output
+            #and search for an NXdata plot.
             sourcekeys = self.getSourceInfo()['KeyList']
             #a key corresponds to an image        
             key_split= key.split(".")
             actual_key= "%d.%d" % (int(key_split[0]), int(key_split[1]))
             if actual_key not in sourcekeys:
-                raise KeyError,"Key %s not in source keys" % actual_key
-            raise NotImplemented, "Direct NXdata plot not implemented yet"        
+                raise KeyError("Key %s not in source keys" % actual_key)
+            raise NotImplemented("Direct NXdata plot not implemented yet")        
         #create data object
         output = DataObject.DataObject()
         output.info = self.__getKeyInfo(actual_key)
@@ -317,10 +306,11 @@ class NexusDataSource:
             output.info['selectiontype'] = "2D"
             output.info['imageselection'] = True
         else:
-            raise TypeError, "Unsupported selection type %s" % selection['selectiontype']
-        if selection.has_key('LabelNames'):
+            raise TypeError("Unsupported selection type %s" %\
+                            selection['selectiontype'])
+        if 'LabelNames' in selection:
             output.info['LabelNames'] = selection['LabelNames']
-        elif selection.has_key('aliaslist'):
+        elif 'aliaslist' in selection:
             output.info['LabelNames'] = selection['aliaslist']
         else:
             output.info['LabelNames'] = selection['cntlist']
@@ -329,7 +319,7 @@ class NexusDataSource:
         output.m = None
         output.data = None
         for cnt in ['y', 'x', 'm']:
-            if not selection.has_key(cnt):
+            if not cnt in selection:
                 continue
             if not len(selection[cnt]):
                 continue
@@ -338,19 +328,20 @@ class NexusDataSource:
             totalElements = 1
             for dim in data.shape:
                 totalElements *= dim
-            if totalElements < 1.0E8:
+            if totalElements < 2.0E7:
                 try:
                     data = phynxFile[path].value
                 except MemoryError:
+                    data = phynxFile[path]
                     pass
             if output.info['selectiontype'] == "1D":
                 if len(data.shape) == 2:
                     if min(data.shape) == 1:
                         data = numpy.ravel(data)
                     else:
-                        raise TypeError, "%s selection is not 1D" % cnt.upper()
+                        raise TypeError("%s selection is not 1D" % cnt.upper())
                 elif len(data.shape) > 2:
-                    raise TypeError, "%s selection is not 1D" % cnt.upper()                
+                    raise TypeError("%s selection is not 1D" % cnt.upper())            
             if cnt == 'y':
                 if output.info['selectiontype'] == "2D":
                     output.data = data
@@ -360,7 +351,7 @@ class NexusDataSource:
                 #there can be more than one X except for 1D
                 if output.info['selectiontype'] == "1D":
                     if len(selection[cnt]) > 1:
-                        raise TypeError, "%s selection is not 1D" % cnt.upper()
+                        raise TypeError("%s selection is not 1D" % cnt.upper())
                 if output.x is None:
                     output.x = [data]
                 if len(selection[cnt]) > 1:
@@ -373,7 +364,7 @@ class NexusDataSource:
                 output.m = [data]
         # MCA specific
         if selection['selectiontype'].upper() == "MCA":
-            if not output.info.has_key('Channel0'):
+            if not 'Channel0' in output.info:
                 output.info['Channel0'] = 0
         """"
         elif selection['selectiontype'].upper() in ["BATCH"]:
@@ -434,8 +425,8 @@ def DataSource(name="", source_type=SOURCE_TYPE):
      sourceClass = source_types[source_type]
   except KeyError:
      #ERROR invalid source type
-     raise TypeError,"Invalid Source Type, source type should be one of %s" % source_types.keys()
-  
+     raise TypeError("Invalid Source Type, source type should be one of %s" %\
+                     source_types.keys())  
   return sourceClass(name)
 
         
@@ -445,25 +436,25 @@ if __name__ == "__main__":
         sourcename=sys.argv[1]
         key       =sys.argv[2]        
     except:
-        print "Usage: EdfFileDataSource <file> <key>"
+        print("Usage: NexusDataSource <file> <key>")
         sys.exit()
     #one can use this:
-    obj = EdfFileDataSource(sourcename)
+    obj = NexusDataSource(sourcename)
     #or this:
     obj = DataSource(sourcename)
     #data = obj.getData(key,selection={'pos':(10,10),'size':(40,40)})
     #data = obj.getDataObject(key,selection={'pos':None,'size':None})
     t0 = time.time()
     data = obj.getDataObject(key,selection=None)
-    print "elapsed = ",time.time() - t0
-    print "info = ",data.info
+    print("elapsed = ",time.time() - t0)
+    print("info = ",data.info)
     if data.data is not None:
-        print "data shape = ",data.data.shape
-        print Numeric.ravel(data.data)[0:10]
+        print("data shape = ",data.data.shape)
+        print(Numeric.ravel(data.data)[0:10])
     else:
-        print data.y[0].shape
-        print Numeric.ravel(data.y[0])[0:10]
+        print(data.y[0].shape)
+        print(Numeric.ravel(data.y[0])[0:10])
     data = obj.getDataObject('1.1',selection=None)
     r = int(key.split('.')[-1])
-    print " data[%d,0:10] = " % (r-1),data.data[r-1   ,0:10]
-    print " data[0:10,%d] = " % (r-1),data.data[0:10, r-1]        
+    print(" data[%d,0:10] = " % (r-1),data.data[r-1   ,0:10])
+    print(" data[0:10,%d] = " % (r-1),data.data[0:10, r-1])
