@@ -1,5 +1,5 @@
 #/*##########################################################################
-# Copyright (C) 2004-2010 European Synchrotron Radiation Facility
+# Copyright (C) 2004-2012 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMCA X-ray Fluorescence Toolkit developed at
 # the ESRF by the Beamline Instrumentation Software Support (BLISS) group.
@@ -58,7 +58,7 @@ class PCAParametersDialog(qt.QDialog):
         self.methodOptions = qt.QGroupBox(self)
         self.methodOptions.setTitle('PCA Method to use')
         self.methods = ['Covariance', 'Expectation Max.', 'Cov. Multiple Arrays']
-        self.functions = [PCAModule.lanczosPCA,
+        self.functions = [PCAModule.numpyPCA,
                           PCAModule.expectationMaximizationPCA,
                           PCAModule.multipleArrayPCA]
         self.methodOptions.mainLayout = qt.QGridLayout(self.methodOptions)
@@ -255,18 +255,18 @@ class PCAParametersDialog(qt.QDialog):
         self.scanWindow.newCurve(x, y, self._legend, replace=True)
 
     def setParameters(self, ddict):
-        if ddict.has_key('options'):
+        if 'options' in ddict:
             self.binningCombo.clear()
             for option in ddict['options']:
                 self.binningCombo.addItem("%d" % option)
-        if ddict.has_key('binning'):
+        if 'binning' in ddict:
             option = "%d" % ddict['binning']
             for i in range(self.binningCombo.count()):
                 if str(self.binningCombo.itemText(i)) == option:
                     self.binningCombo.setCurrentIndex(i)
-        if ddict.has_key('npc'):
+        if 'npc' in ddict:
             self.nPC.setValue(ddict['npc'])
-        if ddict.has_key('method'):
+        if 'method' in ddict:
             self.buttonGroup.buttons()[ddict['method']].setChecked(True)
             if ddict['method'] != 2:
                 self.binningCombo.setEnabled(True)
@@ -571,7 +571,7 @@ def test2():
     ret = dialog.exec_()
     if ret:
         dialog.close()
-        print dialog.getParameters()
+        print(dialog.getParameters())
     #app.exec_()
 
 def test():
@@ -589,7 +589,7 @@ def test():
                                 imagenames=["I1", "I2"], vectornames=["V1", "V2"])
     container.show()
     def theSlot(ddict):
-        print ddict['event']
+        print(ddict['event'])
 
     if QTVERSION < '4.0.0':
         qt.QObject.connect(container,
