@@ -8,7 +8,7 @@ try:
 except ImportError:
     text  = "You must have numpy installed.\n"
     text += "See http://sourceforge.net/project/showfiles.php?group_id=1369&package_id=175103\n"
-    raise ImportError, text
+    raise ImportError(text)
 
 from distutils.core import setup
 from distutils.extension import Extension
