@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 __revision__ = "$Revision: 2.02 $"
 #/*##########################################################################
-# Copyright (C) 2004-2010 European Synchrotron Radiation Facility
+# Copyright (C) 2004-2012 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMCA X-ray Fluorescence Toolkit developed at
 # the ESRF by the Beamline Instrumentation Software Support (BLISS) group.
@@ -26,7 +26,8 @@ __revision__ = "$Revision: 2.02 $"
 # Please contact the ESRF industrial unit (industry@esrf.fr) if this license 
 # is a problem for you.
 #############################################################################*/
-import sys, getopt, string
+import sys, getopt
+import traceback
 nativeFileDialogs = None
 DEBUG = 0
 if __name__ == '__main__':
@@ -37,8 +38,8 @@ if __name__ == '__main__':
                      sys.argv[1:],
                      options,
                      longoptions)
-    except getopt.error,msg:
-        print msg
+    except getopt.error:
+        print(sys.exc_info()[1])
         sys.exit(1)
     
     keywords={}
@@ -67,19 +68,24 @@ if __name__ == '__main__':
 import PyMcaMdi
 from PyMcaMdi import qt
 
+if hasattr(qt, "QString"):
+    QString = qt.QString
+else:
+    QString = str
+
 QTVERSION = qt.qVersion()
 
 from PyMca_Icons import IconDict
 from PyMca_help import HelpDict
 import os
-__version__ = "4.4.1"
+__version__ = "4.5.0"
 if (QTVERSION < '4.0.0') and ((sys.platform == 'darwin') or (QTVERSION < '3.0.0')):
     class SplashScreen(qt.QWidget):
         def __init__(self,parent=None,name="SplashScreen",
                         fl=qt.Qt.WStyle_Customize  | qt.Qt.WDestructiveClose,
                         pixmap = None):
             qt.QWidget.__init__(self,parent,name,fl)
-            self.setCaption("PyMCA %s" % __version__)
+            self.setCaption("PyMca %s" % __version__)
             layout = qt.QVBoxLayout(self)
             layout.setAutoAdd(1)
             label = qt.QLabel(self)
@@ -98,7 +104,7 @@ if (QTVERSION < '4.0.0') and ((sys.platform == 'darwin') or (QTVERSION < '3.0.0'
 
 if __name__ == "__main__":
     app = qt.QApplication(sys.argv)
-    if qt.qVersion >= '3.0.0':
+    if QTVERSION >= '3.0.0':
         strlist = qt.QStyleFactory.keys()
         if sys.platform == "win32":
             for item in strlist:
@@ -145,7 +151,7 @@ if __name__ == "__main__":
              else:
                  break
         if os.path.exists(fname):
-            pixmap = qt.QPixmap(qt.QString(fname))
+            pixmap = qt.QPixmap(QString(fname))
             splash  = qt.QSplashScreen(pixmap)
         else:
             splash = qt.QSplashScreen()
@@ -154,7 +160,7 @@ if __name__ == "__main__":
         font = splash.font()
         font.setBold(1)
         splash.setFont(font)
-        splash.showMessage( 'PyMCA %s' % __version__, 
+        splash.showMessage( 'PyMca %s' % __version__, 
                 qt.Qt.AlignLeft|qt.Qt.AlignBottom, 
                 qt.Qt.white)
         if sys.platform == "darwin":
@@ -360,7 +366,7 @@ class PyMca(PyMcaMdi.PyMca):
                 else:
                     self.connect(self.mcawindow,qt.SIGNAL('McaWindowSignal'),
                                  self.__McaWindowSignal)
-                if kw.has_key('shm'):
+                if 'shm' in kw:
                     if len(kw['shm']) >= 8:
                         if kw['shm'][0:8] in ['MCA_DATA', 'XIA_DATA']:
                             self.mcawindow.showMaximized()
@@ -370,11 +376,11 @@ class PyMca(PyMcaMdi.PyMca):
             currentConfigDict = ConfigDict.ConfigDict()
             defaultFileName = self.__getDefaultSettingsFile()
             self.configDir  = os.path.dirname(defaultFileName)
-            if not kw.has_key('fresh'):
+            if not ('fresh' in kw):
                 if os.path.exists(defaultFileName):
                     currentConfigDict.read(defaultFileName)
                     self.setConfig(currentConfigDict)
-            if kw.has_key('spec') and kw.has_key('shm'):
+            if ('spec' in kw) and ('shm' in kw):
                 if len(kw['shm']) >= 8:
                     #if kw['shm'][0:8] in ['MCA_DATA', 'XIA_DATA']:
                     if kw['shm'][0:8] in ['MCA_DATA']:
@@ -413,22 +419,22 @@ class PyMca(PyMcaMdi.PyMca):
         if QTVERSION < '4.0.0':
             #is not an index but a widget
             index = self.mainTabWidget.indexOf(index)
-            legend = str(self.mainTabWidget.label(index))
+            legend = "%s" % self.mainTabWidget.label(index)
         else:
-            legend = str(self.mainTabWidget.tabText(index))
+            legend = "%s" % self.mainTabWidget.tabText(index)
             for key in self.imageWindowDict.keys():
                 if key == legend:value = True
                 else: value = False
                 self.imageWindowDict[key].setPlotEnabled(value)
 
     def _is2DSelection(self, ddict):
-        if ddict.has_key('imageselection'):
+        if 'imageselection' in ddict:
             if ddict['imageselection']:
                 return True
-        if ddict.has_key('selection'):
+        if 'selection' in ddict:
             if ddict['selection'] is None:
                 return False
-            if ddict['selection'].has_key('selectiontype'):
+            if 'selectiontype' in ddict['selection']:
                 if ddict['selection']['selectiontype'] == '2D':
                     return True
         return False
@@ -437,14 +443,14 @@ class PyMca(PyMcaMdi.PyMca):
         if self._is2DSelection(ddict):
             return False
 
-        if ddict.has_key('selection'):
+        if 'selection' in ddict:
             if ddict['selection'] is None:
                 return False
-            if ddict['selection'].has_key('selectiontype'):
+            if 'selectiontype' in ddict['selection']:
                 if ddict['selection']['selectiontype'] == '3D':
                     return True
             
-            if ddict['selection'].has_key('x'):
+            if 'x' in ddict['selection']:
                 if ddict['selection']['x'] is not None:
                     if len(ddict['selection']['x']) > 1:
                         return True           
@@ -455,10 +461,10 @@ class PyMca(PyMcaMdi.PyMca):
             return False
         if self._is3DSelection(ddict):
             return False
-        if ddict.has_key('selection'):
+        if 'selection' in ddict:
             if ddict['selection'] is None:
                 return False
-            if ddict['selection'].has_key('selectiontype'):
+            if 'selectiontype' in ddict['selection']:
                 if ddict['selection']['selectiontype'] == 'STACK':
                     return True
         return False
@@ -480,17 +486,19 @@ class PyMca(PyMcaMdi.PyMca):
             if QTVERSION < '4.0.0':
                 msg.exec_loop()
             else:
+                msg.setInformativeText(str(sys.exc_info()[1]))
+                msg.setDetailedText(traceback.format_exc())
                 msg.exec_()
 
     def _dispatcherAddSelectionSlot(self, ddict):
         if DEBUG:
-            print "self.dispatcherAddSelectionSlot(ddict), ddict = ",ddict
+            print("self.dispatcherAddSelectionSlot(ddict), ddict = ",ddict)
 
         toadd = False
         if self._is2DSelection(ddict):
             if QTVERSION < '4.0.0':
                 if DEBUG:
-                    print "For the time being, no Qt3 support"
+                    print("For the time being, no Qt3 support")
                 return
             if self.imageWindowCorrelator is None:
                 self.imageWindowCorrelator = RGBCorrelator.RGBCorrelator()
@@ -514,10 +522,12 @@ class PyMca(PyMcaMdi.PyMca):
                     pass
                 if hkl:
                     imageWindow = PyMcaHKLImageWindow.PyMcaHKLImageWindow(name = legend,
-                                correlator = self.imageWindowCorrelator)
+                                correlator = self.imageWindowCorrelator,
+                                scanwindow=self.scanwindow)
                 else:
                     imageWindow = PyMcaImageWindow.PyMcaImageWindow(name = legend,
-                                correlator = self.imageWindowCorrelator)
+                                correlator = self.imageWindowCorrelator,
+                                scanwindow=self.scanwindow)
                 self.imageWindowDict[legend] = imageWindow
                 if QTVERSION > '4.0.0':
                     self.connect(imageWindow, qt.SIGNAL("addImageClicked"),
@@ -586,12 +596,12 @@ class PyMca(PyMcaMdi.PyMca):
 
     def _dispatcherRemoveSelectionSlot(self, ddict):
         if DEBUG:
-            print "self.dispatcherRemoveSelectionSlot(ddict), ddict = ",ddict
+            print("self.dispatcherRemoveSelectionSlot(ddict), ddict = ",ddict)
 
         if self._is2DSelection(ddict):
             if QTVERSION < '4.0.0':
                 if DEBUG:
-                    print "For the time being, no Qt3 support"
+                    print("For the time being, no Qt3 support")
                 return
             legend = ddict['legend'] 
             if legend in self.imageWindowDict.keys():
@@ -622,14 +632,14 @@ class PyMca(PyMcaMdi.PyMca):
 
     def _dispatcherReplaceSelectionSlot(self, ddict):
         if DEBUG:
-            print "self.dispatcherReplaceSelectionSlot(ddict), ddict = ",ddict
+            print("self.dispatcherReplaceSelectionSlot(ddict), ddict = ",ddict)
         if self._is2DSelection(ddict):
             if QTVERSION < '4.0.0':
                 if DEBUG:
-                    print "For the time being, no Qt3 support"
+                    print("For the time being, no Qt3 support")
                 return
             legend = ddict['legend']
-            for key in self.imageWindowDict.keys():
+            for key in list(self.imageWindowDict.keys()):
                 index = self.mainTabWidget.indexOf(self.imageWindowDict[key])
                 if key == legend:continue
                 if index >= 0:
@@ -654,7 +664,8 @@ class PyMca(PyMcaMdi.PyMca):
             self.scanwindow._replaceSelection(ddict)
 
     def dispatcherOtherSignalsSlot(self, ddict):
-        if DEBUG:print "self.dispatcherOtherSignalsSlot(ddict), ddict = ",ddict
+        if DEBUG:
+            print("self.dispatcherOtherSignalsSlot(ddict), ddict = ",ddict)
         if not self.__useTabWidget:return
         if ddict['event'] == "SelectionTypeChanged":
             if QTVERSION < '4.0.0':
@@ -678,16 +689,21 @@ class PyMca(PyMcaMdi.PyMca):
         if ddict['event'] == "SourceTypeChanged":
             pass
             return
-        if DEBUG:print "Unhandled dict"
+        if DEBUG:
+            print("Unhandled dict")
         
     def setConfig(self, configDict):
-        if configDict.has_key('PyMca'):    self.__configurePyMca(configDict['PyMca'])
-        if configDict.has_key('ROI'):      self.__configureRoi(configDict['ROI'])
-        if configDict.has_key('Elements'): self.__configureElements(configDict['Elements'])
-        if configDict.has_key('Fit'):      self.__configureFit(configDict['Fit'])
-        if configDict.has_key('ScanSimpleFit'):
+        if 'PyMca' in configDict:
+            self.__configurePyMca(configDict['PyMca'])
+        if 'ROI' in configDict:
+            self.__configureRoi(configDict['ROI'])
+        if 'Elements' in configDict:
+            self.__configureElements(configDict['Elements'])
+        if 'Fit' in configDict:
+            self.__configureFit(configDict['Fit'])
+        if 'ScanSimpleFit' in configDict:
             self.__configureScanSimpleFit(configDict['ScanSimpleFit'])
-        if configDict.has_key('ScanCustomFit'):
+        if 'ScanCustomFit' in configDict:
             self.__configureScanCustomFit(configDict['ScanCustomFit'])
         
     def getConfig(self):
@@ -783,7 +799,7 @@ class PyMca(PyMcaMdi.PyMca):
                   d['ScanSimpleFit']['Configuration'].update(\
                       self.scanwindow.scanFit.getConfiguration())
             except:
-                print "Error getting ScanFint configuration"
+                print("Error getting ScanFint configuration")
         return d
         
     def saveConfig(self, config, filename = None):
@@ -794,10 +810,10 @@ class PyMca(PyMcaMdi.PyMca):
         d.write(filename)
 
     def __configurePyMca(self, dict):
-        if dict.has_key('ConfigDir'):
+        if 'ConfigDir' in dict:
             self.configDir = dict['ConfigDir']
 
-        if dict.has_key('Geometry'):
+        if 'Geometry' in dict:
             r = qt.QRect(*dict['Geometry']['MainWindow'])
             self.setGeometry(r)
             key = 'Splitter'
@@ -821,19 +837,19 @@ class PyMca(PyMcaMdi.PyMca):
             
         PyMcaDirs.nativeFileDialogs = dict.get('nativeFileDialogs', True)
 
-        if dict.has_key('Sources'):
-            if dict['Sources'].has_key('lastFileFilter'):
+        if 'Sources' in dict:
+            if 'lastFileFilter' in dict['Sources']:
                 self.sourceWidget.sourceSelector.lastFileFilter = dict['Sources']['lastFileFilter']
         for source in SOURCESLIST:
-            if dict.has_key(source):
-                if dict[source].has_key('lastInputDir'):
+            if source in dict:
+                if 'lastInputDir' in dict[source]:
                     if dict[source] ['lastInputDir'] != "None":
                         self.sourceWidget.sourceSelector.lastInputDir =  dict[source] ['lastInputDir']
                         try:
                             PyMcaDirs.inputDir = dict[source] ['lastInputDir']
                         except ValueError:
                             pass
-                if dict[source].has_key('SourceName'):
+                if 'SourceName' in dict[source]:
                     if type(dict[source]['SourceName']) != type([]):
                         dict[source]['SourceName'] = [dict[source]['SourceName'] * 1]
                     for SourceName in dict[source]['SourceName']:
@@ -861,7 +877,7 @@ class PyMca(PyMcaMdi.PyMca):
                                 else:
                                     msg.exec_()
 
-                if dict[source].has_key('WidgetConfiguration'):
+                if 'WidgetConfiguration' in dict[source]:
                     selectorWidget = self.sourceWidget.selectorWidget[source]
                     if hasattr(selectorWidget,'setWidgetConfiguration'):
                         try:
@@ -875,7 +891,7 @@ class PyMca(PyMcaMdi.PyMca):
                             else:
                                 msg.exec_()
                 """
-                if dict[source].has_key('Selection'):
+                if 'Selection' in dict[source]:
                     if type(dict[source]['Selection']) != type([]):
                         dict[source]['Selection'] = [dict[source]['Selection']]
                     if source == "EdfFile":
@@ -883,29 +899,29 @@ class PyMca(PyMcaMdi.PyMca):
                 """    
 
 
-    def __configureRoi(self, dict):
-        if dict.has_key('roidict'):
-            if dict.has_key('roilist'):
-                roilist = dict['roilist']
+    def __configureRoi(self, ddict):
+        if 'roidict' in ddict:
+            if 'roilist' in ddict:
+                roilist = ddict['roilist']
                 if type(roilist) != type([]):
                     roilist=[roilist]                
-                roidict = dict['roidict']
+                roidict = ddict['roidict']
                 self.mcawindow.roiwidget.fillfromroidict(roilist=roilist,
                                                          roidict=roidict)
             
 
-    def __configureElements(self, dict):
-        if dict.has_key('Material'):
-            ElementsInfo.Elements.Material.update(dict['Material'])    
+    def __configureElements(self, ddict):
+        if 'Material' in ddict:
+            ElementsInfo.Elements.Material.update(ddict['Material'])
 
     def __configureFit(self, d):
-        if d.has_key('Configuration'):
+        if 'Configuration' in d:
             self.mcawindow.advancedfit.mcafit.configure(d['Configuration'])
             if not self.mcawindow.advancedfit.isHidden():
                 self.mcawindow.advancedfit._updateTop()
-        if d.has_key('ConfigDir'):
+        if 'ConfigDir' in d:
             self.mcawindow.advancedfit.configDir = d['ConfigDir'] * 1
-        if False and d.has_key('LastFit'):
+        if False and ('LastFit' in d):
             if (d['LastFit']['ydata0'] != None) and \
                (d['LastFit']['ydata0'] != 'None'):               
                 self.mcawindow.advancedfit.setdata(x=d['LastFit']['xdata0'],
@@ -921,16 +937,16 @@ class PyMca(PyMcaMdi.PyMca):
                         except:
                             pass  
                 else:
-                    print "hidden"     
+                    print("hidden")
             
     def __configureFit(self, d):
-        if d.has_key('Configuration'):
+        if 'Configuration' in d:
             self.mcawindow.advancedfit.mcafit.configure(d['Configuration'])
             if not self.mcawindow.advancedfit.isHidden():
                 self.mcawindow.advancedfit._updateTop()
-        if d.has_key('ConfigDir'):
+        if 'ConfigDir' in d:
             self.mcawindow.advancedfit.configDir = d['ConfigDir'] * 1
-        if False and d.has_key('LastFit'):
+        if False and ('LastFit' in d):
             if (d['LastFit']['ydata0'] != None) and \
                (d['LastFit']['ydata0'] != 'None'):               
                 self.mcawindow.advancedfit.setdata(x=d['LastFit']['xdata0'],
@@ -946,20 +962,20 @@ class PyMca(PyMcaMdi.PyMca):
                         except:
                             pass  
                 else:
-                    print "hidden"     
+                    print("hidden")
 
     def __configureScanCustomFit(self, ddict):
         pass
 
     def __configureScanSimpleFit(self, ddict):
-        if ddict.has_key('Configuration'):
+        if 'Configuration' in ddict:
             self.scanwindow.scanFit.setConfiguration(ddict['Configuration'])
                 
     def initMenuBar(self):
         if self.options["MenuFile"]:
             if QTVERSION < '4.0.0':
                 self.menuFile= qt.QPopupMenu(self.menuBar())
-                idx= self.menuFile.insertItem(self.Icons["fileopen"], qt.QString("&Open"), self.onOpen, qt.Qt.CTRL+qt.Qt.Key_O)
+                idx= self.menuFile.insertItem(self.Icons["fileopen"], QString("&Open"), self.onOpen, qt.Qt.CTRL+qt.Qt.Key_O)
                 self.menuFile.setWhatsThis(idx, HelpDict["fileopen"])
                 idx= self.menuFile.insertItem(self.Icons["filesave"], "&Save as", self.onSaveAs, qt.Qt.CTRL+qt.Qt.Key_S)
                 self.menuFile.setWhatsThis(idx, HelpDict["filesave"])
@@ -976,14 +992,14 @@ class PyMca(PyMcaMdi.PyMca):
                 #build the actions
                 #fileopen
                 self.actionOpen = qt.QAction(self)
-                self.actionOpen.setText(qt.QString("&Open"))
+                self.actionOpen.setText(QString("&Open"))
                 self.actionOpen.setIcon(self.Icons["fileopen"])
                 self.actionOpen.setShortcut(qt.Qt.CTRL+qt.Qt.Key_O)
                 self.connect(self.actionOpen, qt.SIGNAL("triggered(bool)"),
                              self.onOpen)
                 #filesaveas
                 self.actionSaveAs = qt.QAction(self)
-                self.actionSaveAs.setText(qt.QString("&Save"))
+                self.actionSaveAs.setText(QString("&Save"))
                 self.actionSaveAs.setIcon(self.Icons["filesave"])
                 self.actionSaveAs.setShortcut(qt.Qt.CTRL+qt.Qt.Key_S)
                 self.connect(self.actionSaveAs, qt.SIGNAL("triggered(bool)"),
@@ -991,14 +1007,14 @@ class PyMca(PyMcaMdi.PyMca):
 
                 #filesave
                 self.actionSave = qt.QAction(self)
-                self.actionSave.setText(qt.QString("Save &Default Settings"))
+                self.actionSave.setText(QString("Save &Default Settings"))
                 #self.actionSave.setIcon(self.Icons["filesave"])
                 #self.actionSave.setShortcut(qt.Qt.CTRL+qt.Qt.Key_S)
                 self.connect(self.actionSave, qt.SIGNAL("triggered(bool)"),
                              self.onSave)
                 #fileprint
                 self.actionPrint = qt.QAction(self)
-                self.actionPrint.setText(qt.QString("&Print"))
+                self.actionPrint.setText(QString("&Print"))
                 self.actionPrint.setIcon(self.Icons["fileprint"])
                 self.actionPrint.setShortcut(qt.Qt.CTRL+qt.Qt.Key_P)
                 self.connect(self.actionPrint, qt.SIGNAL("triggered(bool)"),
@@ -1006,7 +1022,7 @@ class PyMca(PyMcaMdi.PyMca):
 
                 #filequit
                 self.actionQuit = qt.QAction(self)
-                self.actionQuit.setText(qt.QString("&Quit"))
+                self.actionQuit.setText(QString("&Quit"))
                 #self.actionQuit.setIcon(self.Icons["fileprint"])
                 self.actionQuit.setShortcut(qt.Qt.CTRL+qt.Qt.Key_Q)
                 qt.QObject.connect(self.actionQuit,
@@ -1192,7 +1208,7 @@ class PyMca(PyMcaMdi.PyMca):
 
     def menuToolsAboutToShow(self):
         if DEBUG:
-            print "menu ToolsAboutToShow"
+            print("menu ToolsAboutToShow")
         self.menuTools.clear()
         if QTVERSION < '4.0.0':
             if self.sourceFrame.isHidden():
@@ -1224,7 +1240,9 @@ class PyMca(PyMcaMdi.PyMca):
             if XIA_CORRECT:
                 self.menuTools.addAction("XIA Correct",
                                          self.__xiaCorrect)
-        if DEBUG:"print Fit to Specfile missing"
+        if DEBUG:
+            print("Fit to Specfile missing")
+            
     def fontdialog(self):
         fontd = qt.QFontDialog.getFont(self)
         if fontd[1]:
@@ -1233,7 +1251,7 @@ class PyMca(PyMcaMdi.PyMca):
 
     def toggleSource(self,**kw):
         if DEBUG:
-            print "toggleSource called"
+            print("toggleSource called")
         if self.sourceFrame.isHidden():
             self.sourceFrame.show()
             if QTVERSION < '4.0.0': self.sourceFrame.raiseW()
@@ -1364,7 +1382,10 @@ class PyMca(PyMcaMdi.PyMca):
                 fdialog = qt.QFileDialog(self)
                 fdialog.setModal(True)
                 fdialog.setWindowTitle(message)
-                strlist = qt.QStringList()
+                if hasattr(qt, "QStringList"):
+                    strlist = qt.QStringList()
+                else:
+                    strlist = []
                 for filetype in fileTypeList:
                     strlist.append(filetype.replace("(","").replace(")",""))
                 fdialog.setFilters(strlist)
@@ -1388,7 +1409,7 @@ class PyMca(PyMcaMdi.PyMca):
                         return [], filterused
                     else:
                         return []
-        filelist = map(str, filelist)
+        filelist = [str(x) for x in filelist]
         if getfilter:
             return filelist, filterused
         else:
@@ -1427,7 +1448,7 @@ class PyMca(PyMcaMdi.PyMca):
                 self.__imagingTool = None
                 msg = qt.QMessageBox(self)
                 msg.setIcon(qt.QMessageBox.Critical)
-                print "Error info = ",sys.exc_info()
+                print("Error info = ",sys.exc_info())
                 msg.setText("Unexpected Error: %s" % (sys.exc_info()[1]))
                 if QTVERSION < '4.0.0':
                     msg.exec_loop()
@@ -1444,9 +1465,9 @@ class PyMca(PyMcaMdi.PyMca):
     def customEvent(self, event):
         if hasattr(event, 'dict'):
             ddict = event.dict
-            if ddict.has_key('event'):
+            if 'event' in ddict:
                 if ddict['event'] == "closeEventSignal":
-                    if self._widgetDict.has_key(ddict['id']):
+                    if ddict['id'] in self._widgetDict:
                         if ddict['id'] == self.__imagingTool:
                             self.__imagingTool = None
                         del self._widgetDict[ddict['id']]
@@ -1587,7 +1608,7 @@ class PyMca(PyMcaMdi.PyMca):
 
     def openSource(self,index=0):
         if DEBUG:
-            print "index = ",index
+            print("index = %d " % index)
         if index <= 0:
             if QTVERSION < '4.0.0':
                 outfile = qt.QFileDialog(self,"Select PyMca Configuration File",1)
@@ -1633,18 +1654,18 @@ class PyMca(PyMcaMdi.PyMca):
         if self.menuBrowser is None:
             self.menuBrowser= qt.QTextBrowser()
             if QTVERSION < '4.0.0':
-                self.menuBrowser.setCaption(qt.QString("Main Menu Help"))
+                self.menuBrowser.setCaption(QString("Main Menu Help"))
             else:
-                self.menuBrowser.setWindowTitle(qt.QString("Main Menu Help"))
+                self.menuBrowser.setWindowTitle(QString("Main Menu Help"))
             dir=os.path.dirname(PyMcaMdi.__file__)
             if not os.path.exists(os.path.join(dir,"HTML","Menu.html")):
                 dir = os.path.dirname(dir)
             if QTVERSION < '4.0.0':
-                self.menuBrowser.mimeSourceFactory().addFilePath(qt.QString(dir+"/HTML"))
-                self.menuBrowser.setSource(qt.QString("Menu.html"))
+                self.menuBrowser.mimeSourceFactory().addFilePath(QString(dir+"/HTML"))
+                self.menuBrowser.setSource(QString("Menu.html"))
             else:
                 self.menuBrowser.setSearchPaths([os.path.join(dir,"HTML")])
-                self.menuBrowser.setSource(qt.QUrl(qt.QString("Menu.html")))
+                self.menuBrowser.setSource(qt.QUrl(QString("Menu.html")))
             self.menuBrowser.show()
         if self.menuBrowser.isHidden():self.menuBrowser.show()
         if QTVERSION < '4.0.0': self.menuBrowser.raiseW()
@@ -1654,18 +1675,18 @@ class PyMca(PyMcaMdi.PyMca):
         if self.displayBrowser is None:
             self.displayBrowser= qt.QTextBrowser()
             if QTVERSION < '4.0.0':
-                self.displayBrowser.setCaption(qt.QString("Data Display HOWTO"))
+                self.displayBrowser.setCaption(QString("Data Display HOWTO"))
             else:
-                self.displayBrowser.setWindowTitle(qt.QString("Data Display HOWTO"))                
+                self.displayBrowser.setWindowTitle(QString("Data Display HOWTO"))                
             dir=os.path.dirname(PyMcaMdi.__file__)
             if not os.path.exists(os.path.join(dir,"HTML","Display-HOWTO.html")):
                 dir = os.path.dirname(dir)
             if QTVERSION < '4.0.0':
-                self.displayBrowser.mimeSourceFactory().addFilePath(qt.QString(dir+"/HTML"))
-                self.displayBrowser.setSource(qt.QString("Display-HOWTO.html"))
+                self.displayBrowser.mimeSourceFactory().addFilePath(QString(dir+"/HTML"))
+                self.displayBrowser.setSource(QString("Display-HOWTO.html"))
             else:
                 self.displayBrowser.setSearchPaths([os.path.join(dir,"HTML")])
-                self.displayBrowser.setSource(qt.QUrl(qt.QString("Display-HOWTO.html")))
+                self.displayBrowser.setSource(qt.QUrl(QString("Display-HOWTO.html")))
             self.displayBrowser.show()
         if self.displayBrowser.isHidden():self.displayBrowser.show()
         if QTVERSION < '4.0.0':self.displayBrowser.raiseW()
@@ -1675,18 +1696,18 @@ class PyMca(PyMcaMdi.PyMca):
         if self.mcaBrowser is None:
             self.mcaBrowser= MyQTextBrowser()
             if QTVERSION < '4.0.0':
-                self.mcaBrowser.setCaption(qt.QString("MCA HOWTO"))
+                self.mcaBrowser.setCaption(QString("MCA HOWTO"))
             else:
-                self.mcaBrowser.setWindowTitle(qt.QString("MCA HOWTO"))
+                self.mcaBrowser.setWindowTitle(QString("MCA HOWTO"))
             dir=os.path.dirname(PyMcaMdi.__file__)
             if not os.path.exists(dir+"/HTML"+"/MCA-HOWTO.html"):
                 dir = os.path.dirname(dir)
             if QTVERSION < '4.0.0':
-                self.mcaBrowser.mimeSourceFactory().addFilePath(qt.QString(dir+"/HTML"))
-                self.mcaBrowser.setSource(qt.QString("MCA-HOWTO.html"))
+                self.mcaBrowser.mimeSourceFactory().addFilePath(QString(dir+"/HTML"))
+                self.mcaBrowser.setSource(QString("MCA-HOWTO.html"))
             else:
                 self.mcaBrowser.setSearchPaths([os.path.join(dir,"HTML")])
-                self.mcaBrowser.setSource(qt.QUrl(qt.QString("MCA-HOWTO.html")))
+                self.mcaBrowser.setSource(qt.QUrl(QString("MCA-HOWTO.html")))
                 #f = open(os.path.join(dir,"HTML","MCA-HOWTO.html"))
                 #self.mcaBrowser.setHtml(f.read())
                 #f.close()
@@ -1726,19 +1747,19 @@ class PyMca(PyMcaMdi.PyMca):
         self.changeLog.show()
     
     def onDebug(self):
-        print "Module name = ","PyMca",__revision__.replace("$","")
-        print "Module name = ","PyQt ",qt.PYQT_VERSION_STR
+        print("Module name PyMca ",__revision__.replace("$",""))
+        print("Module name PyQt  ",qt.PYQT_VERSION_STR)
         for module in sys.modules.values():
             try:
                 if 'Revision' in module.__revision__:
                     if module.__name__ != "__main__":
-                        print "Module name = ",module.__name__,module.__revision__.replace("$","")
+                        print("Module name = ",module.__name__,module.__revision__.replace("$",""))
             except:
                 pass 
     
     def onPrint(self):
         if DEBUG:
-            print "onPrint called"
+            print("onPrint called")
         if self.scanwindow.hasFocus():
             self.scanwindow.graph.printps() 
         else:
@@ -1799,7 +1820,7 @@ if 0:
             """
             Called after a graph is closed
             """
-            print "closeGraph", name
+            print("closeGraph", name)
 
     def __getGraphNames(self):
             return [ str(window.caption()) for window in self.mdi.windowList() ]
@@ -1814,7 +1835,7 @@ if 0:
 
 class MyQTextBrowser(qt.QTextBrowser):
     def  setSource(self,name):
-        if name == qt.QString("./PyMCA.html"):
+        if name == QString("./PyMCA.html"):
             if sys.platform == 'win32':
                 dir=os.path.dirname(PyMcaMdi.__file__)
                 if not os.path.exists(dir+"/HTML"+"/PyMCA.html"):
@@ -1826,9 +1847,9 @@ class MyQTextBrowser(qt.QTextBrowser):
                 self.report.show()
             except:
                 self.report = qt.QTextBrowser()
-                self.report.setCaption(qt.QString("PyMca Report"))
-                self.report.mimeSourceFactory().addFilePath(qt.QString(os.path.dirname(PyMcaMdi.__file__)+"/HTML"))
-                self.report.mimeSourceFactory().addFilePath(qt.QString(os.path.dirname(PyMcaMdi.__file__)+"/HTML/PyMCA_files"))
+                self.report.setCaption(QString("PyMca Report"))
+                self.report.mimeSourceFactory().addFilePath(QString(os.path.dirname(PyMcaMdi.__file__)+"/HTML"))
+                self.report.mimeSourceFactory().addFilePath(QString(os.path.dirname(PyMcaMdi.__file__)+"/HTML/PyMCA_files"))
                 self.report.setSource(name)
             if self.report.isHidden():self.report.show()
             self.report.raiseW()
@@ -1838,7 +1859,7 @@ class MyQTextBrowser(qt.QTextBrowser):
 class Line(qt.QFrame):
     def mouseDoubleClickEvent(self,event):
         if DEBUG:
-            print "Double Click Event"
+            print("Double Click Event")
         ddict={}
         ddict['event']="DoubleClick"
         ddict['data'] = event
@@ -1850,7 +1871,7 @@ class Line(qt.QFrame):
 class PixmapLabel(qt.QLabel):
     def mousePressEvent(self,event):
         if DEBUG:
-            print "Mouse Press Event"
+            print("Mouse Press Event")
         ddict={}
         ddict['event']="MousePress"
         ddict['data'] = event
@@ -1864,15 +1885,16 @@ if __name__ == '__main__':
     if PROFILING:
         import profile
         import pstats
-    demo = PyMca(**keywords)
+    PyMcaMainWidgetInstance = PyMca(**keywords)
     if nativeFileDialogs is not None:
         PyMcaDirs.nativeFileDialogs = nativeFileDialogs
-    if debugreport:demo.onDebug()
+    if debugreport:PyMcaMainWidgetInstance.onDebug()
     qt.QObject.connect(app, qt.SIGNAL("lastWindowClosed()"),
                             app,qt.SLOT("quit()"))
+            
     if QTVERSION < '4.0.0':
-        app.setMainWidget(demo)
-        demo.show()
+        app.setMainWidget(PyMcaMainWidgetInstance)
+        PyMcaMainWidgetInstance.show()
         # --- close waiting widget
         splash.close()
         if PROFILING:
@@ -1882,8 +1904,21 @@ if __name__ == '__main__':
         else:
             app.exec_loop()
     else:
-        splash.finish(demo)
-        demo.show()
+        splash.finish(PyMcaMainWidgetInstance)
+        PyMcaMainWidgetInstance.show()
+        #try to interpret rest of command line arguments as data sources
+        try:
+            for source in args:
+                PyMcaMainWidgetInstance.sourceWidget.sourceSelector.openSource(source)
+        except:
+            msg = qt.QMessageBox(PyMcaMainWidgetInstance)
+            msg.setIcon(qt.QMessageBox.Critical)
+            msg.setWindowTitle("Error opening data source")
+            msg.setText("Cannot open data source %s" % source)
+            msg.setInformativeText(str(sys.exc_info()[1]))
+            msg.setDetailedText(traceback.format_exc())
+            msg.exec_()
+                    
         if PROFILING:
             profile.run('sys.exit(app.exec_())',"test")
             p=pstats.Stats("test")
