@@ -1,5 +1,5 @@
 #/*##########################################################################
-# Copyright (C) 2004-2009 European Synchrotron Radiation Facility
+# Copyright (C) 2004-2010 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMCA X-ray Fluorescence Toolkit developed at
 # the ESRF by the Beamline Instrumentation Software Support (BLISS) group.
@@ -24,9 +24,12 @@
 # Please contact the ESRF industrial unit (industry@esrf.fr) if this license 
 # is a problem for you.
 #############################################################################*/
-#!/usr/bin/env python
 import sys, getopt, string
 import PyMcaQt as qt
+if hasattr(qt, "QString"):
+    QString = qt.QString
+else:
+    QString = str
     
 QTVERSION = qt.qVersion()
 
@@ -103,14 +106,14 @@ class PyMca(qt.QMainWindow):
         def createActions(self):
                 #fileopen
                 self.actionOpen = qt.QAction(self)
-                self.actionOpen.setText(qt.QString("&Open"))
+                self.actionOpen.setText(QString("&Open"))
                 self.actionOpen.setIcon(self.Icons["fileopen"])
                 self.actionOpen.setShortcut(qt.Qt.CTRL+qt.Qt.Key_O)
                 self.connect(self.actionOpen, qt.SIGNAL("triggered(bool)"),
                              self.onOpen)
                 #filesaveas
                 self.actionSaveAs = qt.QAction(self)
-                self.actionSaveAs.setText(qt.QString("&Save"))
+                self.actionSaveAs.setText(QString("&Save"))
                 self.actionSaveAs.setIcon(self.Icons["filesave"])
                 self.actionSaveAs.setShortcut(qt.Qt.CTRL+qt.Qt.Key_S)
                 self.connect(self.actionSaveAs, qt.SIGNAL("triggered(bool)"),
@@ -118,7 +121,7 @@ class PyMca(qt.QMainWindow):
 
                 #filesave
                 self.actionSave = qt.QAction(self)
-                self.actionSave.setText(qt.QString("Save &Defaults"))
+                self.actionSave.setText(QString("Save &Defaults"))
                 #self.actionSave.setIcon(self.Icons["filesave"])
                 #self.actionSave.setShortcut(qt.Qt.CTRL+qt.Qt.Key_S)
                 self.connect(self.actionSave, qt.SIGNAL("triggered(bool)"),
@@ -126,7 +129,7 @@ class PyMca(qt.QMainWindow):
 
                 #fileprint
                 self.actionPrint = qt.QAction(self)
-                self.actionPrint.setText(qt.QString("&Print"))
+                self.actionPrint.setText(QString("&Print"))
                 self.actionPrint.setIcon(self.Icons["fileprint"])
                 self.actionPrint.setShortcut(qt.Qt.CTRL+qt.Qt.Key_P)
                 self.connect(self.actionPrint, qt.SIGNAL("triggered(bool)"),
@@ -134,7 +137,7 @@ class PyMca(qt.QMainWindow):
 
                 #filequit
                 self.actionQuit = qt.QAction(self)
-                self.actionQuit.setText(qt.QString("&Quit"))
+                self.actionQuit.setText(QString("&Quit"))
                 #self.actionQuit.setIcon(self.Icons["fileprint"])
                 self.actionQuit.setShortcut(qt.Qt.CTRL+qt.Qt.Key_Q)
                 qt.QObject.connect(self.actionQuit,
@@ -157,11 +160,22 @@ class PyMca(qt.QMainWindow):
                 self.fileToolBar= qt.QToolBar(self, "filetoolbar")
                 self.fileToolBar.setLabel("File Operations")
                 self.onInitFileToolBar(self.fileToolBar)
-                fileOpen= qt.QToolButton(self.Icons["fileopen"], "Open", qt.QString.null, self.onOpen, self.fileToolBar, "open")
+                fileOpen= qt.QToolButton(self.Icons["fileopen"],
+                                         "Open",
+                                         QString(""),
+                                         self.onOpen,
+                                         self.fileToolBar, "open")
                 qt.QWhatsThis.add(fileOpen, HelpDict["fileopen"])
-                fileSave= qt.QToolButton(self.Icons["filesave"], "Save As", qt.QString.null, self.onSaveAs, self.fileToolBar, "save")
+                fileSave= qt.QToolButton(self.Icons["filesave"],
+                                         "Save As",
+                                         QString(""),
+                                         self.onSaveAs,
+                                         self.fileToolBar, "save")
                 qt.QWhatsThis.add(fileSave, HelpDict["filesave"])
-                filePrint= qt.QToolButton(self.Icons["fileprint"], "Print", qt.QString.null, self.onPrint, self.fileToolBar, "print")
+                filePrint= qt.QToolButton(self.Icons["fileprint"], "Print",
+                                          QString(""),
+                                          self.onPrint,
+                                          self.fileToolBar, "print")
                 qt.QWhatsThis.add(filePrint, HelpDict["fileprint"])
                 self.fileToolBar.addSeparator()
                 qt.QWhatsThis.whatsThisButton(self.fileToolBar)
@@ -179,11 +193,17 @@ class PyMca(qt.QMainWindow):
                     self.winToolBar= qt.QToolBar(self, "wintoolbar")
                     self.winToolBar.setLabel("Window resize")
                     self.onInitWinToolBar(self.winToolBar)
-                    FullScreen= qt.QToolButton(self.Icons["window_fullscreen"], "Full Screen", qt.QString.null,
-                                    self.windowFullScreen, self.winToolBar, "fullscreen")
+                    FullScreen= qt.QToolButton(self.Icons["window_fullscreen"],
+                                               "Full Screen",
+                                               QString(""),
+                                               self.windowFullScreen,
+                                               self.winToolBar, "fullscreen")
                     qt.QWhatsThis.add(FullScreen, HelpDict["fullscreen"])
-                    self.winToolButton= qt.QToolButton(self.Icons["window_nofullscreen"], "Tile",
-                                                    qt.QString.null, self.onWinToolAction, self.winToolBar, "wintile")
+                    self.winToolButton= qt.QToolButton(self.Icons["window_nofullscreen"],\
+                                                       "Tile",
+                                                       QString(""),
+                                                       self.onWinToolAction,
+                                                       self.winToolBar, "wintile")
                     qt.QWhatsThis.add(self.winToolButton, HelpDict["nofullscreen"])
                     self.winToolMenu= qt.QPopupMenu(self.winToolButton)
                     self.winToolMenu.setCheckable(1)
@@ -202,7 +222,7 @@ class PyMca(qt.QMainWindow):
 
     def onWinToolMenu(self, idx):
         if DEBUG:
-            print "onWinToolMenu ",idx
+            print("onWinToolMenu %d " % idx)
         for midx in self.winToolMenuIndex:
                 self.winToolMenu.setItemChecked(midx, midx==idx)
         act= self.winToolMenuIndex.index(idx)
@@ -220,57 +240,57 @@ class PyMca(qt.QMainWindow):
     # Mdi windows geometry
     #
     def windowCascade(self):
-            if self.followActiveWindow: self.__disconnectFollow()
-            self.mdi.cascade()
-            for window in self.mdi.windowList():
-                    window.resize(0.7*self.mdi.width(),0.7*self.mdi.height())
-            if self.followActiveWindow: self.__connectFollow()
+        if self.followActiveWindow: self.__disconnectFollow()
+        self.mdi.cascade()
+        for window in self.mdi.windowList():
+                window.resize(0.7*self.mdi.width(),0.7*self.mdi.height())
+        if self.followActiveWindow: self.__connectFollow()
 
     def windowTile(self):
-            if self.followActiveWindow: self.__disconnectFollow()
-            self.mdi.tile()
-            if self.followActiveWindow: self.__connectFollow()
+        if self.followActiveWindow: self.__disconnectFollow()
+        self.mdi.tile()
+        if self.followActiveWindow: self.__connectFollow()
 
     def windowHorizontal(self):
-            #if self.followActiveWindow: self.__disconnectFollow()
-            if not len(self.mdi.windowList()): return
-            windowheight=float(self.mdi.height())/len(self.mdi.windowList())
-            i=0
-            for window in self.mdi.windowList():
-                    window.parentWidget().showNormal()
-                    window.parentWidget().setGeometry(0, int(windowheight*i),
-                                            self.mdi.width(),int(windowheight))
-                    if QTVERSION < '4.0.0':
-                        window.parentWidget().raiseW()
-                    else:
-                        window.parentWidget().raise_()
-                    i+=1
-            self.mdi.update()
-            self.update()
-            #if self.followActiveWindow: self.__connectFollow()
+        #if self.followActiveWindow: self.__disconnectFollow()
+        if not len(self.mdi.windowList()): return
+        windowheight=float(self.mdi.height())/len(self.mdi.windowList())
+        i=0
+        for window in self.mdi.windowList():
+                window.parentWidget().showNormal()
+                window.parentWidget().setGeometry(0, int(windowheight*i),
+                                        self.mdi.width(),int(windowheight))
+                if QTVERSION < '4.0.0':
+                    window.parentWidget().raiseW()
+                else:
+                    window.parentWidget().raise_()
+                i+=1
+        self.mdi.update()
+        self.update()
+        #if self.followActiveWindow: self.__connectFollow()
 
     def windowVertical(self):
-            #if self.followActiveWindow: self.__disconnectFollow()
-            if not len(self.mdi.windowList()): return
-            windowwidth=float(self.mdi.width())/len(self.mdi.windowList())
-            i=0
-            for window in self.mdi.windowList():
-                    window.parentWidget().showNormal()
-                    window.parentWidget().setGeometry(int(windowwidth*i),0,
-                                            int(windowwidth),self.mdi.height())
-                    
-                    if QTVERSION < '4.0.0':
-                        window.parentWidget().raiseW()
-                    else:
-                        window.parentWidget().raise_()
-                    i+=1
-            self.mdi.update()
-            self.update()
-            #if self.followActiveWindow: self.__connectFollow()
+        #if self.followActiveWindow: self.__disconnectFollow()
+        if not len(self.mdi.windowList()): return
+        windowwidth=float(self.mdi.width())/len(self.mdi.windowList())
+        i=0
+        for window in self.mdi.windowList():
+                window.parentWidget().showNormal()
+                window.parentWidget().setGeometry(int(windowwidth*i),0,
+                                        int(windowwidth),self.mdi.height())
+                
+                if QTVERSION < '4.0.0':
+                    window.parentWidget().raiseW()
+                else:
+                    window.parentWidget().raise_()
+                i+=1
+        self.mdi.update()
+        self.update()
+        #if self.followActiveWindow: self.__connectFollow()
 
     def windowFullScreen(self):
-            if len(self.mdi.windowList()):
-                    self.mdi.activeWindow().showMaximized()
+        if len(self.mdi.windowList()):
+                self.mdi.activeWindow().showMaximized()
 
 
     def initMenuBar(self):
@@ -278,7 +298,7 @@ class PyMca(qt.QMainWindow):
             if QTVERSION < '4.0.0':
                 self.menuFile= qt.QPopupMenu(self.menuBar())
                 idx= self.menuFile.insertItem(self.Icons["fileopen"],
-                                              qt.QString("&Open"),
+                                              QString("&Open"),
                                               self.onOpen,
                                               qt.Qt.CTRL+qt.Qt.Key_O)
                 self.menuFile.setWhatsThis(idx, HelpDict["fileopen"])
@@ -356,7 +376,7 @@ class PyMca(qt.QMainWindow):
 
     def menuWindowAboutToShow(self):
         if DEBUG:
-            print "menuWindowAboutToShow"
+            print("menuWindowAboutToShow")
         self.menuWindow.clear()
         if len(self.mdi.windowList())==0: return
         if QTVERSION < '4.0.0':
@@ -381,7 +401,7 @@ class PyMca(qt.QMainWindow):
                         self.menuWindow.setItemChecked(idx, 1)
                     else:
                         if DEBUG:
-                            print "self.menuWindow.setItemChecked(idx, 1) equivalent missing"
+                            print("self.menuWindow.setItemChecked(idx, 1) equivalent missing")
         else:
             self.menuWindow.addAction("&Cascade", self.windowCascade)
             self.menuWindow.addAction("&Tile", self.windowTile)
@@ -402,7 +422,7 @@ class PyMca(qt.QMainWindow):
 
     def menuWindowActivated(self, idx = None):
         if DEBUG:
-            print "menuWindowActivated idx = ",idx
+            print("menuWindowActivated idx = ",idx)
         if idx is None:return
         if self.menuWindowMap[idx].isHidden():
             self.menuWindowMap[idx].show()
@@ -425,7 +445,7 @@ class PyMca(qt.QMainWindow):
                     self.followActiveWindow= follow
 
     def onWindowActivated(self, win):
-            print "Window activated"
+            print("Window activated")
             pass
 
     #
@@ -458,7 +478,7 @@ class PyMca(qt.QMainWindow):
 
     def menuToolsAboutToShow(self):
         if DEBUG:
-            print "menuToolsAboutToShow"
+            print("menuToolsAboutToShow")
         self.menuTools.clear()
         self.menuToolsMap= {}
         """
@@ -474,7 +494,7 @@ class PyMca(qt.QMainWindow):
 
     def menuToolsActivated(self, idx):
         if DEBUG:
-            print "menuToolsActivated idx = ",idx    
+            print("menuToolsActivated idx = ",idx)
         if self.menuTools.isItemChecked(idx):
             self.menuToolsMap[idx].hide()
         else:
@@ -537,8 +557,8 @@ def main(args):
                      sys.argv[1:],
                      options,
                      longoptions)
-    except getopt.error,msg:
-        print msg
+    except getopt.error:
+        print(sys.exc_info()[1])
         sys.exit(1)
     # --- waiting widget
     if QTVERSION < '4.0.0':
