@@ -1,5 +1,5 @@
 #/*##########################################################################
-# Copyright (C) 2004-2009 European Synchrotron Radiation Facility
+# Copyright (C) 2004-2011 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMCA X-ray Fluorescence Toolkit developed at
 # the ESRF by the Beamline Instrumentation Software Support (BLISS) group.
@@ -285,6 +285,72 @@ average16=[
 "                "
 ]
 
+horizontal=[
+"16 16 2 1",
+". c blue",
+"  c None",
+"                ",
+"                ",
+"                ",
+"                ",
+"                ",
+"                ",
+"                ",
+" .............. ",
+" .............. ",
+"                ",
+"                ",
+"                ",
+"                ",
+"                ",
+"                ",
+"                "
+]
+
+vertical=[
+"16 16 2 1",
+". c blue",
+"  c None",
+"                ",
+"       ..       ",
+"       ..       ",
+"       ..       ",
+"       ..       ",
+"       ..       ",
+"       ..       ",
+"       ..       ",
+"       ..       ",
+"       ..       ",
+"       ..       ",
+"       ..       ",
+"       ..       ",
+"       ..       ",
+"       ..       ",
+"                "
+]
+
+diagonal =[
+"16 16 2 1",
+". c blue",
+"  c None",
+"                ",
+" ..             ",
+"  ..            ",
+"   ..           ",
+"    ..          ",
+"     ..         ",
+"      ..        ",
+"       ..       ",
+"        ..      ",
+"         ..     ",
+"          ..    ",
+"           ..   ",
+"            ..  ",
+"             .. ",
+"              . ",
+"                "
+]
+
 # -------------------------
 sliderson=[
 "16 16 2 1",
@@ -3373,33 +3439,36 @@ IconDict= {
     "remove":remove,
     "additionalselect":additionalselect,
     "crop":crop,
-    "plugin":plugin
+    "plugin":plugin,
+    "horizontal":horizontal,
+    "vertical":vertical,
+    "diagonal":diagonal
 }
 
 def showIcons():
-	import sys
-	import PyMcaQt as qt
-	a= qt.QApplication(sys.argv)
-	a.connect(a, qt.SIGNAL("lastWindowClosed()"), a.quit)
-	w= qt.QWidget()
-	g= qt.QGridLayout(w)
+        import sys
+        import PyMcaQt as qt
+        a= qt.QApplication(sys.argv)
+        a.connect(a, qt.SIGNAL("lastWindowClosed()"), a.quit)
+        w= qt.QWidget()
+        g= qt.QGridLayout(w)
 
-	idx= 0
-	for name,icon in IconDict.items():
+        idx= 0
+        for name,icon in IconDict.items():
                 #print "name",name
-		lab= qt.QLabel(w)
-		lab.setText(str(name))
-		g.addWidget(lab, idx, 0)
-		lab= qt.QLabel(w)
-		lab.setPixmap(qt.QPixmap(icon))
-		g.addWidget(lab, idx, 1)
-		idx+= 1
+                lab= qt.QLabel(w)
+                lab.setText(str(name))
+                g.addWidget(lab, idx, 0)
+                lab= qt.QLabel(w)
+                lab.setPixmap(qt.QPixmap(icon))
+                g.addWidget(lab, idx, 1)
+                idx+= 1
 
-	w.show()
-	if qt.qVersion () < '4.0.0':
-        	a.exec_loop()
+        w.show()
+        if qt.qVersion () < '4.0.0':
+            a.exec_loop()
         else:
-                a.exec_()
+            a.exec_()
 
 if __name__=='__main__':
-	showIcons()
+        showIcons()
