@@ -1,5 +1,5 @@
 #/*##########################################################################
-# Copyright (C) 2004-2009 European Synchrotron Radiation Facility
+# Copyright (C) 2004-2011 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMCA X-ray Fluorescence Toolkit developed at
 # the ESRF by the Beamline Instrumentation Software Support (BLISS) group.
@@ -1179,7 +1179,7 @@ class PrintPreview(qt.QDialog):
         if self.printer != None:
             self.printer.setOutputFileName(name)
         else:
-            print "error setOutputFileName : a printer must be defined before"
+            print("error setOutputFileName : a printer must be defined before")
 
     def setPrintToFile(self, value):
         """
@@ -1188,7 +1188,7 @@ class PrintPreview(qt.QDialog):
         if self.printer != None:
             self.printer.setOutputToFile(value)
         else:
-            print "error setOutputToFile : a printer must be defined before"
+            print("error setOutputToFile : a printer must be defined before")
 
     def updatePrinter(self):
         """
@@ -1305,11 +1305,11 @@ def testPreview():
     import os.path
 
     if len(sys.argv) < 2:
-        print "give an image file as parameter please."
+        print("give an image file as parameter please.")
         sys.exit(1)
 
     if len(sys.argv) > 2:
-        print "only one parameter please."
+        print("only one parameter please.")
         sys.exit(1)
 
     filename = sys.argv[1]
