@@ -1,5 +1,5 @@
 #/*##########################################################################
-# Copyright (C) 2004-2009 European Synchrotron Radiation Facility
+# Copyright (C) 2004-2011 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMCA X-ray Fluorescence Toolkit developed at
 # the ESRF by the Beamline Instrumentation Software Support (BLISS) group.
@@ -48,10 +48,14 @@ class PyMcaPrintPreview(qt.QDialog):
         self.setWindowTitle(name)
         self.setModal(modal)
         self.resize(400, 500)
-
+        self.printDialog = None
         if printer is None:
             printer = qt.QPrinter(qt.QPrinter.HighResolution)
             printer.setPageSize(qt.QPrinter.A4)
+            printerName = "%s"  % printer.printerName()            
+            if printerName in ['id24b2u']:
+                #id24 printer very slow in color mode
+                printer.setColorMode(qt.QPrinter.GrayScale)
             printer.setFullPage(True)
             if (printer.width() <= 0) or (printer.height() <= 0):
                 if QTVERSION < '4.2.0':         #this is impossible (no QGraphicsView)
@@ -122,7 +126,7 @@ class PyMcaPrintPreview(qt.QDialog):
         if self.printer is not None:
             self.printer.setOutputFileName(name)
         else:
-            raise IOError, "setOutputFileName : a printer must be defined before"
+            raise IOError("setOutputFileName : a printer must be defined before")
 
     def _buildToolbar(self):
         # --- command buttons
@@ -218,12 +222,21 @@ class PyMcaPrintPreview(qt.QDialog):
     def __updateTargetLabel(self):
         if self.printer is None:
             self.targetLabel.setText("???")
-        elif len(self.printer.outputFileName()):
-            self.targetLabel.setText(qt.QString("File:").append(
-                self.printer.outputFileName()))
+            return
+        if hasattr(qt, "QString"):
+            if len(self.printer.outputFileName()):
+                self.targetLabel.setText(qt.QString("File:").append(
+                    self.printer.outputFileName()))
+            else:
+                self.targetLabel.setText(qt.QString("Printer:").append(
+                    self.printer.printerName()))
         else:
-            self.targetLabel.setText(qt.QString("Printer:").append(
-                self.printer.printerName()))
+            if len(self.printer.outputFileName()):
+                self.targetLabel.setText("File:"+\
+                    self.printer.outputFileName())
+            else:
+                self.targetLabel.setText("Printer:"+\
+                    self.printer.printerName())
 
     def __print(self):
         printer = self.printer
@@ -244,19 +257,22 @@ class PyMcaPrintPreview(qt.QDialog):
             return
 
     def __scaleChanged(self, value):
-        if DEBUG:print "current scale = ",   self._viewScale
+        if DEBUG:
+            print("current scale = ",   self._viewScale)
         if value > 2:
             self.view.scale(1.20, 1.20)
         else:
             self.view.scale(0.80, 0.80)
             
     def __zoomPlus(self):
-        if DEBUG:print "current scale = ",   self._viewScale
+        if DEBUG:
+            print("current scale = ",   self._viewScale)
         self._viewScale *= 1.20 
         self.view.scale(1.20, 1.20)
             
     def __zoomMinus(self):
-        if DEBUG:print "current scale = ",   self._viewScale
+        if DEBUG:
+            print("current scale = ",   self._viewScale)
         self._viewScale *= 0.80 
         self.view.scale(0.80, 0.80)
 
@@ -325,7 +341,10 @@ class PyMcaPrintPreview(qt.QDialog):
             x = 0.5 * pixmap.width() - offset
         commentItem.moveBy(x, pixmap.height()+20) 
         commentItem.setZValue(2)
-        
+
+        #I should adjust text size here
+        #textItem.scale(2,2)
+        #commentItem.scale(2,2)
         rectItem.scale(scale, scale)
         rectItem.moveBy(20 , 40)
 
@@ -333,14 +352,17 @@ class PyMcaPrintPreview(qt.QDialog):
     def __setup(self):
         """
         """
-        self.printer = qt.QPrinter()
-        printDialog = qt.QPrintDialog(self.printer, self)
-        if printDialog.exec_():
+        if self.printer is None:
+            self.printer = qt.QPrinter()
+        if self.printDialog is None:
+            self.printDialog = qt.QPrintDialog(self.printer, self)
+        if self.printDialog.exec_():
              self.printer.setFullPage(True)
              self.updatePrinter()
 
     def updatePrinter(self):
-        if DEBUG:print "UPDATE PRINTER"
+        if DEBUG:
+            print("UPDATE PRINTER")
         self.scene.setSceneRect(qt.QRectF(0,0, self.printer.width(), self.printer.height()))
         self.page.setPos(qt.QPointF(0.0, 0.0))
         self.page.setRect(qt.QRectF(0,0, self.printer.width(), self.printer.height()))
@@ -409,11 +431,13 @@ class GraphicsResizeRectItem(qt.QGraphicsRectItem):
         self.show()
 
     def mouseDoubleClickEvent(self, event):
-        if DEBUG:print "ResizeRect mouseDoubleClick"
+        if DEBUG:
+            print("ResizeRect mouseDoubleClick")
 
 
     def mousePressEvent(self, event):
-        if DEBUG:print "ResizeRect mousePress"
+        if DEBUG:
+            print("ResizeRect mousePress")
         if self._newRect is not None:
             self._newRect = None
         self.__point0 = self.pos()
@@ -433,7 +457,8 @@ class GraphicsResizeRectItem(qt.QGraphicsRectItem):
         qt.QGraphicsRectItem.mousePressEvent(self, event)
 
     def mouseMoveEvent(self, event):
-        if DEBUG:print "ResizeRect mouseMove"
+        if DEBUG:
+            print("ResizeRect mouseMove")
         point1 = self.pos()
         deltax = point1.x() -  self.__point0.x()
         deltay = point1.y() -  self.__point0.y()
@@ -458,7 +483,8 @@ class GraphicsResizeRectItem(qt.QGraphicsRectItem):
         qt.QGraphicsRectItem.mouseMoveEvent(self, event)
 
     def mouseReleaseEvent(self, event):
-        if DEBUG:print "ResizeRect mouseRelease"
+        if DEBUG:
+            print("ResizeRect mouseRelease")
         point1 = self.pos()
         deltax = point1.x() -  self.__point0.x()
         deltay = point1.y() -  self.__point0.y()
@@ -500,11 +526,11 @@ def testPreview():
     import os
 
     if len(sys.argv) < 2:
-        print "give an image file as parameter please."
+        print("give an image file as parameter please.")
         sys.exit(1)
 
     if len(sys.argv) > 2:
-        print "only one parameter please."
+        print("only one parameter please.")
         sys.exit(1)
 
     filename = sys.argv[1]
@@ -552,7 +578,6 @@ def testSimple():
 
 
     printer = qt.QPrinter(qt.QPrinter.HighResolution)
-    printer.setPageSize(qt.QPrinter.A4)
     printer.setFullPage(True)
     printer.setOutputFileName(os.path.splitext(filename)[0]+".ps")
 
