@@ -1,7 +1,7 @@
 #/*##########################################################################
-# Copyright (C) 2004-2010 European Synchrotron Radiation Facility
+# Copyright (C) 2004-2012 European Synchrotron Radiation Facility
 #
-# This file is part of the PyMCA X-ray Fluorescence Toolkit developed at
+# This file is part of the PyMca X-ray Fluorescence Toolkit developed at
 # the ESRF by the Beamline Instrumentation Software Support (BLISS) group.
 #
 # This toolkit is free software; you can redistribute it and/or modify it 
@@ -9,16 +9,16 @@
 # Software Foundation; either version 2 of the License, or (at your option) 
 # any later version.
 #
-# PyMCA is distributed in the hope that it will be useful, but WITHOUT ANY
+# PyMca is distributed in the hope that it will be useful, but WITHOUT ANY
 # WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 # FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 # details.
 #
 # You should have received a copy of the GNU General Public License along with
-# PyMCA; if not, write to the Free Software Foundation, Inc., 59 Temple Place,
+# PyMca; if not, write to the Free Software Foundation, Inc., 59 Temple Place,
 # Suite 330, Boston, MA 02111-1307, USA.
 #
-# PyMCA follows the dual licensing model of Trolltech's Qt and Riverbank's PyQt
+# PyMca follows the dual licensing model of Trolltech's Qt and Riverbank's PyQt
 # and cannot be used as a free plugin for a non-free program. 
 #
 # Please contact the ESRF industrial unit (industry@esrf.fr) if this license 
@@ -28,6 +28,11 @@ import os
 import sys
 import PyQt4.QtCore as QtCore
 import PyQt4.QtGui as QtGui
+if hasattr(QtCore, 'QString'):
+    QString = QtCore.QString
+else:
+    QString = str
+
 import h5py
 import HDF5Widget
 import HDF5Info
@@ -126,16 +131,16 @@ class QNexusWidget(QtGui.QWidget):
         self.cntTable.setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
 
         self._cntTableMenu = QtGui.QMenu(self)
-        self._cntTableMenu.addAction(QtCore.QString("Load"),
+        self._cntTableMenu.addAction(QString("Load"),
                                     self._loadCounterTableConfiguration)
-        self._cntTableMenu.addAction(QtCore.QString("Merge"),
+        self._cntTableMenu.addAction(QString("Merge"),
                                     self._mergeCounterTableConfiguration)
-        self._cntTableMenu.addAction(QtCore.QString("Save"),
+        self._cntTableMenu.addAction(QString("Save"),
                                     self._saveCounterTableConfiguration)
         self._cntTableMenu.addSeparator()
-        self._cntTableMenu.addAction(QtCore.QString("Delete All"),
+        self._cntTableMenu.addAction(QString("Delete All"),
                                     self._deleteAllCountersFromTable)
-        self._cntTableMenu.addAction(QtCore.QString("Delete Selected"),
+        self._cntTableMenu.addAction(QString("Delete Selected"),
                                     self._deleteSelectedCountersFromTable)
 
     def _counterTableCustomMenuSlot(self, qpoint):
@@ -339,11 +344,12 @@ class QNexusWidget(QtGui.QWidget):
             self.hdf5Widget.collapseAll()
             self.hdf5Widget.setModel(self._defaultModel)
             return
-        def dataSourceDistroyed(weakrefReference):
+        def dataSourceDestroyed(weakrefReference):
             idx = self._dataSourceList.index(weakrefReference)
             del self._dataSourceList[idx]
             del self._modelDict[weakrefReference]
-        ref = weakref.ref(dataSource, dataSourceDistroyed)
+            return
+        ref = weakref.ref(dataSource, dataSourceDestroyed)
         if ref not in self._dataSourceList:
             self._dataSourceList.append(ref)
             self._modelDict[ref] = HDF5Widget.FileModel()
@@ -357,8 +363,19 @@ class QNexusWidget(QtGui.QWidget):
 
     def showInfoWidget(self, filename, name, dset=False):
         self._checkWidgetDict()
-        fileIndex = self.data.sourceName.index(filename)
-        phynxFile  = self.data._sourceObjectList[fileIndex]
+        #this solution seems more robust
+        if 1:
+            useInstance = True
+        else:
+            if h5py.version.version < '2.0':
+                useInstance = True
+            else:
+                useInstance = False
+        if useInstance:
+            fileIndex = self.data.sourceName.index(filename)
+            phynxFile  = self.data._sourceObjectList[fileIndex]
+        else:
+            phynxFile  = h5py.File(filename, 'r')
         info = self.getInfo(phynxFile, name)
         widget = HDF5Info.HDF5InfoWidget()
         widget.notifyCloseEventToWidget(self)
@@ -375,16 +392,26 @@ class QNexusWidget(QtGui.QWidget):
                 pass
         self._lastWidgetId = wid
         self._widgetDict[wid] = widget
+        if useInstance:
+            def sourceObjectDestroyed(weakrefReference):
+                if wid == self._lastWidgetId:
+                    self._latWidgetId = None
+                if wid in self._widgetDict:
+                    del self._widgetDict[wid]
+            widget._sourceObjectWeakReference = weakref.ref(phynxFile,
+                                                 sourceObjectDestroyed)
         widget.setInfoDict(info)
         if dset:
             dataset = phynxFile[name]
             if isinstance(dataset, h5py.Dataset):
-                widget.w = HDF5DatasetTable.HDF5DatasetTable(widget)
-                try:
-                    widget.w.setDataset(dataset)
-                except:
-                    print "Error filling table"
-                widget.addTab(widget.w, 'TableView')
+                if len(dataset.shape):
+                    #0 length datasets do not need a table
+                    widget.w = HDF5DatasetTable.HDF5DatasetTable(widget)
+                    try:
+                        widget.w.setDataset(dataset)
+                    except:
+                        print("Error filling table")
+                    widget.addTab(widget.w, 'TableView')
         widget.show()
         return widget
 
@@ -405,17 +432,17 @@ class QNexusWidget(QtGui.QWidget):
         else:
             #handle a right click on a numeric dataset
             _hdf5WidgetDatasetMenu = QtGui.QMenu(self)
-            _hdf5WidgetDatasetMenu.addAction(QtCore.QString("Add to selection table"),
+            _hdf5WidgetDatasetMenu.addAction(QString("Add to selection table"),
                                         self._addToSelectionTable)
 
             if 0:
                 #these two options can be combined into one for the time being
-                _hdf5WidgetDatasetMenu.addAction(QtCore.QString("Open"),
+                _hdf5WidgetDatasetMenu.addAction(QString("Open"),
                                             self._openDataset)
-                _hdf5WidgetDatasetMenu.addAction(QtCore.QString("Show Properties"),
+                _hdf5WidgetDatasetMenu.addAction(QString("Show Properties"),
                                             self._showDatasetProperties)
             else:
-                _hdf5WidgetDatasetMenu.addAction(QtCore.QString("Show Information"),
+                _hdf5WidgetDatasetMenu.addAction(QString("Show Information"),
                                         self._showInfoWidgetSlot)
                 self._lastDatasetDict= ddict
                 _hdf5WidgetDatasetMenu.exec_(QtGui.QCursor.pos())
@@ -487,7 +514,7 @@ class QNexusWidget(QtGui.QWidget):
         if ddict['event'] == "itemDoubleClicked":
             if ddict['type'] in ['Dataset']:
                 if ddict['dtype'].startswith('|S'):
-                    print "string"
+                    print("string")
                 else:
                     root = ddict['name'].split('/')
                     root = "/" + root[1]
@@ -503,7 +530,7 @@ class QNexusWidget(QtGui.QWidget):
                         else:
                             self._aliasList.append(cnt)
                         self.cntTable.build(self._cntList, self._aliasList)
-            elif ddict['type'] == 'Entry':
+            elif ddict['type'] in ['NXentry', 'Entry']:
                 if self._lastAction is None:
                     return
                 action, selectionType = self._lastAction.split()
@@ -524,7 +551,7 @@ class QNexusWidget(QtGui.QWidget):
                         cnt  = ddict['name'].split(root)[-1]
                         if cnt not in self._cntList:
                             if DEBUG:
-                                print "USING SECOND WAY"
+                                print("USING SECOND WAY")
                             self._cntList.append(cnt)
                             basename = posixpath.basename(cnt)
                             if basename not in self._aliasList:
@@ -534,13 +561,13 @@ class QNexusWidget(QtGui.QWidget):
                             self.cntTable.build(self._cntList, self._aliasList)
                         return
                 if DEBUG:
-                    print "Unhandled item type:", ddict['dtype']
+                    print("Unhandled item type: %s" % ddict['dtype'])
 
     def buttonsSlot(self, ddict):
         if self.data is None:
             return
         action, selectionType = ddict['action'].split()
-        entryList = self.getEntryList()
+        entryList = self.getSelectedEntries()
         if not len(entryList):
             return
         cntSelection = self.cntTable.getCounterSelection()
@@ -558,10 +585,10 @@ class QNexusWidget(QtGui.QWidget):
                 sel['SourceType'] = "HDF5"
                 fileIndex = self.data.sourceName.index(filename)
                 phynxFile  = self.data._sourceObjectList[fileIndex]
-                entryIndex = phynxFile["/"].keys().index(entry[1:])
+                entryIndex = list(phynxFile["/"].keys()).index(entry[1:])
                 sel['Key']        = "%d.%d" % (fileIndex+1, entryIndex+1)
                 sel['legend']     = os.path.basename(sel['SourceName'][0])+\
-                                    " " + sel['Key']
+                                    " " + posixpath.basename(entry) #it was sel['Key']
                 sel['selection'] = {}
                 sel['selection']['sourcename'] = filename
                 #deal with the case the "entry" is a dataset hunging at root level
@@ -614,7 +641,7 @@ class QNexusWidget(QtGui.QWidget):
             if action.upper() == "REPLACE":
                 self.emit(QtCore.SIGNAL("replaceSelection"), selectionList)
 
-    def getEntryList(self):
+    def getSelectedEntries(self):
         return self.hdf5Widget.getSelectedEntries()
 
     def closeEvent(self, event):
@@ -633,13 +660,13 @@ class QNexusWidget(QtGui.QWidget):
     def customEvent(self, event):
         if hasattr(event, 'dict'):
             ddict = event.dict
-            if ddict.has_key('event'):
+            if 'event' in ddict:
                 if ddict['event'] == "closeEventSignal":
-                    if self._widgetDict.has_key(ddict['id']):
+                    if ddict['id'] in self._widgetDict:
                         if DEBUG:
                             try:
                                 widget = self._widgetDict[ddict['id']] 
-                                print "DELETING ", widget.windowTitle()
+                                print("DELETING %s" % widget.windowTitle())
                             except:
                                 pass
                         del self._widgetDict[ddict['id']]
@@ -659,11 +686,11 @@ if __name__ == "__main__":
         dataSource = NexusDataSource.NexusDataSource(sys.argv[1:])
         w.setDataSource(dataSource)
     def addSelection(sel):
-        print sel
+        print(sel)
     def removeSelection(sel):
-        print sel
+        print(sel)
     def replaceSelection(sel):
-        print sel
+        print(sel)
     w.show()
     QtCore.QObject.connect(w, QtCore.SIGNAL("addSelection"),     addSelection)
     QtCore.QObject.connect(w, QtCore.SIGNAL("removeSelection"),  removeSelection)
