@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 #/*##########################################################################
-# Copyright (C) 2004-2010 European Synchrotron Radiation Facility
+# Copyright (C) 2004-2011 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMCA X-ray Fluorescence Toolkit developed at
 # the ESRF by the Beamline Instrumentation Software Support (BLISS) group.
@@ -209,7 +209,10 @@ class SaveImageSetup(qt.QWidget):
             self.lastOutputDir = PyMcaDirs.outputDir
 
         outfile.setWindowTitle("Output File Selection")
-        strlist = qt.QStringList()
+        if hasattr(qt, "QStringList"):
+            strlist = qt.QStringList()
+        else:
+            strlist = []
         format_list = []
         format_list.append('Graphics PNG *.png')
         format_list.append('Graphics EPS *.eps')
@@ -230,7 +233,7 @@ class SaveImageSetup(qt.QWidget):
             try:
                 outstr=str(outfile.selectedFiles()[0])
             except UnicodeError:
-                print "WARNING: Unsupported characters in file name, trying workaround"
+                print("WARNING: Unsupported characters in file name, trying workaround")
                 try:
                     outstr = str(outfile.selectedFiles()[0].toLocal8Bit())
                 except:
@@ -276,9 +279,10 @@ class SaveImageSetup(qt.QWidget):
             self.imageWidget.print_figure(finalFile,
                                           edgecolor='w',
                                           facecolor='w',
-                                          format=finalFile[-3:])
+                                          format=finalFile[-3:],
+                                          dpi=self.imageWidget.config['outputdpi'])
         except:
-            print "WARNING: trying to save using obsolete method"
+            print("WARNING: trying to save using obsolete method")
             config = self.imageWidget.getParameters()
             try:
                 s=PyMcaMatplotlibSave.PyMcaMatplotlibSaveImage(self.imageWidget.imageData)
@@ -340,7 +344,8 @@ class RightWidget(qt.QWidget):
                         'Zoom Y Min',
                         'Zoom Y Max',
                         'Value Min',
-                        'Value Max']
+                        'Value Max',
+                        'Output dpi']
         self.keyList = []
         for label in self.labelList:
             self.keyList.append(label.lower().replace(' ','').replace('/',""))
@@ -398,15 +403,19 @@ class RightWidget(qt.QWidget):
                     tip += "limits to the same value."
                     line.setToolTip(tip)
                     line.setText('0.0')
+                elif 'Output dpi' in self.labelList[i]:
+                    tip  = "=Output file resolution."
+                    line.setToolTip(tip)
+                    line.setText("%d" % 100)
                 else:
                     line.setText('1.0')
             self.gridLayout.addWidget(label, i, 0)
             self.gridLayout.addWidget(line, i, 1)
             self.comboBoxList.append(line)
 
-	self.mainLayout.addWidget(self.gridWidget)
-	self.mainLayout.addWidget(VerticalSpacer(self))
-	self.setPixmapMode(False)
+        self.mainLayout.addWidget(self.gridWidget)
+        self.mainLayout.addWidget(VerticalSpacer(self))
+        self.setPixmapMode(False)
 
     def setPixmapMode(self, flag):
         if flag:
@@ -424,21 +433,24 @@ class RightWidget(qt.QWidget):
                 self.comboBoxList[index].setEnabled(True)
 
     def getParameters(self):
-	ddict = {}
-	i = 0
-	for label in self.keyList:
+        ddict = {}
+        i = 0
+        for label in self.keyList:
             if i > self.labelList.index('Image Background'):
                 text = str(self.comboBoxList[i].text())
                 if len(text):
-                    ddict[label] = float(text)
+                    if label == 'Output dpi':
+                        ddict[label] = int(text)
+                    else:
+                        ddict[label] = float(text)
                 else:
                     ddict[label] = None
             else:
                 ddict[label] = str(self.comboBoxList[i].currentText()).lower()
-	    if (ddict[label] == 'none') or (ddict[label] == 'default'):
-		ddict[label] = None
-	    i = i + 1
-	return ddict
+            if (ddict[label] == 'none') or (ddict[label] == 'default'):
+                ddict[label] = None
+            i = i + 1
+        return ddict
 
     def setParameters(self, ddict):
         for label in ddict.keys():
@@ -446,9 +458,19 @@ class RightWidget(qt.QWidget):
                 i = self.keyList.index(label)
                 if i > self.labelList.index('Image Background'):
                     if ddict[label] is not None:
-                        self.comboBoxList[i].setText("%f" % ddict[label])
+                        if label == 'Output dpi':
+                            self.comboBoxList[i].setText("%d" % int(ddict[label]))
+                        else:
+                            self.comboBoxList[i].setText("%f" % ddict[label])
                 else:
-                    self.comboBoxList[i].setCurrentText(ddict[label])
+                    txt = ddict[label]
+                    if ddict[label] is not None:
+                        try:
+                            txt = ddict[label][0].upper() +\
+                                  ddict[label][1:].lower()
+                        except:
+                            pass
+                    self.comboBoxList[i].setCurrentText(txt)
         return
 	
 class MyLineEdit(qt.QLineEdit):
@@ -524,7 +546,8 @@ class QPyMcaMatplotlibImage(FigureCanvas):
                      'valuemax':None,
                      'xlimits':xlimits,
                      'ylimits':ylimits,
-                     'vlimits':vlimits}
+                     'vlimits':vlimits,
+                     'outputdpi':dpi}
 
         #generate own colormaps
         cdict = {'red': ((0.0, 0.0, 0.0),
