@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 #/*##########################################################################
-# Copyright (C) 2004-2010 European Synchrotron Radiation Facility
+# Copyright (C) 2004-2011 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMCA X-ray Fluorescence Toolkit developed at
 # the ESRF by the Beamline Instrumentation Software Support (BLISS) group.
@@ -84,7 +84,7 @@ class HorizontalSpacer(qt.QWidget):
 class MatplotlibCurveTable(qt.QTableWidget):
     def __init__(self, parent=None):
         qt.QTableWidget.__init__(self, parent)
-        labels = ["Curve", "Alias", "Color", "Line Style"]
+        labels = ["Curve", "Alias", "Color", "Line Style", "Line Symbol"]
         n = len(labels)
         self.setColumnCount(len(labels))
         for i in range(len(labels)):
@@ -169,7 +169,7 @@ class MatplotlibCurveTable(qt.QTableWidget):
         #linestyle
         j = 3
         widget = self.cellWidget(i, j)
-        options = ['-','--','-.',':']
+        options = ['-','--','-.',':','']
         if widget is None:
             widget = ComboBoxItem(self, i, j, options=options)
             self.setCellWidget(i, j, widget)
@@ -180,6 +180,21 @@ class MatplotlibCurveTable(qt.QTableWidget):
         idx = widget.findText(ddict['linestyle'])
         widget.setCurrentIndex(idx)
 
+        #line marker
+        j = 4
+        widget = self.cellWidget(i, j)
+        options = ['','o','+','x','^']
+        if widget is None:
+            widget = ComboBoxItem(self, i, j, options=options)
+            self.setCellWidget(i, j, widget)
+            qt.QObject.connect(widget,
+                               qt.SIGNAL('ComboBoxItemSignal'),
+                               self._mySlot)
+
+        idx = widget.findText(ddict['linemarker'])
+        widget.setCurrentIndex(idx)
+
+
     def _mySlot(self, ddict):
         #if self.__disconnect:
         #    return
@@ -204,6 +219,9 @@ class MatplotlibCurveTable(qt.QTableWidget):
             widget = self.cellWidget(i, 3)
             linestyle = str(widget.currentText())
             ddict['curvedict'][legend]['linestyle'] = linestyle
+            widget = self.cellWidget(i, 4)
+            linemarker = str(widget.currentText())
+            ddict['curvedict'][legend]['linemarker'] = linemarker
         self.emit(qt.SIGNAL("CurveTableSignal"), ddict)
 
 class ComboBoxItem(qt.QComboBox):
@@ -247,6 +265,23 @@ class QPyMcaMatplotlibSaveDialog(qt.QDialog):
         self.mainLayout.setMargin(0)
         self.mainLayout.setSpacing(0)
         self._lastGoodSize = None
+
+        self.axesLabelsWidget = qt.QWidget(self)
+        layout = qt.QHBoxLayout(self.axesLabelsWidget)
+        layout.setMargin(0)
+        layout.setSpacing(2)
+        xLabelLabel = qt.QLabel(self.axesLabelsWidget)
+        xLabelLabel.setText("X Axis Label: ")
+        self.xLabelLine = qt.QLineEdit(self.axesLabelsWidget)
+        yLabelLabel = qt.QLabel(self.axesLabelsWidget)
+        yLabelLabel.setText("Y Axis Label: ")
+        self.yLabelLine = qt.QLineEdit(self.axesLabelsWidget)
+        layout.addWidget(xLabelLabel)
+        layout.addWidget(self.xLabelLine)
+        layout.addWidget(yLabelLabel)
+        layout.addWidget(self.yLabelLine)
+
+
         self.curveTable = MatplotlibCurveTable(self)
         self.plot = QPyMcaMatplotlibSave(self, **kw)
         self.plot.setCurveTable(self.curveTable)
@@ -270,19 +305,31 @@ class QPyMcaMatplotlibSaveDialog(qt.QDialog):
         layout.addWidget(self.dismissButton)
         horizontal = False
         if horizontal:
-            self.mainLayout.addWidget(self.plot, 0, 0)
-            self.mainLayout.addWidget(self.curveTable, 0, 1)
-            self.mainLayout.addWidget(self.actionsWidget, 1, 0, 1, 2)
+            self.mainLayout.addWidget(self.axesLabelsWidget, 0, 0)
+            self.mainLayout.addWidget(self.plot, 1, 0)
+            self.mainLayout.addWidget(self.curveTable, 1, 1)
+            self.mainLayout.addWidget(self.actionsWidget, 2, 0, 1, 2)
             self.mainLayout.setColumnStretch(0, 1)
         else:
-            self.mainLayout.addWidget(self.curveTable, 0, 0)
-            self.mainLayout.addWidget(self.plot, 1, 0)
-            self.mainLayout.addWidget(self.actionsWidget, 2, 0)
+            self.mainLayout.addWidget(self.axesLabelsWidget, 0, 0)
+            self.mainLayout.addWidget(self.curveTable, 1, 0)
+            self.mainLayout.addWidget(self.plot, 2, 0)
+            self.mainLayout.addWidget(self.actionsWidget, 3, 0)
             self.mainLayout.setRowStretch(1, 1)
 
+        self.connect(self.xLabelLine,
+                     qt.SIGNAL("editingFinished()"),
+                     self._xLabelSlot)
+        
+        self.connect(self.yLabelLine,
+                     qt.SIGNAL("editingFinished()"),
+                     self._yLabelSlot)
+
+
         self.connect(self.acceptButton,
                      qt.SIGNAL("clicked()"),
                      self.accept)
+        
         self.connect(self.dismissButton,
                      qt.SIGNAL("clicked()"),
                      self.reject)
@@ -300,6 +347,27 @@ class QPyMcaMatplotlibSaveDialog(qt.QDialog):
         self._lastGoodSize = self.size()
         return qt.QDialog.accept(self)
 
+    def _xLabelSlot(self):
+        label = self.xLabelLine.text()
+        if sys.version < '3.0':
+            label = str(label)
+        self.plot.setXLabel(label)
+        self.plot.draw()
+
+    def _yLabelSlot(self):
+        label = self.yLabelLine.text()
+        if sys.version < '3.0':
+            label = str(label)
+        self.plot.setYLabel(label)
+        self.plot.draw()
+
+    def setXLabel(self, label):
+        self.xLabelLine.setText(label)
+        self.plot.setXLabel(label)
+
+    def setYLabel(self, label):
+        self.yLabelLine.setText(label)
+        self.plot.setYLabel(label)
 
 class QPyMcaMatplotlibSave(FigureCanvas):
     def __init__(self, parent=None,
@@ -432,6 +500,7 @@ class QPyMcaMatplotlibSave(FigureCanvas):
                       color = None,
                       linewidth = None,
                       linestyle = None,
+                      marker=None,
                       alias = None,**kw):
         if self.limitsSet is not None:
             n = self._filterData(x, y)
@@ -443,7 +512,7 @@ class QPyMcaMatplotlibSave(FigureCanvas):
         if n == 0:
             #nothing to plot
             if DEBUG:
-                print "nothing to plot"
+                print("nothing to plot")
             return
         
         style = None
@@ -454,7 +523,8 @@ class QPyMcaMatplotlibSave(FigureCanvas):
                 style = '-'
         else:
             style = linestyle
-
+        if marker is None:
+            marker = ''
         if linewidth is None:linewidth = 1.0
         self._axFunction( x, y, linestyle = style, color=color, linewidth = linewidth, **kw)
         self._dataCounter += 1
@@ -470,6 +540,7 @@ class QPyMcaMatplotlibSave(FigureCanvas):
         self.curveDict[legend]['linestyle'] = style
         self.curveDict[legend]['color'] = color
         self.curveDict[legend]['linewidth'] = linewidth
+        self.curveDict[legend]['linemarker'] = marker
         if alias is not None:
             self.curveDict[legend]['alias'] = alias
             self._legendList[-1] = alias
@@ -564,8 +635,14 @@ class QPyMcaMatplotlibSave(FigureCanvas):
                 color = ddict['curvedict'][legend]['color']
             linewidth = self.curveDict[legend]['linewidth']
             linestyle = ddict['curvedict'][legend]['linestyle']
+            linemarker = ddict['curvedict'][legend]['linemarker']
+            if linestyle in ['None', '']:
+                linestyle = ''
+            if linemarker in ['None', '']:
+                linemarker = ''
             self._axFunction( x, y,
                               linestyle=linestyle,
+                              marker=linemarker,
                               color=color,
                               linewidth=linewidth)
             legendList.append(alias)
@@ -603,15 +680,15 @@ if __name__ == "__main__":
         n = 14
     for i in range(n):
         y = x * i
-        w.addDataToPlot(x,y, legend="%d" % i)
+        w.addDataToPlot(x, y, legend="%d" % i)
     #w.setTitle('title')
-    w.setXLabel('Channel')
-    w.setYLabel('Counts')
+    w0.setXLabel('Channel')
+    w0.setYLabel('Counts')
     w.plotLegends()
     ret = w0.exec_()
     if ret:
         w.saveFile("filename.png")
-        print "Plot filename.png saved"
+        print("Plot filename.png saved")
     w.setParameters({'logy':True, 'bw':True})
     for i in range(n):
         y = x * i + 1
