@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 #/*##########################################################################
-# Copyright (C) 2004-2010 European Synchrotron Radiation Facility
+# Copyright (C) 2004-2012 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMCA X-ray Fluorescence Toolkit developed at
 # the ESRF by the Beamline Instrumentation Software Support (BLISS) group.
@@ -26,10 +26,16 @@
 # is a problem for you.
 #############################################################################*/
 import sys
+import os
+import traceback
 import numpy
 import weakref
 
 from PyMca import PyMcaQt as qt
+if hasattr(qt, "QString"):
+    QString = qt.QString
+else:
+    QString = str
 from PyMca import DataObject
 from PyMca import McaWindow
 from PyMca import StackBase
@@ -98,27 +104,33 @@ class QStackWidget(StackBase.StackBase,
         self.stackWindow.mainLayout.setMargin(0)
         self.stackWindow.mainLayout.setSpacing(0)
 
-        if HDF5:
+        #if HDF5:
+        if 1:
             self.stackWidget = MaskImageWidget.MaskImageWidget(self.stackWindow,
                                                         selection=False,
                                                         standalonesave=False,
                                                         imageicons=False)
             self._stackSaveMenu = qt.QMenu()
-            self._stackSaveMenu.addAction(qt.QString("Stack as Spectra"),
+            if HDF5:
+                self._stackSaveMenu.addAction(QString("Save Zoomed Stack Region as Spectra"),
                                                  self.saveStackAsNeXusSpectra)
-            self._stackSaveMenu.addAction(qt.QString("Stack as Images"),
+                self._stackSaveMenu.addAction(QString("Save Zoomed Stack Region as Images"),
                                                  self.saveStackAsNeXusImages)
-            self._stackSaveMenu.addAction(qt.QString("Stack as Float32 Spectra"),
+                self._stackSaveMenu.addAction(QString("Save Zoomed Stack Region as Float32 Spectra"),
                                                  self.saveStackAsFloat32NeXusSpectra)
-            self._stackSaveMenu.addAction(qt.QString("Stack as Float64 Spectra"),
+                self._stackSaveMenu.addAction(QString("Save Zoomed Stack Region as Float64 Spectra"),
                                                  self.saveStackAsFloat64NeXusSpectra)
-            self._stackSaveMenu.addAction(qt.QString("Stack as Float32 Images"),
+                self._stackSaveMenu.addAction(QString("Save Zoomed Stack Region as Float32 Images"),
                                                  self.saveStackAsFloat32NeXusImages)
-            self._stackSaveMenu.addAction(qt.QString("Stack as Float64 Images"),
+                self._stackSaveMenu.addAction(QString("Save Zoomed Stack Region as Float64 Images"),
                                                  self.saveStackAsFloat64NeXusImages)
-            self._stackSaveMenu.addAction(qt.QString("Stack as HDF5 /data"),
+                self._stackSaveMenu.addAction(QString("Save Zoomed Stack Region as HDF5 /data"),
                                                  self.saveStackAsSimplestHDF5)
-            self._stackSaveMenu.addAction(qt.QString("Standard Graphics"),
+            self._stackSaveMenu.addAction(QString("Save Zoomed Stack Region as Monochromatic TIFF Images"),
+                                                 self.saveStackAsMonochromaticTiffImages)
+            self._stackSaveMenu.addAction(QString("Save Zoomed Stack Region as Float32 TIFF Images"),
+                                                 self.saveStackAsFloat32TiffImages)
+            self._stackSaveMenu.addAction(QString("Standard Graphics"),
                                 self.stackWidget.graphWidget._saveIconSignal)
             self.connect(self.stackWidget.graphWidget.saveToolButton,
                          qt.SIGNAL("clicked()"), 
@@ -140,7 +152,8 @@ class QStackWidget(StackBase.StackBase,
                                                          selection=True,
                                                          colormap=True,
                                                          imageicons=True,
-                                                         standalonesave=standaloneSaving)
+                                                         standalonesave=standaloneSaving,
+                                                         profileselection=True)
         infotext  = 'Toggle background subtraction from current image\n'
         infotext += 'subtracting a straight line between the ROI limits.'
         self.roiBackgroundIcon = qt.QIcon(qt.QPixmap(IconDict["subtract"]))  
@@ -221,8 +234,11 @@ class QStackWidget(StackBase.StackBase,
         if self.roiBackgroundButton.isChecked():
             self.roiWidget.setImageData(self._ROIImageList[0]-\
                                         self._ROIImageList[-1])
+            self.roiWidget.graphWidget.graph.setTitle(self._ROIImageNames[0]+\
+                                                      " Net")
         else:
             self.roiWidget.setImageData(self._ROIImageList[0])
+            self.roiWidget.graphWidget.graph.setTitle(self._ROIImageNames[0])
 
     def _stackSaveToolButtonSignal(self):
         self._stackSaveMenu.exec_(self.cursor().pos())
@@ -246,19 +262,74 @@ class QStackWidget(StackBase.StackBase,
                     msg.exec_()
         return ""
 
+    def _getOutputTiffFilename(self):
+        fileTypes = "TIFF Files (*.tif *.tiff *.TIF *.TIFF)"
+        message = "Enter output filename"
+        wdir = PyMcaDirs.outputDir
+        filename = qt.QFileDialog.getSaveFileName(self, message, wdir, fileTypes)
+        if len(filename):
+            try:
+                return str(filename)
+            except UnicodeEncodeError:
+                if 0:
+                    return str(unicode(filename).encode('utf-8'))
+                else:
+                    msg = qt.QMessageBox(self)
+                    msg.setWindowTitle("Encoding error")
+                    msg.setIcon(qt.QMessageBox.Critical)
+                    msg.setText("Please use ASCII characters in file name and path")
+                    msg.exec_()
+        return ""
+
+    def saveStackAsMonochromaticTiffImages(self, dtype=None):
+        if dtype is None:
+            dtype = self._stack.data.dtype
+        if dtype in [numpy.uint32, numpy.uint64]:
+            dtype = numpy.float32
+        elif dtype in [numpy.int32, numpy.int64]:
+            dtype = numpy.float32
+
+        mcaIndex = self._stack.info.get('McaIndex', -1)
+
+        filename = self._getOutputTiffFilename()
+        if not len(filename):
+            return
+
+        ArraySave.save3DArrayAsMonochromaticTiff(self._stack.data,
+                                    filename,
+                                    labels = None,
+                                    dtype=dtype,
+                                    mcaindex=mcaIndex)
+
+    def saveStackAsFloat32TiffImages(self):
+        return self.saveStackAsMonochromaticTiffImages(dtype=numpy.float32)    
+
     def saveStackAsNeXus(self, dtype=None, interpretation=None):
         mcaIndex = self._stack.info.get('McaIndex', -1)
         if interpretation is None:
-            if mcaIndex in [0, -1]:
-                interpretation = "spectrum"
-            else:
+            if mcaIndex in [0]:
                 interpretation = "image"
+            else:
+                interpretation = "spectrum"
         if interpretation not in ["spectrum", "image"]:
             raise ValueError("Unknown data interpretation %s" % interpretation)
         filename = self._getOutputHDF5Filename()
         if not len(filename):
             return
-        ArraySave.save3DArrayAsHDF5(self._stack.data,
+        #get limits
+        row0, row1 = self.stackWidget.graph.getY1AxisLimits()
+        col0, col1 = self.stackWidget.graph.getX1AxisLimits()
+        #this should go to array save ...
+        shape = self._stack.data.shape
+        row0 = int(max([row0+0.5, 0]))
+        row1 = int(min([row1+0.5, self._stack.data.shape[0]]))
+        col0 = int(max([col0+0.5, 0]))
+        col1 = int(min([col1+0.5, self._stack.data.shape[1]]))
+        if mcaIndex in [0]:
+            view = self._stack.data[:, row0:row1+1, col0:col1+1]
+        else:
+            view = self._stack.data[row0:row1+1, col0:col1+1,:]
+        ArraySave.save3DArrayAsHDF5(view,
                                     filename,
                                     labels = None,
                                     dtype=dtype,
@@ -323,7 +394,15 @@ class QStackWidget(StackBase.StackBase,
         if self.stackSelector  is None:
             self.stackSelector = StackSelector.StackSelector(self)
         stack = self.stackSelector.getStack()
-        self.setStack(stack)
+        if type(stack) == type([]):
+            #aifira like, two stacks
+            self.setStack(stack[0])
+            self._slave = None
+            slave = QStackWidget(master=False, rgbwidget=self.rgbWidget)
+            slave.setStack(stack[1])
+            self.setSlave(slave)
+        else:
+            self.setStack(stack)
 
     def setStack(self, *var, **kw):
         self.stackWidget.setImageData(None)
@@ -349,7 +428,7 @@ class QStackWidget(StackBase.StackBase,
             actionList = ['Load Slave', 'Show Slave', 'Delete Slave']
             menu = qt.QMenu(self)
             for action in actionList:
-                text = qt.QString(action)
+                text = QString(action)
                 menu.addAction(text)
             a = menu.exec_(qt.QCursor.pos())
             if a is None:
@@ -407,31 +486,34 @@ class QStackWidget(StackBase.StackBase,
     def _pluginClicked(self):
         actionList = []
         menu = qt.QMenu(self)
-        text = qt.QString("Reload Plugins")
+        text = QString("Reload Plugins")
+        menu.addAction(text)
+        actionList.append(text)
+        text = QString("Set User Plugin Directory")
         menu.addAction(text)
         actionList.append(text)
         global DEBUG
         if DEBUG:
-            text = qt.QString("Toggle DEBUG mode OFF")
+            text = QString("Toggle DEBUG mode OFF")
         else:
-            text = qt.QString("Toggle DEBUG mode ON")
+            text = QString("Toggle DEBUG mode ON")
         menu.addAction(text)
         actionList.append(text)
         menu.addSeparator()
-        callableKeys = ["Dummy0", "Dummy1"]
+        callableKeys = ["Dummy0", "Dummy1", "Dummy2"]
         for m in self.pluginList:
             if m == "PyMcaPlugins.StackPluginBase":
                 continue
             module = sys.modules[m]
             if hasattr(module, 'MENU_TEXT'):
-                text = qt.QString(module.MENU_TEXT)
+                text = QString(module.MENU_TEXT)
             else:
                 text = os.path.basename(module.__file__)
                 if text.endswith('.pyc'):
                     text = text[:-4]
                 elif text.endswith('.py'):
                     text = text[:-3]
-                text = qt.QString(text)
+                text = QString(text)
             methods = self.pluginInstanceDict[m].getMethods()
             if not len(methods):
                 continue
@@ -451,6 +533,15 @@ class QStackWidget(StackBase.StackBase,
                 msg.exec_()
             return
         if idx == 1:
+            dirName = str(qt.QFileDialog.getExistingDirectory(self,
+                                "Enter user plugins directory",
+                                os.getcwd()))
+            if len(dirName):
+                pluginsDir = self.getPluginDirectoryList()
+                pluginsDirList = [pluginsDir[0], dirName]
+                self.setPluginDirectoryList(pluginsDirList)
+            return
+        if idx == 2:
             if DEBUG:
                 DEBUG = 0
             else:
@@ -466,9 +557,9 @@ class QStackWidget(StackBase.StackBase,
             methods.sort()
             menu = qt.QMenu(self)
             for method in methods:
-                text = qt.QString(method)
+                text = QString(method)
                 pixmap = self.pluginInstanceDict[key].getMethodPixmap(method)
-                tip = qt.QString(self.pluginInstanceDict[key].getMethodToolTip(method))
+                tip = QString(self.pluginInstanceDict[key].getMethodToolTip(method))
                 if pixmap is not None:
                     action = qt.QAction(qt.QIcon(qt.QPixmap(pixmap)), text, self)
                 else:
@@ -490,7 +581,13 @@ class QStackWidget(StackBase.StackBase,
         except:
             msg = qt.QMessageBox(self)
             msg.setIcon(qt.QMessageBox.Critical)
-            msg.setText("%s" % sys.exc_info()[1])
+            if QTVERSION < '4.0.0':
+                msg.setText("%s" % sys.exc_info()[1])
+            else:
+                msg.setWindowTitle("Plugin error")
+                msg.setText("An error has occured while executing the plugin:")
+                msg.setInformativeText(str(sys.exc_info()[1]))
+                msg.setDetailedText(traceback.format_exc())
             msg.exec_()
             if DEBUG:
                 raise
@@ -593,14 +690,29 @@ class QStackWidget(StackBase.StackBase,
         self.stackWidget.setImageData(self._stackImageData)
 
     def showOriginalMca(self):
-        self.sendMcaSelection(self._mcaData0, action="ADD")
+        goodData = numpy.isfinite(self._mcaData0.y[0].sum())
+        if goodData:
+            self.sendMcaSelection(self._mcaData0, action="ADD")
+
+    def handleNonFiniteData(self):
+        self._addMcaClicked(action="ADD")
+        msg = qt.QMessageBox(self)
+        msg.setIcon(qt.QMessageBox.Information)
+        msg.setWindowTitle("Non finite data")
+        text  = "Your data contain infinite values or nans.\n"
+        text += "Pixels containing those values will be ignored."
+        msg.setText(text)
+        msg.exec_()
+        return
 
     def showROIImageList(self, imageList, image_names=None):
         if self.roiBackgroundButton.isChecked():
             self.roiWidget.setImageData(imageList[0]-imageList[-1])
+            self.roiWidget.graphWidget.graph.setTitle(image_names[0]+\
+                                                      " Net")
         else:
             self.roiWidget.setImageData(imageList[0])
-        self.roiWidget.graphWidget.graph.setTitle(image_names[0])
+            self.roiWidget.graphWidget.graph.setTitle(image_names[0])
         self._ROIImageList = imageList
         self._ROIImageNames = image_names
         self._stackROIImageListUpdated()
@@ -731,9 +843,9 @@ class QStackWidget(StackBase.StackBase,
 
         if DEBUG:
             if self._slave is not None:
-                print "MASTER  setSelectionMask CALLED"
+                print("MASTER  setSelectionMask CALLED")
             elif self._masterStack is not None:
-                print "SLAVE setSelectionMask CALLED"
+                print("SLAVE setSelectionMask CALLED")
 
         #inform built in widgets
         for widget in [self.stackWidget, self.roiWidget]:
@@ -754,7 +866,7 @@ class QStackWidget(StackBase.StackBase,
             if instance_id not in instanceList:
                 #Originated by the master
                 if DEBUG:
-                    print "INFORMING SLAVE"
+                    print("INFORMING SLAVE")
                 self._slave.setSelectionMask(mask, instance_id=id(self))
 
         if self._masterStack is not None:
@@ -766,7 +878,7 @@ class QStackWidget(StackBase.StackBase,
             if instance_id in instanceList:
                 #Originated by the slave
                 if DEBUG:
-                    print "INFORMING MASTER"
+                    print("INFORMING MASTER")
                 self._masterStack.setSelectionMask(mask, instance_id=id(self))
         
         #Inform plugins
@@ -853,7 +965,7 @@ def test():
     nchannels = 1024
     a = numpy.ones((nrows, ncols), numpy.float)
     stackData = numpy.zeros((nrows, ncols, nchannels), numpy.float)
-    for i in xrange(nchannels):
+    for i in range(nchannels):
         stackData[:, :, i] = a * i
     stackData[0:10,:,:] = 0
     w = QStackWidget()
@@ -872,14 +984,14 @@ if __name__ == "__main__":
                      sys.argv[1:],
                      options,
                      longoptions)
-    except getopt.error,msg:
-        print msg
+    except:
+        print(sys.exc_info()[1])
         sys.exit(1)
     fileindex = 0
     filepattern=None
     begin = None
     end = None
-    imagestack=False
+    imagestack=None
     increment=None
     for opt, arg in opts:
         if opt in '--begin':
@@ -914,7 +1026,7 @@ if __name__ == "__main__":
             sys.exit(QEDFStackWidget.runAsMain())
     if filepattern is not None:
         if (begin is None) or (end is None):
-            raise ValueError, "A file pattern needs at least a set of begin and end indices"
+            raise ValueError("A file pattern needs at least a set of begin and end indices")
     app = qt.QApplication([])
     widget = QStackWidget()
     w = StackSelector.StackSelector(widget)
