@@ -1,5 +1,5 @@
 #/*##########################################################################
-# Copyright (C) 2004-2009 European Synchrotron Radiation Facility
+# Copyright (C) 2004-2011 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMCA X-ray Fluorescence Toolkit developed at
 # the ESRF by the Beamline Instrumentation Software Support (BLISS) group.
@@ -39,23 +39,37 @@ DEBUG = 0
 
 class RGBCorrelatorGraph(qt.QWidget):
     def __init__(self, parent = None, selection=False, colormap=False,
-                 imageicons=False, standalonesave=True, standalonezoom=True):
+                 imageicons=False, standalonesave=True, standalonezoom=True,
+                 profileselection=False):
         qt.QWidget.__init__(self, parent)
         self.mainLayout = qt.QVBoxLayout(self)
         self.mainLayout.setMargin(0)
         self.mainLayout.setSpacing(0)
+        if QTVERSION < '4.0.0':
+            profileselection = False
         self._buildToolBar(selection, colormap, imageicons,
                            standalonesave,
-                           standalonezoom=standalonezoom)
+                           standalonezoom=standalonezoom,
+                           profileselection=profileselection)
         self.graph = QtBlissGraph.QtBlissGraph(self)
         self.graph.xlabel("Column")
         self.graph.ylabel("Row")
         self.graph.yAutoScale = 1
         self.graph.xAutoScale = 1
+        if profileselection:
+            if len(self._pickerSelectionButtons):
+                self.connect(self.graph,
+                         qt.SIGNAL('PolygonSignal'),
+                         self._graphPolygonSignalReceived)
+                self.connect(self._pickerSelectionWidthValue,
+                             qt.SIGNAL('valueChanged(int)'),
+                             self.setPickerSelectionWith)
+        
         self.saveDirectory = os.getcwd()
         self.mainLayout.addWidget(self.graph)
         self.printPreview = PyMcaPrintPreview.PyMcaPrintPreview(modal = 0)
-        if DEBUG: print "printPreview id = ", id(self.printPreview)
+        if DEBUG:
+            print("printPreview id = %d" % id(self.printPreview))
 
     def sizeHint(self):
         return qt.QSize(1.5 * qt.QWidget.sizeHint(self).width(),
@@ -63,7 +77,7 @@ class RGBCorrelatorGraph(qt.QWidget):
 
     def _buildToolBar(self, selection=False, colormap=False,
                       imageicons=False, standalonesave=True,
-                      standalonezoom=True):
+                      standalonezoom=True,profileselection=False):
         if QTVERSION < '4.0.0':
             if qt.qVersion() < '3.0':
                 self.colormapIcon= qt.QIconSet(qt.QPixmap(IconDict["colormap16"]))
@@ -97,6 +111,9 @@ class RGBCorrelatorGraph(qt.QWidget):
             self.brushSelectionIcon = qt.QIcon(qt.QPixmap(IconDict["brushselect"]))
             self.brushIcon          = qt.QIcon(qt.QPixmap(IconDict["brush"]))
             self.additionalIcon     = qt.QIcon(qt.QPixmap(IconDict["additionalselect"]))
+            self.hLineIcon     = qt.QIcon(qt.QPixmap(IconDict["horizontal"]))
+            self.vLineIcon     = qt.QIcon(qt.QPixmap(IconDict["vertical"]))
+            self.lineIcon     = qt.QIcon(qt.QPixmap(IconDict["diagonal"]))
 
         self.toolBar = qt.QWidget(self)
         self.toolBarLayout = qt.QHBoxLayout(self.toolBar)
@@ -204,6 +221,59 @@ class RGBCorrelatorGraph(qt.QWidget):
         else:
             self.imageToolButton = None
 
+        #picker selection
+        self._pickerSelectionButtons = []
+        if profileselection:
+            self._profileSelection = True
+            self._polygonSelection = False
+            self._pickerSelectionButtons = []
+            if self._profileSelection:
+                tb = self._addToolButton(self.hLineIcon,
+                                     self._hLineProfileClicked,
+                                     'Horizontal Profile Selection',
+                                     toggle=True,
+                                     state=False)
+                self.hLineProfileButton = tb
+                self._pickerSelectionButtons.append(tb)
+    
+                tb = self._addToolButton(self.vLineIcon,
+                                     self._vLineProfileClicked,
+                                     'Vertical Profile Selection',
+                                     toggle=True,
+                                     state=False)
+                self.vLineProfileButton = tb
+                self._pickerSelectionButtons.append(tb)
+
+                tb = self._addToolButton(self.lineIcon,
+                                     self._lineProfileClicked,
+                                     'Line Profile Selection',
+                                     toggle=True,
+                                     state=False)
+                self.lineProfileButton = tb
+                self._pickerSelectionButtons.append(tb)
+
+                self._pickerSelectionWidthLabel = qt.QLabel(self.toolBar)
+                self._pickerSelectionWidthLabel.setText("W:")
+                self.toolBar.layout().addWidget(self._pickerSelectionWidthLabel)
+                self._pickerSelectionWidthValue = qt.QSpinBox(self.toolBar)
+                self._pickerSelectionWidthValue.setMinimum(1)
+                self._pickerSelectionWidthValue.setMaximum(1000)
+                self.toolBar.layout().addWidget(self._pickerSelectionWidthValue)
+                #tb = self._addToolButton(None,
+                #                     self._lineProfileClicked,
+                #                     'Line Profile Selection',
+                #                     toggle=True,
+                #                     state=False)
+                #tb.setText = "W:"
+                #self.lineWidthProfileButton = tb
+                #self._pickerSelectionButtons.append(tb)
+            if self._polygonSelection:
+                print("Polygon selection not implemented yet")
+        #hide profile selection buttons
+        if imageicons:
+            for button in self._pickerSelectionButtons:
+                button.hide()
+
         self.infoWidget = qt.QWidget(self.toolBar)
         self.infoWidget.mainLayout = qt.QHBoxLayout(self.infoWidget)
         self.infoWidget.mainLayout.setMargin(0)
@@ -240,6 +310,8 @@ class RGBCorrelatorGraph(qt.QWidget):
         self.rectSelectionToolButton.hide()
         self.brushSelectionToolButton.hide()
         self.brushToolButton.hide()
+        if QTVERSION > '4.0.0':
+            self.additionalSelectionToolButton.hide()
 
     def showImageIcons(self):
         if self.imageToolButton is None:return
@@ -248,6 +320,102 @@ class RGBCorrelatorGraph(qt.QWidget):
         self.rectSelectionToolButton.show()
         self.brushSelectionToolButton.show()
         self.brushToolButton.show()
+        if QTVERSION > '4.0.0':
+            self.additionalSelectionToolButton.show()
+
+    def _hLineProfileClicked(self):
+        for button in self._pickerSelectionButtons:
+            if button != self.hLineProfileButton:
+                button.setChecked(False)
+
+        if self.hLineProfileButton.isChecked():
+            self._setPickerSelectionMode("HORIZONTAL")
+        else:
+            self._setPickerSelectionMode(None)
+
+    def _vLineProfileClicked(self):
+        for button in self._pickerSelectionButtons:
+            if button != self.vLineProfileButton:
+                button.setChecked(False)
+        if self.vLineProfileButton.isChecked():
+            self._setPickerSelectionMode("VERTICAL")
+        else:
+            self._setPickerSelectionMode(None)
+
+    def _lineProfileClicked(self):
+        for button in self._pickerSelectionButtons:
+            if button != self.lineProfileButton:
+                button.setChecked(False)
+        if self.lineProfileButton.isChecked():
+            self._setPickerSelectionMode("LINE")
+        else:
+            self._setPickerSelectionMode(None)
+
+    def setPickerSelectionWith(self, intValue):
+        self._pickerSelectionWidthValue.setValue(intValue)
+        #get the current mode
+        mode = "NONE"
+        for button in self._pickerSelectionButtons:
+            if button.isChecked():
+                if button == self.hLineProfileButton:
+                    mode = "HORIZONTAL"
+                elif button == self.vLineProfileButton:
+                    mode = "VERTICAL"
+                elif button == self.lineProfileButton:
+                    mode = "LINE"        
+        ddict = {}
+        ddict['event'] = "PolygonWidthChanged"
+        ddict['pixelwidth'] = self._pickerSelectionWidthValue.value()
+        ddict['mode'] = mode
+        self.emit(qt.SIGNAL('PolygonSignal'), ddict)
+
+    def hideProfileSelectionIcons(self):
+        if not len(self._pickerSelectionButtons):
+            return
+        for button in self._pickerSelectionButtons:
+            button.setChecked(False)
+            button.hide()
+        self._pickerSelectionWidthLabel.hide()
+        self._pickerSelectionWidthValue.hide()
+        self.graph.setPickerSelectionModeOff()
+
+    def showProfileSelectionIcons(self):
+        if not len(self._pickerSelectionButtons):
+            return
+        for button in self._pickerSelectionButtons:
+            button.show()
+        self._pickerSelectionWidthLabel.show()
+        self._pickerSelectionWidthValue.show()
+
+    def _setPickerSelectionMode(self, mode=None):
+        if mode is None:
+            self.graph.setPickerSelectionModeOff()
+            self.graph.enableZoom(True)
+        else:
+            try:
+                self.graph.enableZoom(False)
+                self.graph.setPickerSelectionModeOn(mode)
+            except:
+                self.graph.enableZoom(True)
+                qt.QMessageBox.critical(self, "Cannot set picker mode %s" % mode,
+                                        "%s" % sys.exc_info()[1])
+                if DEBUG:
+                    raise
+        ddict = {}
+        if mode is None:
+            mode = "NONE"
+        ddict['event'] = "PolygonModeChanged"
+        ddict['mode'] = mode
+        self.emit(qt.SIGNAL('PolygonSignal'), ddict)
+
+    def _graphPolygonSignalReceived(self, ddict):
+        if DEBUG:
+            print("PolygonSignal Received")
+            for key in ddict.keys():
+                print(key, ddict[key])
+        ddict['pixelwidth'] = self._pickerSelectionWidthValue.value()
+        self.emit(qt.SIGNAL('PolygonSignal'), ddict)
+
 
     def _addToolButton(self, icon, action, tip, toggle=None, state=None, position=None):
         tb      = qt.QToolButton(self.toolBar)            
@@ -261,7 +429,8 @@ class RGBCorrelatorGraph(qt.QWidget):
                         if state:
                             tb.setState(qt.QButton.On)
         else:
-            tb.setIcon(icon)
+            if icon is not None:
+                tb.setIcon(icon)
             tb.setToolTip(tip)
             if toggle is not None:
                 if toggle:
@@ -280,7 +449,8 @@ class RGBCorrelatorGraph(qt.QWidget):
         return tb
 
     def _zoomReset(self, replot=None):
-        if DEBUG:print "_zoomReset"
+        if DEBUG:
+            print("_zoomReset")
         if replot is None:
             replot = True
         if self.graph is not None:
@@ -335,7 +505,10 @@ class RGBCorrelatorGraph(qt.QWidget):
             ret = outfile.exec_loop()
         else:
             outfile.setWindowTitle("Output File Selection")
-            strlist = qt.QStringList()
+            if hasattr(qt, "QStringList"):
+                strlist = qt.QStringList()
+            else:
+                strlist = []
             for f in fileTypeList:
                 strlist.append(f)
             outfile.setFilters(strlist)
