@@ -1,5 +1,5 @@
 #/*##########################################################################
-# Copyright (C) 2004-2010 European Synchrotron Radiation Facility
+# Copyright (C) 2004-2012 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMCA X-ray Fluorescence Toolkit developed at
 # the ESRF by the Beamline Instrumentation Software Support (BLISS) group.
@@ -27,6 +27,7 @@
 __author__ = "V.A. Sole - ESRF BLISS Group"
 import sys
 import os
+import traceback
 import RGBCorrelatorSlider
 import RGBCorrelatorTable
 import RGBImageCalculator
@@ -37,9 +38,18 @@ from PyMca_Icons import IconDict
 import ArraySave
 import PyMcaDirs
 import EdfFileDataSource
+import ExternalImagesWindow
+import TiffIO
+
 DataReader = EdfFileDataSource.EdfFileDataSource
 USE_STRING = False
 qt = RGBCorrelatorSlider.qt
+if hasattr(qt, "QString"):
+    QString = qt.QString
+    QStringList = qt.QStringList
+else:
+    QString = str
+    QStringList = list
 
 QTVERSION = qt.qVersion()
 try:
@@ -97,6 +107,11 @@ class RGBCorrelatorWidget(qt.QWidget):
         self.calculationButton = qt.QToolButton(hbox)
         self.calculationButton.setIcon(qt.QIcon(qt.QPixmap(IconDict["sigma"])))
         self.calculationButton.setToolTip("Operate with the images")
+        self.profileImageListWidget = None
+        self.profileButton = qt.QToolButton(hbox)
+        self.profileButton.setIcon(qt.QIcon(qt.QPixmap(IconDict["diagonal"])))
+        self.profileButton.setToolTip("Show selected images profile")
+
         #label1 = MyQLabel(self.labelWidget, color = qt.Qt.black)
         label1 = MyQLabel(self.labelWidget, color = qt.Qt.black)
         label1.setAlignment(alignment)
@@ -117,6 +132,7 @@ class RGBCorrelatorWidget(qt.QWidget):
         hbox.mainLayout.addWidget(self.removeButton)
         hbox.mainLayout.addWidget(self.toggleSlidersButton)
         hbox.mainLayout.addWidget(self.calculationButton)
+        hbox.mainLayout.addWidget(self.profileButton)
         hbox.mainLayout.addWidget(HorizontalSpacer(self.toolBar))
         
         #hbox.mainLayout.addWidget(label1)
@@ -190,9 +206,9 @@ class RGBCorrelatorWidget(qt.QWidget):
                      qt.SIGNAL("clicked()"),
                      self.saveButtonClicked)
         self._saveButtonMenu = qt.QMenu()
-        self._saveButtonMenu.addAction(qt.QString("Save all"),
+        self._saveButtonMenu.addAction(QString("Save all"),
                                     self.saveImageList)
-        self._saveButtonMenu.addAction(qt.QString("Save selected"),
+        self._saveButtonMenu.addAction(QString("Save selected"),
                                     self.saveSelectedImages)
 
 
@@ -207,6 +223,11 @@ class RGBCorrelatorWidget(qt.QWidget):
         self.connect(self.calculationButton,
                      qt.SIGNAL("clicked()"),
                      self._showCalculationDialog)
+
+        self.connect(self.profileButton,
+                     qt.SIGNAL("clicked()"),
+                     self.profileSelectedImages)
+
         self._calculationMenu = None
         self.pcaDialog  = None
         self.nnmaDialog = None
@@ -231,17 +252,17 @@ class RGBCorrelatorWidget(qt.QWidget):
             return self.showCalculationDialog()
         if self._calculationMenu is None:
             self._calculationMenu = qt.QMenu()
-            self._calculationMenu.addAction(qt.QString("Image calculator"),
+            self._calculationMenu.addAction(QString("Image calculator"),
                                             self.showCalculationDialog)
             if PCA:
                 if PCADialog.MDP:
-                    self._calculationMenu.addAction(qt.QString("PCA/ICA Analysis"),
+                    self._calculationMenu.addAction(QString("PCA/ICA Analysis"),
                                             self.showPCADialog)
                 else:
-                    self._calculationMenu.addAction(qt.QString("PCA Analysis"),
+                    self._calculationMenu.addAction(QString("PCA Analysis"),
                                             self.showPCADialog)
             if NNMA:
-                self._calculationMenu.addAction(qt.QString("NNMA Analysis"),
+                self._calculationMenu.addAction(QString("NNMA Analysis"),
                                             self.showNNMADialog)
         self._calculationMenu.exec_(self.cursor().pos())
 
@@ -254,7 +275,8 @@ class RGBCorrelatorWidget(qt.QWidget):
             self.toggleSlidersButton.setIcon(self._slidersOnIcon)
         
     def _sliderSlot(self, ddict):
-        if DEBUG: print "RGBCorrelatorWidget._sliderSlot()"
+        if DEBUG:
+            print("RGBCorrelatorWidget._sliderSlot()")
         if self.__imageLength is None: return
         tableDict = self.tableWidget.getElementSelection()
         if ddict['event'] == 'redChanged':
@@ -286,7 +308,8 @@ class RGBCorrelatorWidget(qt.QWidget):
             self.__recolor(['r', 'g', 'b'])
             
     def _tableSlot(self, ddict):
-        if DEBUG: print "RGBCorrelatorWidget._tableSlot()"
+        if DEBUG:
+            print("RGBCorrelatorWidget._tableSlot()")
         if self.__imageLength is None: return
         if ddict['r'] == []:ddict['r'] = None
         if ddict['g'] == []:ddict['g'] = None
@@ -419,7 +442,7 @@ class RGBCorrelatorWidget(qt.QWidget):
         COLORMAPLIST = [spslut.GREYSCALE, spslut.REVERSEGREY, spslut.TEMP,
                         spslut.RED, spslut.GREEN, spslut.BLUE, spslut.MANY]
         if colormap not in COLORMAPLIST:
-            raise ValueError, "Unknown color scheme %s" % colormap
+            raise ValueError("Unknown color scheme %s" % colormap)
 
         if (datamin is None) or (datamax is None):
             #spslut already calculates min and max
@@ -471,8 +494,8 @@ class RGBCorrelatorWidget(qt.QWidget):
                 image = Numeric.resize(image,
                          (self.__imageShape[0], self.__imageShape[1]))
             else:
-                raise ValueError, "Image cannot be reshaped to %d x %d" % \
-                          (self.__imageShape[0], self.__imageShape[1])  
+                raise ValueError("Image cannot be reshaped to %d x %d" % \
+                          (self.__imageShape[0], self.__imageShape[1]))
 
         if label not in self._imageList:
             self._imageList.append(label)
@@ -579,8 +602,8 @@ class RGBCorrelatorWidget(qt.QWidget):
         for value in shape:
             length *= value
         if length != self.__imageLength:
-            raise ValueError, "New length %d different of old length %d" % \
-                    (length, self.__imageLength)
+            raise ValueError("New length %d different of old length %d" % \
+                    (length, self.__imageLength))
         self.__imageShape = shape
         self._updateSizeLabel()
         for key in self._imageDict.keys():
@@ -595,8 +618,8 @@ class RGBCorrelatorWidget(qt.QWidget):
         for value in shape:
             length *= value
         if length != self.__imageLength:
-            raise ValueError, "New length %d different of old length %d" % \
-                    (length, self.__imageLength)
+            raise ValueError("New length %d different of old length %d" % \
+                    (length, self.__imageLength))
         self.__imageShape = (shape[0], shape[1])
         self._updateSizeLabel()
         for key in self._imageDict.keys():
@@ -658,10 +681,12 @@ class RGBCorrelatorWidget(qt.QWidget):
         formatlist = ["ASCII Files *.dat",
                       "EDF Files *.edf",
                       "EDF(Float32) Files *.edf",
+                      "TIFF(Float32 Mono) Files *.tif",
+                      "TIFF(Mono) Files *.tif",
                       'CSV(, separated) Files *.csv',
                       'CSV(; separated) Files *.csv',
                       'CSV(tab separated) Files *.csv']
-        strlist = qt.QStringList()
+        strlist = QStringList()
         for f in formatlist:
                 strlist.append(f)
         if self._saveFilter is None:
@@ -673,20 +698,24 @@ class RGBCorrelatorWidget(qt.QWidget):
         if not ret: return ""
         filename = filedialog.selectedFiles()[0]
         if len(filename):
-            filename = str(filename)
+            filename = "%s" % filename
             self.outputDir = os.path.dirname(filename)
-            self._saveFilter = str(filedialog.selectedFilter())
+            self._saveFilter = "%s" % filedialog.selectedFilter()
             filterused = "."+self._saveFilter[-3:]
             PyMcaDirs.outputDir = os.path.dirname(filename)
             if len(filename) < 4:
                 filename = filename+ filterused
             elif filename[-4:] != filterused :
-                filename = filename+ filterused
+                if filterused in ['.tif'] and filename[-4:] == 'tiff':
+                    #do not append .tif to the file name
+                    pass
+                else:
+                    filename = filename+ filterused
         else:
             filename = ""
         return filename
 
-    def getInputFileName(self):
+    def getInputFileName(self, getfilter=False):
         initdir = PyMcaDirs.inputDir
         filedialog = qt.QFileDialog(self)
         filedialog.setFileMode(filedialog.ExistingFiles)
@@ -696,40 +725,84 @@ class RGBCorrelatorWidget(qt.QWidget):
                       "EDF Files *edf",
                       "EDF Files *ccd",
                       "CSV Files *csv",
+                      "TIFF Files *tiff *tif",
+                      "TextImage Files *txt",
                       "All Files *"]
-        strlist = qt.QStringList()
+        strlist = QStringList()
         for f in formatlist:
                 strlist.append(f)
         filedialog.setFilters(strlist)
         filedialog.setDirectory(initdir)
         ret = filedialog.exec_()
-        if not ret: return [""]
+        if not ret:
+            if getfilter:
+                return [""], None
+            else:
+                return [""]
         filename = filedialog.selectedFiles()
+        filterused = None
         if len(filename):
-            filename = map(str, filename)
+            filename = ["%s" % fname for fname in filename]
             self.outputDir = os.path.dirname(filename[0])
             PyMcaDirs.inputDir = os.path.dirname(filename[0])
+            if getfilter:
+                filterused = "%s" % filedialog.selectedFilter()
         else:
             filename = [""]
-        return filename        
+        if getfilter:
+            return filename, filterused
+        else:
+            return filename
+    
 
-    def addFileList(self, filelist = None):
+    def addFileList(self, filelist = None, filterused=""):
         if filelist is None:
-            filelist = self.getInputFileName()
-        if not len(filelist[0]):return
+            filelist, filterused = self.getInputFileName(getfilter=True)
+            if filterused is None:
+                filterused = ""
+        if not len(filelist[0]):
+            return
         self.outputDir = os.path.dirname(filelist[0])
         try:
             for fname in filelist:
-                if self._isEdf(fname):
-                    source = DataReader(fname)
-                    for key in source.getSourceInfo()['KeyList']:
-                        dataObject = source.getDataObject(key)
-                        self.addImage(dataObject.data,
-                                      os.path.basename(fname)+" "+key)
-                elif fname.lower().split(".")[-1] in ["jpg","jpeg",
+                if fname.lower().split(".")[-1] in ["jpg","jpeg",
                                                       "tif","tiff",
                                                       "png"]:
-                    #try a pure image format
+                    if fname.lower().split(".")[-1] in ["tif", "tiff"]:
+                        #try the built in support
+                        try:
+                            tif = TiffIO.TiffIO(fname)
+                            nImages = tif.getNumberOfImages()
+                            if nImages > 0:
+                                for nImage in range(nImages):
+                                    info = tif.getInfo(nImage)['info']
+                                    imgData = tif.getImage(nImage)
+                                    title = "%04d/%d"  % (nImage+1, nImages)
+                                    if 'Title' in info:
+                                        title = info.get('Title')
+                                    elif nImages > 1:
+                                        title = "%04d/%d "  % (nImage+1, nImages)
+                                        title += os.path.basename(fname)
+                                    else:
+                                        title = os.path.basename(fname)
+                                    if len(imgData.shape) == 3:
+                                        #color image
+                                        colorIndex = 0
+                                        for component in ['R', 'G', 'B']:
+                                            self.addImage(imgData[:,:,colorIndex].astype(numpy.float), title + '_' + component)
+                                            colorIndex += 1
+                                        data = imgData[:,:,0] * 0.114 +\
+                                               imgData[:,:,1] * 0.587 +\
+                                               imgData[:,:,2] * 0.299
+                                        self.addImage(data, title)
+                                    else:                                            
+                                        self.addImage(imgData, title)
+                                continue
+                        except:
+                            if DEBUG:
+                                print("Built-in tif support unsuccessful")
+                            pass                        
+                    #try a pure image format from PyQt
                     qimage = qt.QImage(fname)
                     if qimage.isNull():
                         msg = qt.QMessageBox(self)
@@ -758,6 +831,16 @@ class RGBCorrelatorWidget(qt.QWidget):
                                 pixmap[:,:,1] * 0.587 +\
                                 pixmap[:,:,2] * 0.299
                     self.addImage(data, os.path.basename(fname))
+                elif self._isEdf(fname):
+                    source = DataReader(fname)
+                    for key in source.getSourceInfo()['KeyList']:
+                        dataObject = source.getDataObject(key)
+                        title = dataObject.info.get("Title", key)
+                        self.addImage(dataObject.data,
+                                    os.path.basename(fname)+" "+title)
+                elif filterused.upper().startswith("TEXTIMAGE"):
+                    data = numpy.loadtxt(fname)
+                    self.addImage(data, os.path.basename(fname))
                 else:
                     if len(fname) < 5:
                         self.addBatchDatFile(fname, csv=False)
@@ -769,7 +852,11 @@ class RGBCorrelatorWidget(qt.QWidget):
             msg = qt.QMessageBox(self)
             msg.setIcon(qt.QMessageBox.Critical)
             msg.setText("Error adding file: %s" % sys.exc_info()[1])
+            msg.setInformativeText(str(sys.exc_info()[1]))
+            msg.setDetailedText(traceback.format_exc())
             msg.exec_()
+            if DEBUG:
+                raise
 
     def addBatchDatFile(self, filename, ignoresigma=None, csv=False):
         self.outputDir = os.path.dirname(filename)
@@ -791,6 +878,10 @@ class RGBCorrelatorWidget(qt.QWidget):
                     f = open(filename, "r")
                 lines =f.read()
                 f.close()
+                if sys.version < '3.0':
+                    pass
+                else:
+                    lines = lines.decode()
                 lines = lines.replace("\r","\n")
                 lines = lines.replace("\n\n","\n")
                 lines = lines.replace(",","  ")
@@ -839,7 +930,7 @@ class RGBCorrelatorWidget(qt.QWidget):
             iterationList = range(2, nlabels)
         totalArray = Numeric.zeros((nrows, nlabels), Numeric.Float)
         for i in range(nrows):
-            totalArray[i, :] = map(float, lines[i+1].split())
+            totalArray[i, :] = [float(x) for x in lines[i+1].split()]
 
         nrows = int(max(totalArray[:,0]) + 1)
         ncols = int(max(totalArray[:,1]) + 1)
@@ -849,14 +940,22 @@ class RGBCorrelatorWidget(qt.QWidget):
             self.addImage(Numeric.resize(singleArray, (nrows, ncols)), labels[i])
         
     def _isEdf(self, filename):
-        f = open(filename)
-        line = f.readline().replace('\n',"")
-        if not len(line):
-            line = f.readline().replace('\n',"")
+        f = open(filename, 'rb')
+        twoBytes = f.read(2)
         f.close()
-        if len(line):
-            if line[0] == "{":
-                return True
+        if sys.version < '3.0':
+            twoChar = twoBytes
+        else:
+            try:
+                twoChar = twoBytes.decode('utf-8')
+            except:
+                twoChar = "__dummy__"
+        if twoChar in ["II", "MM", "\n{"] or\
+           twoChar[0] in ["{"] or\
+           filename.lower().endswith('cbf')or\
+           (filename.lower().endswith('spe') and twoChar[0] not in ["$"]):
+            #very likely wrapped as EDF
+            return True
         return False
 
     def saveButtonClicked(self):
@@ -897,14 +996,26 @@ class RGBCorrelatorWidget(qt.QWidget):
         for label in imageList:
             datalist.append(self._imageDict[label]['image'])
             labels.append(label.replace(" ","_"))
-            
-        if filename[-4:].lower() == ".edf":
+
+        fileExtension = os.path.splitext(filename)[-1].lower()
+        if fileExtension in [".edf"]:
             if 'Float32'in self._saveFilter:
                 dtype = Numeric.Float32
-                ArraySave.save2DArrayListAsEDF(datalist, filename, labels, dtype)
+                ArraySave.save2DArrayListAsEDF(datalist,
+                                               filename,
+                                               labels, dtype)
             else:
                 ArraySave.save2DArrayListAsEDF(datalist, filename, labels)
-        elif filename[-4:].lower() == ".csv":
+        elif fileExtension in [".tif", ".tiff"]:
+            if 'Float32'in self._saveFilter:
+                dtype = numpy.float32
+            else:
+                dtype = None
+            ArraySave.save2DArrayListAsMonochromaticTiff(datalist,
+                                                         filename,
+                                                         labels=labels,
+                                                         dtype=dtype)
+        elif fileExtension in [".csv"]:
             if "," in self._saveFilter:
                 csvseparator = ","
             elif ";" in self._saveFilter:
@@ -1012,6 +1123,8 @@ class RGBCorrelatorWidget(qt.QWidget):
     def closeEvent(self, event):
         if self.calculationDialog is not None:
             self.calculationDialog.close()
+        if self.profileImageListWidget is not None:
+            self.profileImageListWidget.close()
         qt.QWidget.closeEvent(self, event)
 
     """
@@ -1030,7 +1143,40 @@ class RGBCorrelatorWidget(qt.QWidget):
         pilImage.save(filename)
     """
 
+    def profileSelectedImages(self):
+        itemList = self.tableWidget.selectedItems()
+        if len(itemList) < 1:
+            errorText = "Please select at least one row in the table"
+            qt.QMessageBox.critical(self,"ValueError", errorText)
+            return
+        profileList = []
+        imageList = []
+        imageNames = []
         
+        for item in itemList:
+            row = item.row()
+            profileList.append(row)
+
+        for index in profileList:
+            name = self._imageList[index]
+            imageList.append(self._imageDict[name]['image'])
+            imageNames.append(name)
+        self.profileImageList(imagelist=imageList,
+                           imagenames=imageNames)
+        
+
+    def profileImageList(self, imagelist=None, imagenames=None):
+        if imagelist in [None, []]:
+            return
+        if self.profileImageListWidget is None:
+             self.profileImageListWidget= ExternalImagesWindow.ExternalImagesWindow(None,\
+                                        crop=False,
+                                        imageicons=False,
+                                        profileselection=True,
+                                        depthselection=True)
+        self.profileImageListWidget.setImageList(imagelist=imagelist, imagenames=imagenames)
+        self.profileImageListWidget.show()
+                                                            
 
 class ImageShapeDialog(qt.QDialog):
     def __init__(self, parent = None, shape = None):
@@ -1089,10 +1235,10 @@ class ImageShapeDialog(qt.QDialog):
             self.rows.setText("%g" % (self._size/float(ncolumns)))
 
     def getImageShape(self):
-        text = str(self.rows.text())
+        text = "%s" % self.rows.text()
         if len(text): nrows = int(float(text))
         else: nrows = 0
-        text = str(self.columns.text())
+        text = "%s" % self.columns.text()
         if len(text): ncolumns = int(float(text))
         else: ncolumns = 0
         return nrows, ncolumns
@@ -1155,7 +1301,7 @@ def test():
     w = RGBCorrelatorWidget(container)
     graph = RGBCorrelatorGraph.RGBCorrelatorGraph(container)
     def slot(ddict):
-        if ddict.has_key('image'):
+        if 'image' in ddict:
             image_buffer = ddict['image'].tostring()
             size = ddict['size']
             graph.graph.pixmapPlot(image_buffer,size)
