@@ -1,5 +1,5 @@
 #/*##########################################################################
-# Copyright (C) 2004-2009 European Synchrotron Radiation Facility
+# Copyright (C) 2004-2011 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMCA X-ray Fluorescence Toolkit developed at
 # the ESRF by the Beamline Instrumentation Software Support (BLISS) group.
@@ -24,7 +24,7 @@
 # Please contact the ESRF industrial unit (industry@esrf.fr) if this license 
 # is a problem for you.
 #############################################################################*/
-__author__ = "V.A. Sole - ESRF BLISS Group"
+__author__ = "V.A. Sole - ESRF Data Analysis"
 import PyMcaQt as qt
 from PyMca_Icons import IconDict
 import MaskImageWidget
@@ -59,7 +59,7 @@ class SNIP1DParametersWidget(qt.QWidget):
         textLabels = ["SNIP background width (2 to 3 times fwhm) :",
                      "Minimum channel considered:",
                      "Maximum channel considered:",
-                     "Pleliminar smoothing level:"]
+                     "Preliminar smoothing level:"]
         if smooth:
             textLabels[0] = "SNIP width :"
             self.parametersDict['width'] = 3
@@ -98,15 +98,15 @@ class SNIP1DParametersWidget(qt.QWidget):
 
     def setParameters(self, ddict=None):
         if ddict is None:
-            return
-        
+            return        
         actualKeys = self.widgetDict.keys()
         for key in ddict.keys():
             if key in actualKeys:
                 w = self.widgetDict[key] 
-                w.setMaximum(max(ddict[key], w.value()))
-                w.setMinimum(min(ddict[key], w.value()))
+                #w.setMaximum(max(ddict[key], w.value()))
+                #w.setMinimum(min(ddict[key], w.value()))
                 w.setValue(ddict[key])
+        self._updateParameters("dummy")
 
 class SNIP2DParametersWidget(qt.QWidget):
     def __init__(self, parent = None, shape=(4000,4000)):
@@ -200,6 +200,9 @@ class SNIP2DParametersWidget(qt.QWidget):
     def getParameters(self):
         return self.parametersDict
 
+    def setParameters(self):
+        raise NotImplemented("Set parameters not implemented for SNIP 2D")
+
 class SNIPWindow(qt.QWidget):
     def __init__(self, parent, data, image=None, x=None, smooth=False):
         qt.QWidget.__init__(self, parent)
@@ -254,6 +257,7 @@ class SNIPWindow(qt.QWidget):
         self.xMarkers = []
         self.yMarkers = []
         self.getParameters = self.parametersWidget.getParameters
+        self.setParameters = self.parametersWidget.setParameters
         self.connect(self.parametersWidget,
                      qt.SIGNAL('SNIPParametersSignal'),
                      self.updateGraph)
@@ -369,7 +373,18 @@ class SNIPDialog(qt.QDialog):
                                        parametersDict['roi_min'],
                                        parametersDict['roi_max'],
                                        parametersDict['smoothing']]
-        return parametersDict                                       
+        return parametersDict
+
+    def setParameters(self, ddict0):
+        if 'arguments' in ddict0:
+            ddict = {}
+            ddict['width'] = ddict0['arguments'][0]
+            ddict['roi_min'] = ddict0['arguments'][1]
+            ddict['roi_max'] = ddict0['arguments'][2]
+            ddict['smoothing'] = ddict0['arguments'][3]
+            self.parametersWidget.setParameters(ddict)
+        else:
+            self.parametersWidget.setParameters(ddict0)
                  
 if __name__ == "__main__":
     import numpy
@@ -392,4 +407,4 @@ if __name__ == "__main__":
     w.show()
     ret=w.exec_()
     if ret:
-        print w.getParameters()
+        print(w.getParameters())
