@@ -1,5 +1,5 @@
 #/*##########################################################################
-# Copyright (C) 2004-2010 European Synchrotron Radiation Facility
+# Copyright (C) 2004-2011 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMCA X-ray Fluorescence Toolkit developed at
 # the ESRF by the Beamline Instrumentation Software Support (BLISS) group.
@@ -25,12 +25,11 @@
 # is a problem for you.
 #############################################################################*/
 __revision__ = "$Revision: 1.3$"
-
-import DataObject
-import specfilewrapper as specfile
+import sys
+from PyMca import DataObject
+from PyMca import specfilewrapper as specfile
 import numpy
 import numpy.oldnumeric as Numeric
-import string
 import types
 import os
 
@@ -51,16 +50,21 @@ class SpecFileDataSource:
     Error= "SpecFileDataError"
 
     def __init__(self, nameInput):
-        if type(nameInput) == types.ListType:
+        if type(nameInput) == type([]):
             nameList = nameInput
         else:
             nameList = [nameInput]
         if len(nameList) > 1:
             #who knows if one day will make selections thru several files...
-            raise TypeError,"Constructor needs string as first argument"    
+            raise TypeError("Constructor needs string as first argument")
+        if sys.version < '3.0':
+            testTypes = [types.StringType, types.UnicodeType]
+        else:
+            testTypes = [type("")]
+        
         for name in nameList:
-            if type(name) not in [types.StringType, types.UnicodeType]:
-                raise TypeError,"Constructor needs string as first argument"            
+            if type(name) not in testTypes:
+                raise TypeError("Constructor needs string as first argument")            
         self.sourceName   = nameInput
         self.sourceType   = SOURCE_TYPE
         self.__sourceNameList = nameList
@@ -73,7 +77,7 @@ class SpecFileDataSource:
         self.__fileHeaderList = []
         for name in self.__sourceNameList:
             if not os.path.exists(name):
-                raise ValueError,"File %s does not exists" % name
+                raise ValueError("File %s does not exists" % name)
         for name in self.__sourceNameList:
             self._sourceObjectList.append(specfile.Specfile(name))
             self.__fileHeaderList.append(False)
@@ -126,13 +130,14 @@ class SpecFileDataSource:
         return source_info
 
     def __getScanList(self):
-        aux= string.split(self._sourceObjectList[0].list(),",")
+        aux= self._sourceObjectList[0].list().split(",")
         newlistcount=[]
         newlist=[]
         for i in aux:
-            if string.find(i,":")== -1:  start_index=end_index=int(i)
+            if not (":" in i):
+                start_index=end_index=int(i)
             else:
-                s= string.split(i,":")
+                s= i.split(":")
                 start_index=int(s[0])
                 end_index=int(s[1])
             for j in range(start_index,end_index+1):
@@ -145,21 +150,23 @@ class SpecFileDataSource:
     def __getScanType(self, num_pts, num_mca, command):
         stype= SF_EMPTY
         if num_pts>0:
-                if command is None:stype= SF_SCAN
-                elif string.find(command, "mesh")!=-1:
-                        stype= SF_MESH
-                else:   stype= SF_SCAN
+                if command is None:
+                    stype= SF_SCAN
+                elif "mesh" in command:
+                    stype= SF_MESH
+                else:
+                    stype= SF_SCAN
                 if num_mca%num_pts:
-                        stype+= SF_UMCA
+                    stype+= SF_UMCA
                 elif num_mca==num_pts:
-                        stype+= SF_MCA
+                    stype+= SF_MCA
                 elif num_mca>0:
-                        stype+= SF_NMCA
+                    stype+= SF_NMCA
         else:
                 if num_mca==1:
-                        stype= SF_MCA
+                    stype= SF_MCA
                 elif num_mca>1:
-                        stype= SF_NMCA
+                    stype= SF_NMCA
         return stype
 
 
@@ -175,12 +182,13 @@ class SpecFileDataSource:
         return self.__getScanInfo(scan_key)
 
     def __getKeyType (self,key):
-        count= string.count(key, '.')
-        if (count==1): return "scan"
+        count= key.count('.')
+        if (count==1):
+            return "scan"
         elif (count==2) or (count==3):
             return "mca"
         else:
-            raise KeyError, "SpecFileDataSource: Invalid key"
+            raise KeyError("SpecFileDataSource: Invalid key")
 
     def __getScanInfo(self, scankey):
         index = 0
@@ -235,7 +243,7 @@ class SpecFileDataSource:
     def __getMcaInfo(self, mcano, scandata, info=None):
         if info is None: info = {}
         mcainfo= {}
-        if info.has_key("NbMcaDet"):
+        if "NbMcaDet" in info:
             det= info["NbMcaDet"]
             if info["Lines"]>0:
                 mcainfo["McaPoint"]= int(mcano/info["NbMcaDet"])+(mcano%info["NbMcaDet"]>0)
@@ -253,11 +261,11 @@ class SpecFileDataSource:
                 calib = [calib[mcainfo["McaDet"]-1]]
             else:
                 if DEBUG:
-                    print "Warning","Number of calibrations does not match number of MCAs"
+                    print("Warning","Number of calibrations does not match number of MCAs")
                 if len(calib) == 1:
                     pass
                 else:
-                    raise ValueError,"Number of calibrations does not match number of MCAs"        
+                    raise ValueError("Number of calibrations does not match number of MCAs")
             ctxt= calib[0].split()
             if len(ctxt)==4:
                 #try:
@@ -273,18 +281,19 @@ class SpecFileDataSource:
                 ctime = [ctime[mcainfo["McaDet"]-1]]
             else:
                 if DEBUG:
-                    print "Warning","Number of counting times does not match number of MCAs"
+                    print("Warning","Number of counting times does not match number of MCAs")
                 if len(ctime) == 1:
                     pass
                 else:
-                    raise ValueError,"Number of counting times does not match number of MCAs"        
+                    raise ValueError("Number of counting times does not match number of MCAs")        
             ctxt= ctime[0].split()
             if len(ctxt)==4:
                 try:
                     mcainfo["McaPresetTime"]= float(ctxt[1])
                     mcainfo["McaLiveTime"]= float(ctxt[2])
                     mcainfo["McaRealTime"]= float(ctxt[3])
-                except: pass
+                except:
+                    pass
                         
         chann = scandata.header("@CHANN")
         if len(chann):
@@ -292,11 +301,11 @@ class SpecFileDataSource:
                 chann = [chann[mcainfo["McaDet"] - 1]]
             else:
                 if DEBUG:
-                    print "Warning","Number of @CHANN information does not match number of MCAs"
+                    print("Warning","Number of @CHANN information does not match number of MCAs")
                 if len(chann) == 1:
                     pass
                 else:
-                    raise ValueError,"Number of @CHANN information does not match number of MCAs"        
+                    raise ValueError("Number of @CHANN information does not match number of MCAs")        
             ctxt= chann[0].split()
             if len(ctxt)==5:
                 mcainfo['Channel0'] = float(ctxt[2])
@@ -309,7 +318,7 @@ class SpecFileDataSource:
 
     def __getMcaPars(self,key):
         index = 0
-        nums= string.split(key,'.')
+        nums= key.split('.')
         size = len(nums)
         sel_key = nums[0] + "." + nums[1]
         if size==3:
@@ -321,7 +330,7 @@ class SpecFileDataSource:
             if nums[3]==0: mca_no=int(nums[2])
             else:          mca_no=((int(nums[3])-1)*lines)+int(nums[2])
         else:
-            raise KeyError, "SpecFileData: Invalid key"
+            raise KeyError("SpecFileData: Invalid key")
         return (sel_key,mca_no)
 
     def getDataObject(self,key,selection=None):
@@ -371,15 +380,15 @@ class SpecFileDataSource:
                 sourceinfo = self.getSourceInfo()
                 sourcekeys = sourceinfo['KeyList']
         if scan_key not in sourcekeys:
-            raise KeyError, "Key %s not in source keys" % key
+            raise KeyError("Key %s not in source keys" % key)
 
         mca3D = False
         if DEBUG:
-            print "SELECTION = ", selection
-            print "key_type = ", key_type
+            print("SELECTION = ", selection)
+            print("key_type = ", key_type)
         if key_type == "scan":
             if selection  is not None:
-                if selection.has_key('mcalist'):
+                if 'mcalist' in selection:
                     mca3D = True
 
         if (key_type=="scan") and (not mca3D):
@@ -393,49 +402,49 @@ class SpecFileDataSource:
                 return output
             elif type(selection) != type({}):
                 #I only understand index selections
-                raise TypeError, "Only selections of type {x:[],y:[],m:[]} understood"
+                raise TypeError("Only selections of type {x:[],y:[],m:[]} understood")
             else:
-                if selection.has_key('x'):
+                if 'x' in selection:
                     indexlist = []
                     for labelindex in selection['x']:
                         if labelindex != 0:
-                            if selection.has_key('cntlist'):
+                            if 'cntlist' in selection:
                                 label = selection['cntlist'][labelindex]
                             else:
                                 label = output.info['LabelNames'][labelindex]
                         else:
                             label = output.info['LabelNames'][labelindex]
                         if label not in output.info['LabelNames']:
-                            raise ValueError, "Label %s not in scan labels" % label
+                            raise ValueError("Label %s not in scan labels" % label)
                         index = output.info['LabelNames'].index(label)
                         if output.x is None: output.x = []
                         output.x.append(output.data[:, index])
                         indexlist.append(index)
                     output.info['selection']['x'] = indexlist
-                if selection.has_key('y'):
+                if 'y' in selection:
                     indexlist = []
                     for labelindex in selection['y']:
-                        if selection.has_key('cntlist'):
+                        if 'cntlist' in selection:
                             label = selection['cntlist'][labelindex]
                         else:    
                             label = output.info['LabelNames'][labelindex]
                         if label not in output.info['LabelNames']:
-                            raise ValueError, "Label %s not in scan labels" % label
+                            raise ValueError("Label %s not in scan labels" % label)
                         index = output.info['LabelNames'].index(label)
                         if output.y is None:
                             output.y = []
                         output.y.append(output.data[:, index])
                         indexlist.append(index)
                     output.info['selection']['y'] = indexlist
-                if selection.has_key('m'):
+                if 'm' in selection:
                     indexlist = []
                     for labelindex in selection['m']:
-                        if selection.has_key('cntlist'):
+                        if 'cntlist' in selection:
                             label = selection['cntlist'][labelindex]
                         else:    
                             label = output.info['LabelNames'][labelindex]
                         if label not in output.info['LabelNames']:
-                            raise ValueError, "Label %s not in scan labels" % label
+                            raise ValueError("Label %s not in scan labels" % label)
                         index = output.info['LabelNames'].index(label)
                         if output.m is None: output.m = []
                         output.m.append(output.data[:, index])
@@ -498,7 +507,7 @@ class SpecFileDataSource:
             output.y = None
             output.m = None
             #get the number of counters in the scan
-            if selection.has_key('cntlist'):
+            if 'cntlist' in selection:
                 ncounters = len(selection['cntlist'])
             else:
                 ncounters = output.info['LabelNames']
@@ -522,18 +531,18 @@ class SpecFileDataSource:
             #get the different x components
             xselection = selection.get('x', [])
             if len(xselection) != 2:
-                raise ValueError, "You have to select two X axes"
+                raise ValueError("You have to select two X axes")
             indexlist = []
             for labelindex in xselection:
                 if labelindex != 0:
-                    if selection.has_key('cntlist'):
+                    if 'cntlist' in selection:
                         label = selection['cntlist'][labelindex]
                     else:
                         label = output.info['LabelNames'][labelindex]
                 else:
                     label = output.info['LabelNames'][labelindex]
                 if label not in output.info['LabelNames']:
-                    raise ValueError, "Label %s not in scan labels" % label
+                    raise ValueError("Label %s not in scan labels" % label)
                 index = output.info['LabelNames'].index(label)
                 if output.x is None:
                     output.x = []
@@ -551,15 +560,15 @@ class SpecFileDataSource:
                 mca_key = '%s.%d.%d' % (key, 1+detectorNumber, 1)
                 mcaData = self._getMcaData(mca_key)
                 output.y[0][(i*nChannels):((i+1)*nChannels)] = mcaData.data[:]
-            if selection.has_key('m'):
+            if 'm' in selection:
                 indexlist = []
                 for labelindex in selection['m']:
-                    if selection.has_key('cntlist'):
+                    if 'cntlist' in selection:
                         label = selection['cntlist'][labelindex]
                     else:    
                         label = output.info['LabelNames'][labelindex]
                     if label not in output.info['LabelNames']:
-                        raise ValueError, "Label %s not in scan labels" % label
+                        raise ValueError("Label %s not in scan labels" % label)
                     index = output.info['LabelNames'].index(label)
                     if output.m is None:
                             output.m = []
@@ -588,14 +597,14 @@ class SpecFileDataSource:
             try:
                 scan_data= Numeric.transpose(scan_obj.data()).copy()
             except:
-                raise IOError, "SF_SCAN read failed"
+                raise IOError("SF_SCAN read failed")
         elif scan_type&SF_MESH:
             try:
                 if raw:
                     try:
                         scan_data= Numeric.transpose(scan_obj.data()).copy()
                     except:
-                        raise IOError, "SF_MESH read failed"
+                        raise IOError("SF_MESH read failed")
                 else:
                     scan_array= scan_obj.data()
                     (mot1,mot2,cnts)= self.__getMeshSize(scan_array)
@@ -604,12 +613,17 @@ class SpecFileDataSource:
                         scan_data[:,idx,:]= Numeric.transpose(scan_array[:,idx*mot1:(idx+1)*mot1]).copy()
                     scan_data= Numeric.transpose(scan_data).copy()
             except:
-                raise IOError, "SF_MESH read failed"
+                raise IOError("SF_MESH read failed")
         elif scan_type&SF_MCA:
             try:
                 scan_data= scan_obj.mca(1)
             except:
-                raise IOError, "SF_MCA read failed"
+                raise IOError("SF_MCA read failed")
+        elif scan_type&SF_NMCA:
+            try:
+                scan_data= scan_obj.mca(1)
+            except:
+                raise IOError("SF_NMCA read failed")
 
         if scan_data is not None:
             #create data object
@@ -619,7 +633,7 @@ class SpecFileDataSource:
             dataObject.data = scan_data
             return dataObject
         else:
-            raise TypeError, "getData unknown type"
+            raise TypeError("getData unknown type")
 
     def _getMcaData(self, key):
         index = 0        
@@ -640,7 +654,7 @@ class SpecFileDataSource:
                     mca_no= int(key_split[2])
                     scan_data= scan_obj.mca(mca_no)
                 except: 
-                    raise IOError, "Single MCA read failed"
+                    raise IOError("Single MCA read failed")
             if scan_data is not None:
                 scan_info.update(self.__getMcaInfo(mca_no, scan_obj, scan_info))
                 dataObject = DataObject.DataObject()
@@ -654,7 +668,7 @@ class SpecFileDataSource:
                     mca_no= (int(key_split[2])-1)*scan_info["NbMcaDet"] + int(key_split[3])
                     scan_data= scan_obj.mca(mca_no)
                 except: 
-                    raise IOError, "SF_SCAN+SF_NMCA read failed"
+                    raise IOError("SF_SCAN+SF_NMCA read failed")
             elif scan_type==SF_MESH+SF_MCA:
                 try:
                     #scan_array= scan_obj.data()
@@ -662,19 +676,19 @@ class SpecFileDataSource:
                     #mca_no= 1 + int(key_split[2]) + int(key_split[3])*mot1
                     mca_no= (int(key_split[2])-1)*scan_info["NbMcaDet"] + int(key_split[3])
                     if DEBUG:
-                        print "try to read mca number = ",mca_no
-                        print "total number of mca = ",scan_info["NbMca"]
+                        print("try to read mca number = ",mca_no)
+                        print("total number of mca = ",scan_info["NbMca"])
                     scan_data= scan_obj.mca(mca_no)
                 except: 
-                    raise IOError, "SF_MESH+SF_MCA read failed"
+                    raise IOError("SF_MESH+SF_MCA read failed")
             elif scan_type&SF_NMCA or scan_type&SF_MCA:
                 try:
                     mca_no= (int(key_split[2])-1)*scan_info["NbMcaDet"] + int(key_split[3])
                     scan_data= scan_obj.mca(mca_no)
                 except:
-                    raise IOError, "SF_MCA or SF_NMCA read failed"
+                    raise IOError("SF_MCA or SF_NMCA read failed")
             else:
-                raise TypeError, "Unknown scan type!!!!!!!!!!!!!!!!"
+                raise TypeError("Unknown scan type!!!!!!!!!!!!!!!!")
             if scan_data is not None:
                 scan_info.update(self.__getMcaInfo(mca_no, scan_obj, scan_info))
                 dataObject = DataObject.DataObject()
@@ -740,16 +754,16 @@ def DataSource(name="", source_type=SOURCE_TYPE):
      sourceClass = source_types[source_type]
   except KeyError:
      #ERROR invalid source type
-     raise TypeError,"Invalid Source Type, source type should be one of %s" % source_types.keys()
+     raise TypeError("Invalid Source Type, source type should be one of %s" % source_types.keys())
   
   return sourceClass(name)
 
   
 if __name__ == "__main__":
-    import sys,time
+    import time
 
     if len(sys.argv) not in [2,3,4]:
-        print "Usage: %s <filename> [<key_to_load>]"
+        print("Usage: %s <filename> [<key_to_load>]")
         sys.exit()
 
     filename= sys.argv[1]
@@ -757,13 +771,13 @@ if __name__ == "__main__":
     sf = DataSource(filename)
     if len(sys.argv)==2:
         info= sf.getSourceInfo()
-        print "Filename        :", sf.sourceName
-        print "Number of scans :", info["Size"]
+        print("Filename        :", sf.sourceName)
+        print("Number of scans :", info["Size"])
 
-        print "S# - command - pts - mca - type"
+        print("S# - command - pts - mca - type")
         for (s,c,p,m,t) in zip(info["KeyList"],info["Commands"],info["NumPts"],info["NumMca"],info["ScanType"]):
-                print s,"-",c,"-",p,"-",m,"-",t
-        print "KeyList = ",info["KeyList"]
+                print(s,"-",c,"-",p,"-",m,"-",t)
+        print("KeyList = ",info["KeyList"])
         #print info['Channel0']
 
     if len(sys.argv)==3:
@@ -773,13 +787,13 @@ if __name__ == "__main__":
         info= dataObject.info
         data= dataObject.data
 
-        print "Filename   :", info['SourceName']
-        print "Loaded key :", info["Key"]
-        print "Header     :"
+        print("Filename   :", info['SourceName'])
+        print("Loaded key :", info["Key"])
+        print("Header     :")
         for i,v in info.items():
-                print "-", i, ":", v
-        print "Data Shape :", data.shape
-        print "read time = ",t0
+                print("-", i, ":", v)
+        print("Data Shape :", data.shape)
+        print("read time = ",t0)
 
     if len(sys.argv)==4:
         t0 = time.time()
@@ -790,7 +804,7 @@ if __name__ == "__main__":
         t0 = time.time() - t0
         info= dataObject.info
         #print dataObject.x
-        print dataObject.y
+        print(dataObject.y)
         #print dataObject.x
 
  
