@@ -1,5 +1,5 @@
 #/*##########################################################################
-# Copyright (C) 2004-2010 European Synchrotron Radiation Facility
+# Copyright (C) 2004-2012 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMCA X-ray Fluorescence Toolkit developed at
 # the ESRF by the Beamline Instrumentation Software Support (BLISS) group.
@@ -24,12 +24,11 @@
 # Please contact the ESRF industrial unit (industry@esrf.fr) if this license 
 # is a problem for you.
 #############################################################################*/
-__revision__ = "$Revision: 1.14 $"
+__revision__ = "$Revision: 1.15 $"
 import numpy
 from numpy.oldnumeric import *
 arctan = numpy.arctan
 import SpecfitFuns
-import string
 import os
 from Gefit import LeastSquaresFit
 
@@ -158,6 +157,24 @@ class SpecfitFunctions:
        return SpecfitFuns.apvoigt(pars,x)
        #return pars[0] + pars [1] * x + SpecfitFuns.apvoigt(pars[2:len(pars)],x)
 
+    def splitgauss(self,pars,x):
+       """
+       Asymmetric gaussian.
+       """
+       return SpecfitFuns.splitgauss(pars,x)
+
+    def splitlorentz(self,pars,x):
+       """
+       Asymmetric lorentz.
+       """
+       return SpecfitFuns.splitlorentz(pars,x)
+
+    def splitpvoigt(self,pars,x):
+       """
+       Asymmetric pseudovoigt.
+       """
+       return SpecfitFuns.splitpvoigt(pars,x)
+
     def stepdown(self,pars,x):
         """
         A fit function.
@@ -250,7 +267,6 @@ class SpecfitFunctions:
         bterm = param[1] * t + param[0]
         return gterm + bterm
 
-
     def estimate(self,x,y,z,xscaling=1.0,yscaling=1.0):
         ngauss = input(' Number of Gaussians : ')
         ngauss=int(ngauss)
@@ -258,7 +274,7 @@ class SpecfitFunctions:
             ngauss=1
         newpar=[]
         for i in range(ngauss):
-            print "Defining Gaussian numer %d " % (i+1)
+            print("Defining Gaussian numer %d " % (i+1))
             newpar.append(input('Height   = '))
             newpar.append(input('Position = '))
             newpar.append(input('FWHM     = '))
@@ -308,7 +324,7 @@ class SpecfitFunctions:
         if npoints > (1.5)*search_fwhm:
             peaks=SpecfitFuns.seek(ysearch,0,npoints,
                                     search_fwhm,
-                                    search_sensitivity)       
+                                    search_sensitivity)
         else:
             peaks=[]
         
@@ -328,12 +344,12 @@ class SpecfitFunctions:
         return peaks
 
 
-    def guess_fwhm(self,**kw):
-        if kw.has_key('y'):
+    def guess_fwhm(self, **kw):
+        if 'y' in kw:
             y=kw['y']
         else:
             return self.config['FwhmPoints']
-        if kw.has_key('x'):
+        if 'x' in kw:
             x=kw['x']
         else:
             x=arange(len(y))*1.0
@@ -378,9 +394,9 @@ class SpecfitFunctions:
        if self.config['AutoFwhm']:
             search_fwhm=self.guess_fwhm(x=xx,y=yy)
        else: 
-            search_fwhm=int(string.atof(self.config['FwhmPoints']))
-       search_sens=string.atof(self.config['Sensitivity'])
-       search_mca=int(string.atof(self.config['McaMode']))
+            search_fwhm=int(float(self.config['FwhmPoints']))
+       search_sens=float(self.config['Sensitivity'])
+       search_mca=int(float(self.config['McaMode']))
        
        if search_fwhm < 3:
             search_fwhm = 3
@@ -403,8 +419,8 @@ class SpecfitFunctions:
        else:
             peaks = []
        if not len(peaks):
-            mca = int(string.atof(self.config.get('McaMode', 0)))
-            forcePeak =  int(string.atof(self.config.get('ForcePeakPresence', 0)))
+            mca = int(float(self.config.get('McaMode', 0)))
+            forcePeak =  int(float(self.config.get('ForcePeakPresence', 0)))
             if (not mca) and forcePeak:
                 delta = yy - zz
                 peaks  = [int(numpy.nonzero(delta == delta.max())[0])]
@@ -536,7 +552,7 @@ class SpecfitFunctions:
     def estimate_agauss(self,xx,yy,zzz,xscaling=1.0,yscaling=None):
         fittedpar,cons = self.estimate_gauss(xx,yy,zzz,xscaling,yscaling)
         #get the number of found peaks
-        npeaks=len(cons[0])/3
+        npeaks=int(len(cons[0])/3)
         for i in range(npeaks):
             height = fittedpar[3*i]
             fwhm = fittedpar[3*i+2]
@@ -544,18 +560,74 @@ class SpecfitFunctions:
         return fittedpar,cons
 
     def estimate_alorentz(self,xx,yy,zzz,xscaling=1.0,yscaling=None):
-       fittedpar,cons = self.estimate_gauss(xx,yy,zzz,xscaling,yscaling)
-       #get the number of found peaks
-       npeaks=len(cons[0])/3
-       for i in range(npeaks):
+        fittedpar,cons = self.estimate_gauss(xx,yy,zzz,xscaling,yscaling)
+        #get the number of found peaks
+        npeaks=int(len(cons[0])/3)
+        for i in range(npeaks):
             height = fittedpar[3*i]
             fwhm = fittedpar[3*i+2]
             fittedpar[3*i] = (height * fwhm * 0.5 *pi)
-       return fittedpar,cons
+        return fittedpar,cons
+
+    def estimate_splitgauss(self,xx,yy,zzz,xscaling=1.0,yscaling=None):
+        fittedpar, cons = self.estimate_gauss(xx,yy,zzz,xscaling,yscaling)
+        #get the number of found peaks
+        npeaks=int(len(cons[0])/3)
+        estimated_parameters = []
+        estimated_constraints = zeros((3, 4*npeaks),Float)
+        for i in range(npeaks):
+            for j in range(3):
+                estimated_parameters.append(fittedpar[3*i+j])
+            estimated_parameters.append(fittedpar[3*i+2])
+            estimated_constraints[0][4*i]   = cons [0][3*i]
+            estimated_constraints[0][4*i+1] = cons [0][3*i+1]
+            estimated_constraints[0][4*i+2] = cons [0][3*i+2]
+            estimated_constraints[0][4*i+3] = cons [0][3*i+2]
+            estimated_constraints[1][4*i]   = cons [1][3*i]
+            estimated_constraints[1][4*i+1] = cons [1][3*i+1]
+            estimated_constraints[1][4*i+2] = cons [1][3*i+2]
+            estimated_constraints[1][4*i+3] = cons [1][3*i+2]
+            estimated_constraints[2][4*i]   = cons [2][3*i]
+            estimated_constraints[2][4*i+1] = cons [2][3*i+1]
+            estimated_constraints[2][4*i+2] = cons [2][3*i+2]
+            estimated_constraints[2][4*i+3] = cons [2][3*i+2]
+            if cons[0][3*i+2] == 4:
+                #same FWHM case
+                estimated_constraints[1][4*i+2] = int(cons[1][3*i+2]/3) * 4 + 2
+                estimated_constraints[1][4*i+3] = int(cons[1][3*i+2]/3) * 4 + 3         
+        return estimated_parameters, estimated_constraints
+        
+    def estimate_splitlorentz(self,xx,yy,zzz,xscaling=1.0,yscaling=None):
+        fittedpar, cons = self.estimate_gauss(xx,yy,zzz,xscaling,yscaling)
+        #get the number of found peaks
+        npeaks=int(len(cons[0])/3)
+        estimated_parameters = []
+        estimated_constraints = zeros((3, 4*npeaks),Float)
+        for i in range(npeaks):
+            for j in range(3):
+                estimated_parameters.append(fittedpar[3*i+j])
+            estimated_parameters.append(fittedpar[3*i+2])
+            estimated_constraints[0][4*i]   = cons [0][3*i]
+            estimated_constraints[0][4*i+1] = cons [0][3*i+1]
+            estimated_constraints[0][4*i+2] = cons [0][3*i+2]
+            estimated_constraints[0][4*i+3] = cons [0][3*i+2]
+            estimated_constraints[1][4*i]   = cons [1][3*i]
+            estimated_constraints[1][4*i+1] = cons [1][3*i+1]
+            estimated_constraints[1][4*i+2] = cons [1][3*i+2]
+            estimated_constraints[1][4*i+3] = cons [1][3*i+2]
+            estimated_constraints[2][4*i]   = cons [2][3*i]
+            estimated_constraints[2][4*i+1] = cons [2][3*i+1]
+            estimated_constraints[2][4*i+2] = cons [2][3*i+2]
+            estimated_constraints[2][4*i+3] = cons [2][3*i+2]
+            if cons[0][3*i+2] == 4:
+                #same FWHM case
+                estimated_constraints[1][4*i+2] = int(cons[1][3*i+2]/3) * 4 + 2
+                estimated_constraints[1][4*i+3] = int(cons[1][3*i+2]/3) * 4 + 3         
+        return estimated_parameters, estimated_constraints
        
     def estimate_pvoigt(self,xx,yy,zzz,xscaling=1.0,yscaling=None):
        fittedpar,cons = self.estimate_gauss(xx,yy,zzz,xscaling,yscaling)
-       npeaks=len(cons[0])/3
+       npeaks=int(len(cons[0])/3)
        newpar=[]
        newcons=zeros((3,4*npeaks),Float)
        #find out related parameters proper index
@@ -595,9 +667,62 @@ class SpecfitFunctions:
                       newcons[2][4*i+3]=1.0
        return  newpar,newcons
 
+    def estimate_splitpvoigt(self,xx,yy,zzz,xscaling=1.0,yscaling=None):
+       fittedpar,cons = self.estimate_gauss(xx,yy,zzz,xscaling,yscaling)
+       npeaks=int(len(cons[0])/3)
+       newpar=[]
+       newcons=zeros((3,5*npeaks),Float)
+       #find out related parameters proper index
+       if self.config['NoConstrainsFlag'] == 0:
+            if self.config['SameFwhmFlag']:
+                j=0
+                #get the index of the free FWHM
+                for i in range(npeaks):
+                    if cons[0][3*i+2] != 4:
+                        j=i
+                for i in range(npeaks):
+                    if i != j:
+                       cons[1][3*i+2] = 4*j+2 
+       for i in range(npeaks):
+            #height
+            newpar.append(fittedpar[3*i])
+            #position
+            newpar.append(fittedpar[3*i+1])
+            #fwhm1
+            newpar.append(fittedpar[3*i+2])
+            #fwhm2 equal to the first
+            newpar.append(fittedpar[3*i+2])
+            #eta
+            newpar.append(0.5)
+            newcons[0][5*i]=cons[0][3*i]
+            newcons[0][5*i+1]=cons[0][3*i+1]
+            newcons[0][5*i+2]=cons[0][3*i+2]
+            newcons[0][5*i+3]=cons[0][3*i+2]
+            newcons[1][5*i]=cons[1][3*i]
+            newcons[1][5*i+1]=cons[1][3*i+1]
+            newcons[1][5*i+2]=cons[1][3*i+2]
+            newcons[1][5*i+3]=cons[1][3*i+2]
+            newcons[2][5*i]=cons[2][3*i]
+            newcons[2][5*i+1]=cons[2][3*i+1]
+            newcons[2][5*i+2]=cons[2][3*i+2]
+            newcons[2][5*i+3]=cons[2][3*i+2]
+            if cons[0][3*i+2] == 4:
+                newcons[1][5*i+3] = newcons[1][5*i+2]+1                
+            #Eta constrains
+            newcons[0][5*i+4]=0
+            newcons[1][5*i+4]=0
+            newcons[2][5*i+4]=0
+            if self.config['NoConstrainsFlag'] == 0:
+                if self.config['EtaFlag']:
+                      #QUOTED=2
+                      newcons[0][5*i+4]=2
+                      newcons[1][5*i+4]=0.0              
+                      newcons[2][5*i+4]=1.0
+       return  newpar,newcons
+
     def estimate_apvoigt(self,xx,yy,zzz,xscaling=1.0,yscaling=None):
        fittedpar,cons = self.estimate_pvoigt(xx,yy,zzz,xscaling,yscaling)
-       npeaks=len(cons[0])/4
+       npeaks=int(len(cons[0])/4)
        for i in range(npeaks):
             height = fittedpar[4*i]
             fwhm = fittedpar[4*i+2]
@@ -616,7 +741,7 @@ class SpecfitFunctions:
             yscaling=1.0
        """ 
        fittedpar,cons = self.estimate_gauss(xx,yy,zzz,xscaling,yscaling)
-       npeaks=len(cons[0])/3
+       npeaks=int(len(cons[0])/3)
        newpar=[]
        newcons=zeros((3,8*npeaks),Float)
        main_peak=0
@@ -745,7 +870,7 @@ class SpecfitFunctions:
             if self.config['QuotedPositionFlag']:
                 for i in range(npeaks):
                     delta=self.config['DeltaPositionFwhmUnits'] * \
-                      int(string.atof(self.config['FwhmPoints']))
+                      int(float(self.config['FwhmPoints']))
                     #that was delta in points
                     #I need it in terms of FWHM
                     delta=self.config['DeltaPositionFwhmUnits'] * fwhm
@@ -780,7 +905,7 @@ class SpecfitFunctions:
             yy = yy * max(yyy)/max(yy)
         xx=xxx[2:-2]
         fittedpar,cons=self.estimate_agauss(xx,yy,zzz,xscaling,yscaling)
-        npeaks=len(cons[0])/4
+        npeaks=int(len(cons[0])/4)
         largest_index=0
         largest=[fittedpar[3*largest_index],
                  fittedpar[3*largest_index+1],
@@ -875,7 +1000,7 @@ class SpecfitFunctions:
             yy = yy * max(yyy)/max(yy)
         xx=xxx[2:-2]
         fittedpar,cons=self.estimate_agauss(xx,yy,zzz,xscaling,yscaling)
-        npeaks=len(cons[0])/4
+        npeaks=int(len(cons[0])/4)
         largest_index=0
         largest=[fittedpar[3*largest_index],
                  fittedpar[3*largest_index+1],
@@ -931,9 +1056,9 @@ class SpecfitFunctions:
         if self.config['AutoFwhm']:
             search_fwhm=self.guess_fwhm(x=xx,y=yy)
         else: 
-            search_fwhm=int(string.atof(self.config['FwhmPoints']))
-        search_sens=string.atof(self.config['Sensitivity'])
-        search_mca=int(string.atof(self.config['McaMode']))
+            search_fwhm=int(float(self.config['FwhmPoints']))
+        search_sens=float(self.config['Sensitivity'])
+        search_mca=int(float(self.config['McaMode']))
        
         if search_fwhm < 3:
             search_fwhm = 3
@@ -1026,7 +1151,7 @@ class SpecfitFunctions:
             notdone=1
             #take care of lower / upper case problems ...
             for config_key in self.config.keys():
-                if string.lower(config_key) == string.lower(key):
+                if config_key.lower() == key.lower():
                     self.config[config_key] = kw[key]
                     notdone=0
             if notdone:
@@ -1041,6 +1166,9 @@ FUNCTION=[fitfuns.gauss,
           fitfuns.alorentz,
           fitfuns.pvoigt,
           fitfuns.apvoigt,
+          fitfuns.splitgauss,
+          fitfuns.splitlorentz,
+          fitfuns.splitpvoigt,
           fitfuns.stepdown,
           fitfuns.stepup,
           fitfuns.slit,
@@ -1054,6 +1182,9 @@ PARAMETERS=[['Height','Position','FWHM'],
             ['Area','Position','Fwhm'],
             ['Height','Position','Fwhm','Eta'],
             ['Area','Position','Fwhm','Eta'],
+            ['Height','Position','LowFWHM', 'HighFWHM'],
+            ['Height','Position','LowFWHM', 'HighFWHM'],
+            ['Height','Position','LowFWHM', 'HighFWHM', 'Eta'],
             ['Height','Position','FWHM'],
             ['Height','Position','FWHM'],
             ['Height','Position','FWHM','BeamFWHM'],
@@ -1068,6 +1199,9 @@ THEORY=['Gaussians',
         'Area Lorentz',
         'Pseudo-Voigt Line',
         'Area Pseudo-Voigt',
+        'Split Gaussian',
+        'Split Lorentz',
+        'Split Pseudo-Voigt',
         'Step Down',
         'Step Up',
         'Slit',
@@ -1081,6 +1215,9 @@ ESTIMATE=[fitfuns.estimate_gauss,
           fitfuns.estimate_alorentz,
           fitfuns.estimate_pvoigt,
           fitfuns.estimate_apvoigt,
+          fitfuns.estimate_splitgauss,
+          fitfuns.estimate_splitlorentz,
+          fitfuns.estimate_splitpvoigt,
           fitfuns.estimate_stepdown,
           fitfuns.estimate_stepup,
           fitfuns.estimate_slit,
@@ -1099,6 +1236,9 @@ CONFIGURE=[fitfuns.configure,
            fitfuns.configure,
            fitfuns.configure,
            fitfuns.configure,
+           fitfuns.configure,
+           fitfuns.configure,
+           fitfuns.configure,
            fitfuns.configure]
 
 def test(a):
@@ -1126,7 +1266,7 @@ def test(a):
     fit.estimate()
     fit.startfit()
     yfit=fit.gendata(x=x,parameters=fit.paramlist)
-    print "I set an offset of 1 to see the difference in log scale :-)"
+    print("I set an offset of 1 to see the difference in log scale :-)")
     w = ScanWindow.ScanWindow()
     w.addCurve(x, y + 1, "Data + 1")
     w.addCurve(x, yfit, "Fit")
