@@ -1,5 +1,5 @@
 #/*##########################################################################
-# Copyright (C) 2004-2009 European Synchrotron Radiation Facility
+# Copyright (C) 2004-2011 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMCA X-ray Fluorescence Toolkit developed at
 # the ESRF by the Beamline Instrumentation Software Support (BLISS) group.
@@ -27,6 +27,7 @@
 import EventHandler
 import Specfit
 import sys
+import os
 
 import PyMcaQt as qt
     
@@ -36,10 +37,8 @@ import MultiParameters
 import FitActionsGUI
 import FitStatusGUI
 import EventHandler
-if 1 or QTVERSION < '4.0.0':
-    import QScriptOption
-else:
-    print "QScriptOption not ported yet"
+import QScriptOption
+DEBUG = 0
 
 class SpecfitGUI(qt.QWidget):
     def __init__(self,parent = None,name = None,fl = 0, specfit = None,
@@ -58,9 +57,17 @@ class SpecfitGUI(qt.QWidget):
             self.eh = eh
         if specfit is None:
             self.specfit = Specfit.Specfit(eh=self.eh)
-            self.specfit.importfun("SpecfitFunctions.py")
         else:
             self.specfit = specfit
+
+        #initialize the default fitting functions in case
+        #none is present
+        if not len(self.specfit.theorylist):
+            funsFile = "SpecfitFunctions.py"
+            if not os.path.exists(funsFile):
+                funsFile = os.path.join(os.path.dirname(Specfit.__file__),\
+                                funsFile)
+            self.specfit.importfun(funsFile)
         
         #copy specfit configure method for direct access
         self.configure=self.specfit.configure
@@ -118,9 +125,11 @@ class SpecfitGUI(qt.QWidget):
                 else:
                     self.funevent(configuration['fittheory'])
                 if configuration['fitbkg']    is None:
-                    if QTVERSION < '4.0.0': self.guiconfig.BkgComBox.setCurrentItem(1)
-                    else: self.guiconfig.BkgComBox.setCurrentIndex(1)
-                    self.bkgevent(self.specfit.bkgdict.keys()[0])
+                    if QTVERSION < '4.0.0':
+                        self.guiconfig.BkgComBox.setCurrentItem(1)
+                    else:
+                        self.guiconfig.BkgComBox.setCurrentIndex(1)
+                    self.bkgevent(list(self.specfit.bkgdict.keys())[0])
                 else:
                     self.bkgevent(configuration['fitbkg'])
             else:
@@ -131,7 +140,7 @@ class SpecfitGUI(qt.QWidget):
                     self.guiconfig.BkgComBox.setCurrentIndex(1)
                     self.guiconfig.FunComBox.setCurrentIndex(1)
                 self.funevent(self.specfit.theorylist[0])
-                self.bkgevent(self.specfit.bkgdict.keys()[0])
+                self.bkgevent(list(self.specfit.bkgdict.keys())[0])
             configuration.update(self.configure())
             if configuration['McaMode']:            
                 self.guiconfig.MCACheckBox.setChecked(1)
@@ -189,18 +198,21 @@ class SpecfitGUI(qt.QWidget):
                     self.guiconfig.FunComBox.setCurrentIndex(i)
                 self.funevent(self.specfit.fitconfig['fittheory'])
             except:
-                print  "Function not in list"
+                print("Function not in list %s" %\
+                      self.specfit.fitconfig['fittheory'])
                 self.funevent(self.specfit.theorylist[0])
             #current background
             try:
-                i=1+self.specfit.bkgdict.keys().index(self.specfit.fitconfig['fitbkg'])
+                #the list conversion is needed in python 3.
+                i=1+list(self.specfit.bkgdict.keys()).index(self.specfit.fitconfig['fitbkg'])
                 if QTVERSION < '4.0.0':
                     self.guiconfig.BkgComBox.setCurrentItem(i)
                 else:
                     self.guiconfig.BkgComBox.setCurrentIndex(i)
             except:
-                print "Background not in list"
-                self.bkgevent(self.specfit.bkgdict.keys()[0])
+                print("Background not in list %s" %\
+                      self.specfit.fitconfig['fitbkg'])
+                self.bkgevent(list(self.specfit.bkgdict.keys())[0])
             #and all the rest
             if configuration['McaMode']:            
                 self.guiconfig.MCACheckBox.setChecked(1)
@@ -280,6 +292,8 @@ class SpecfitGUI(qt.QWidget):
                     self.emit(qt.PYSIGNAL('SpecfitGUISignal'),(ddict,))
                 else:
                     self.emit(qt.SIGNAL('SpecfitGUISignal'), ddict)
+                if DEBUG:
+                    raise
                 return
             self.guiparameters.fillfrommca(mcaresult)
             ddict={}
@@ -308,11 +322,15 @@ class SpecfitGUI(qt.QWidget):
                         msg.exec_()
                     return
             except:
+                if DEBUG:
+                    raise
                 msg = qt.QMessageBox(self)
                 msg.setIcon(qt.QMessageBox.Critical)
                 msg.setText("Error on estimate: %s" % sys.exc_info()[1])
-                if QTVERSION < '4.0.0':msg.exec_loop()
-                else: msg.exec_()
+                if QTVERSION < '4.0.0':
+                    msg.exec_loop()
+                else:
+                    msg.exec_()
                 return
             self.guiparameters.fillfromfit(self.specfit.paramlist,current='Fit')
             self.guiparameters.removeallviews(keep='Fit')
@@ -340,8 +358,12 @@ class SpecfitGUI(qt.QWidget):
                 msg = qt.QMessageBox(self)
                 msg.setIcon(qt.QMessageBox.Critical)
                 msg.setText("Error on mcafit: %s" % sys.exc_info()[1])
-                if QTVERSION < '4.0.0':msg.exec_loop()
-                else: msg.exec_()
+                if QTVERSION < '4.0.0':
+                    msg.exec_loop()
+                else:
+                    msg.exec_()
+                if DEBUG:
+                    raise
                 return
             self.guiparameters.fillfrommca(mcaresult)
             ddict={}
@@ -356,16 +378,23 @@ class SpecfitGUI(qt.QWidget):
             #for param in self.specfit.paramlist:
             #    print param['name'],param['group'],param['estimation']
             self.specfit.paramlist=self.guiparameters.fillfitfromtable()
-            #for param in self.specfit.paramlist:
-            #    print param['name'],param['group'],param['estimation']
+            if DEBUG:
+                for param in self.specfit.paramlist:
+                    print(param['name'],param['group'],param['estimation'])
+                print("TESTING")
+                self.specfit.startfit()
             try:
                 self.specfit.startfit()
             except:
                 msg = qt.QMessageBox(self)
                 msg.setIcon(qt.QMessageBox.Critical)
                 msg.setText("Error on Fit")
-                if QTVERSION < '4.0.0':msg.exec_loop()
-                else: msg.exec_()
+                if QTVERSION < '4.0.0':
+                    msg.exec_loop()
+                else:
+                    msg.exec_()
+                if DEBUG:
+                    raise
                 return
             self.guiparameters.fillfromfit(self.specfit.paramlist,current='Fit')
             self.guiparameters.removeallviews(keep='Fit')
@@ -558,8 +587,8 @@ class SpecfitGUI(qt.QWidget):
                                        'xmax':None})
         if self.specfit.fitconfig['fittheory'] is not None:
           for pname in self.specfit.theorydict[self.specfit.fitconfig['fittheory']][1]:
-            self.specfit.final_theory.append(pname+`1`)
-            self.specfit.paramlist.append({'name':pname+`1`,
+            self.specfit.final_theory.append(pname+"1")
+            self.specfit.paramlist.append({'name':pname+"1",
                                        'estimation':0,
                                        'group':1,
                                        'code':'FREE',
@@ -578,14 +607,14 @@ class SpecfitGUI(qt.QWidget):
         return
 
     def fitstatus(self,data):
-        if data.has_key('chisq'):
+        if 'chisq' in data:
             if data['chisq'] is None:
                 self.guistatus.ChisqLine.setText(" ")
             else:
                 chisq=data['chisq']
                 self.guistatus.ChisqLine.setText("%6.2f" % chisq)
             
-        if data.has_key('status'):
+        if 'status' in data:
             status=data['status']
             self.guistatus.StatusLine.setText(str(status))
         return
@@ -633,6 +662,3 @@ if __name__ == "__main__":
     else:
         w.show()
         a.exec_()
-
-
-    
