@@ -1,5 +1,5 @@
 #/*##########################################################################
-# Copyright (C) 2004-2010 European Synchrotron Radiation Facility
+# Copyright (C) 2004-2012 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMCA X-ray Fluorescence Toolkit developed at
 # the ESRF by the Beamline Instrumentation Software Support (BLISS) group.
@@ -75,50 +75,80 @@ class StackBase(object):
         self._ROIImageList = []
         self._ROIImageNames = []
 
+        self.__pluginDirList = []
         self.pluginList = []
         self.pluginInstanceDict = {}
         self.getPlugins()
 
+    def setPluginDirectoryList(self, dirlist):
+        for directory in dirlist:
+            if not os.path.exists(directory):
+                raise IOError("Directory:\n%s\ndoes not exist." % directory)                
+
+        self.__pluginDirList = dirlist
+
+    def getPluginDirectoryList(self):
+        return self.__pluginDirList
+
     def getPlugins(self):
         """
         Import or reloads all the available plugins.
         It returns the number of plugins loaded.
         """
-        if PLUGINS_DIR is None:
-            return 0
-        directory = PLUGINS_DIR
-        if not os.path.exists(directory):
-            raise IOError, "Directory:\n%s\ndoes not exist." % directory
 
+        if self.__pluginDirList == []:
+           self.__pluginDirList = [PLUGINS_DIR] 
         self.pluginList = []
-        fileList = glob.glob(os.path.join(directory, "*.py"))
-        targetMethod = 'getStackPluginInstance'
-        for module in fileList:
-            try:
-                pluginName = os.path.basename(module)[:-3]
-                plugin = "PyMcaPlugins." + pluginName
-                if pluginName in self.pluginList:
-                    idx = self.pluginList.index(pluginName)
-                    del self.pluginList[idx]
-                if plugin in self.pluginInstanceDict.keys():
-                    del self.pluginInstanceDict[plugin]
-                if plugin in sys.modules:
+        for directory in self.__pluginDirList:
+            if directory is None:
+                continue
+            if not os.path.exists(directory):
+                raise IOError("Directory:\n%s\ndoes not exist." % directory)
+            
+            fileList = glob.glob(os.path.join(directory, "*.py"))
+            targetMethod = 'getStackPluginInstance'
+            for module in fileList:
+                try:
+                    pluginName = os.path.basename(module)[:-3]
+                    if directory == PLUGINS_DIR:
+                        plugin = "PyMcaPlugins." + pluginName
+                    else:
+                        plugin = pluginName
+                        if directory not in sys.path:
+                            sys.path.insert(0, directory)
+                    if pluginName in self.pluginList:
+                        idx = self.pluginList.index(pluginName)
+                        del self.pluginList[idx]
+                    if plugin in self.pluginInstanceDict.keys():
+                        del self.pluginInstanceDict[plugin]
+                    if plugin in sys.modules:
+                        if hasattr(sys.modules[plugin], targetMethod):
+                            if sys.version < '3.0':
+                                reload(sys.modules[plugin])
+                            else:
+                                import imp
+                                imp.reload(sys.modules[plugin])                            
+                    else:
+                        __import__(plugin)
                     if hasattr(sys.modules[plugin], targetMethod):
-                        reload(sys.modules[plugin])
-                else:
-                    __import__(plugin)
-                if hasattr(sys.modules[plugin], targetMethod):
-                    self.pluginInstanceDict[plugin] = \
-                            sys.modules[plugin].getStackPluginInstance(self)
-                    self.pluginList.append(plugin)
-            except:
-                if DEBUG:
-                    print "Problem importing module %s" % plugin
-                    raise
+                        self.pluginInstanceDict[plugin] = \
+                                sys.modules[plugin].getStackPluginInstance(self)
+                        self.pluginList.append(plugin)
+                except:
+                    if DEBUG:
+                        print("Problem importing module %s" % plugin)
+                        raise
         return len(self.pluginList)
 
     def setStack(self, stack, mcaindex=2, fileindex=None):
-        if isinstance(stack, DataObject.DataObject):
+        #unfortunaly python 3 reports
+        #isinstance(stack, DataObject.DataObject) as false
+        #for DataObject derived classes like OmnicMap!!!!
+        if isinstance(stack, DataObject.DataObject) or\
+           ("DataObject.DataObject" in ("%s" % type(stack))) or\
+           ("QStack" in ("%s" % type(stack))) or\
+           ("Map" in ("%s" % type(stack)))or\
+           ("Stack" in ("%s" % type(stack))):
             self._stack = stack
             self._stack.info['SourceName'] = stack.info.get('SourceName',
                                                             "Data of unknown origin")
@@ -128,6 +158,9 @@ class StackBase(object):
 
         info = self._stack.info
         mcaIndex  = info.get('McaIndex', mcaindex)
+        if (mcaIndex <0) and (len(self._stack.data.shape) == 3):
+            mcaIndex = len(self._stack.data.shape) + mcaIndex
+
         fileIndex = info.get('FileIndex', fileindex)
 
         if fileIndex is None:
@@ -161,7 +194,8 @@ class StackBase(object):
             self._stackImageData = numpy.sum(self._stack.data, self.mcaIndex)
             #original ICR mca
             if DEBUG:
-                print "(self.otherIndex, self.fileIndex) = ", (self.otherIndex, self.fileIndex)
+                print("(self.otherIndex, self.fileIndex) = (%d, %d)" %\
+                      (self.otherIndex, self.fileIndex))
             i = max(self.otherIndex, self.fileIndex)
             j = min(self.otherIndex, self.fileIndex)                
             mcaData0 = numpy.sum(numpy.sum(self._stack.data, i), j) * 1.0
@@ -169,11 +203,16 @@ class StackBase(object):
             if DEBUG:
                 t0 = time.time()
             shape = self._stack.data.shape
-            if self.mcaIndex == 2:
+            if self.mcaIndex in [2, -1]:
                 self._stackImageData = numpy.zeros((shape[0], shape[1]),
                                                 self._stack.data.dtype)
                 mcaData0 = numpy.zeros((shape[2],), numpy.float)
                 step = 1
+                if hasattr(self._stack, "monitor"):
+                    monitor = self._stack.monitor[:]
+                    monitor.shape = shape[2]
+                else:
+                    monitor = numpy.ones((shape[2],), numpy.float)
                 for i in range(shape[0]):
                     tmpData = self._stack.data[i:i+step,:,:]
                     numpy.add(self._stackImageData[i:i+step,:],
@@ -193,11 +232,13 @@ class StackBase(object):
                               tmpData,
                               self._stackImageData)
                     mcaData0[i] = tmpData.sum()
+            else:
+                raise ValueError("Unhandled case 1D index = %d" % self.mcaIndex)
             if DEBUG:
-                print "Print dynamic loading elapsed = ", time.time() -t0
+                print("Print dynamic loading elapsed = %f" % (time.time() -t0))
 
         if DEBUG:
-            print "__stackImageData.shape = ",  self._stackImageData.shape               
+            print("__stackImageData.shape = ",  self._stackImageData.shape)               
         calib = self._stack.info.get('McaCalib', [0.0, 1.0, 0.0])
         dataObject = DataObject.DataObject()
         dataObject.info = {"McaCalib": calib,
@@ -217,7 +258,11 @@ class StackBase(object):
         self.showOriginalImage()
 
         #add the mca
-        self.showOriginalMca()
+        goodData = numpy.isfinite(self._mcaData0.y[0].sum())
+        if goodData:
+            self.showOriginalMca()
+        else:
+            self.handleNonFiniteData()
 
         #calculate the ROIs
         self._ROIDict = {'name': "ICR",
@@ -230,6 +275,9 @@ class StackBase(object):
         for key in self.pluginInstanceDict.keys():
             self.pluginInstanceDict[key].stackUpdated()
 
+    def handleNonFiniteData(self):
+        pass
+
     def updateROIImages(self, ddict=None):
         if ddict is None:
             updateROIDict = False
@@ -256,14 +304,14 @@ class StackBase(object):
                     i1 = min(i1)
                 else:
                     if DEBUG:
-                        print "updateROIImages: nothing to be made"
+                        print("updateROIImages: nothing to be made")
                     return
                 i2 = numpy.nonzero(xw <= ddict['to'])[0]
                 if len(i2):
                     i2 = max(i2) + 1
                 else:
                     if DEBUG:
-                        print "updateROIImages: nothing to be made"
+                        print("updateROIImages: nothing to be made")
                     return
                 pos = 0.5 * (ddict['from'] + ddict['to'])
                 imiddle = max(numpy.nonzero(xw <= pos)[0])
@@ -273,14 +321,14 @@ class StackBase(object):
                     i2 = max(i2)
                 else:
                     if DEBUG:
-                        print "updateROIImages: nothing to be made"
+                        print("updateROIImages: nothing to be made")
                     return
                 i1 = numpy.nonzero(xw <= ddict['to'])[0]
                 if len(i1):
                     i1 = min(i1) + 1
                 else:
                     if DEBUG:
-                        print "updateROIImages: nothing to be made"
+                        print("updateROIImages: nothing to be made")
                     return
                 pos = 0.5 * (ddict['from'] + ddict['to'])
                 imiddle = min(numpy.nonzero(xw <= pos)[0])
@@ -309,7 +357,7 @@ class StackBase(object):
         roiKeys = ['ROI', 'Maximum', 'Minimum', 'Left', 'Middle', 'Right', 'Background']
         nImages = len(roiKeys)
         imageList  = [None] * nImages
-        for i in xrange(nImages):
+        for i in range(nImages):
             key = roiKeys[i]
             imageList[i] = self._ROIImageDict[key]
 
@@ -337,11 +385,11 @@ class StackBase(object):
                     
     def showOriginalImage(self):
         if DEBUG:
-            print "showOriginalImage to be implemented" 
+            print("showOriginalImage to be implemented")
 
     def showOriginalMca(self):
         if DEBUG:
-            print "showOriginalMca to be implemented" 
+            print("showOriginalMca to be implemented")
 
     def showROIImageList(self, imageList, image_names=None):
         self._ROIImageList  = imageList
@@ -360,7 +408,8 @@ class StackBase(object):
         if self._stackImageData is None:
             return
         mcaData = None
-        if self._selectionMask is None:
+        goodData = numpy.isfinite(self._mcaData0.y[0].sum())
+        if (self._selectionMask is None) and goodData:
             if normalize:
                 npixels = self._stackImageData.shape[0] *\
                           self._stackImageData.shape[1] * 1.0
@@ -371,8 +420,15 @@ class StackBase(object):
             else:
                 dataObject = self._mcaData0
             return dataObject
-        npixels = self._selectionMask.sum()
-        if npixels == 0:
+
+        #deal with NaN and inf values
+        if self._selectionMask is None:
+            actualSelectionMask = numpy.isfinite(self._stackImageData)
+        else:
+            actualSelectionMask = self._selectionMask * numpy.isfinite(self._stackImageData)
+
+        npixels = actualSelectionMask.sum()
+        if (npixels == 0) and goodData:
             if normalize:
                 npixels = self._stackImageData.shape[0] * self._stackImageData.shape[1] * 1.0
                 dataObject = DataObject.DataObject()
@@ -387,13 +443,18 @@ class StackBase(object):
 
         n_nonselected = self._stackImageData.shape[0] *\
                         self._stackImageData.shape[1] - npixels
-        if n_nonselected < npixels:
-            arrayMask = (self._selectionMask == 0)
+        if goodData:
+            if n_nonselected < npixels:
+                arrayMask = (actualSelectionMask == 0)
+            else:
+                arrayMask = (actualSelectionMask > 0)
         else:
-            arrayMask = (self._selectionMask > 0)
+                arrayMask = (actualSelectionMask > 0)
+            
         cleanMask = numpy.nonzero(arrayMask)
         if DEBUG:
-            print "self.fileIndex, self.mcaIndex", self.fileIndex, self.mcaIndex
+            print("self.fileIndex, self.mcaIndex = %d , %d" %\
+                  (self.fileIndex, self.mcaIndex))
         if DEBUG:
             t0 = time.time()            
         if len(cleanMask[0]) and len(cleanMask[1]):
@@ -405,21 +466,29 @@ class StackBase(object):
                             mcaData += self._stack.data[:,r,c]
                     else:
                         if DEBUG:
-                            print "Dynamic loading case 0"
+                            print("Dynamic loading case 0")
                         #no other choice than to read all images
                         #for the time being, one by one
-                        for i in xrange(self._stack.data.shape[0]):
-                            tmpData = self._stack.data[i:i+1,:,:]
-                            tmpData.shape = tmpData.shape[1:]
-                            mcaData[i] = (tmpData*arrayMask).sum()
+                        rMin = cleanMask[0][0]
+                        rMax = cleanMask[-1][0]
+                        cMin = cleanMask[:,1].min()
+                        cMax = cleanMask[:,1].max()
+                        #rMin, cMin = cleanMask.min(axis=0)
+                        #rMax, cMax = cleanMask.max(axis=0)
+                        tmpMask = arrayMask[rMin:(rMax+1),cMin:(cMax+1)]
+                        tmpData = numpy.zeros((1, rMax-rMin+1,cMax-cMin+1))
+                        for i in range(self._stack.data.shape[0]):
+                            tmpData[0:1,:,:] = self._stack.data[i:i+1,rMin:(rMax+1),cMin:(cMax+1)]
+                            #multiplication is faster than selection
+                            mcaData[i] = (tmpData[0]*tmpMask).sum(dtype=numpy.float)
                 elif self.mcaIndex == 1:
                     if isinstance(self._stack.data, numpy.ndarray):
                         for r, c in cleanMask:
                             mcaData += self._stack.data[r,:,c]
                     else:
-                        raise IndexError, "Dynamic loading case 1"
+                        raise IndexError("Dynamic loading case 1")
                 else:
-                    raise IndexError, "Wrong combination of indices. Case 0"
+                    raise IndexError("Wrong combination of indices. Case 0")
             elif self.fileIndex == 1:
                 if self.mcaIndex == 0:
                     if isinstance(self._stack.data, numpy.ndarray):
@@ -427,22 +496,36 @@ class StackBase(object):
                             mcaData += self._stack.data[:,r,c]
                     else:
                         if DEBUG:
-                            print "Dynamic loading case 2"
+                            print("Dynamic loading case 2")
                         #no other choice than to read all images
                         #for the time being, one by one
-                        for i in xrange(self._stack.data.shape[0]):
-                            tmpData = self._stack.data[i:i+1,:,:]
-                            tmpData.shape = tmpData.shape[1:]
-                            #multiplication is faster than selection
-                            #tmpData[arrayMask].sum() in my machine
-                            mcaData[i] = (tmpData*arrayMask).sum()
+                        if 1:
+                            rMin = cleanMask[0][0]
+                            rMax = cleanMask[-1][0]
+                            cMin = cleanMask[:,1].min()
+                            cMax = cleanMask[:,1].max()
+                            #rMin, cMin = cleanMask.min(axis=0)
+                            #rMax, cMax = cleanMask.max(axis=0)
+                            tmpMask = arrayMask[rMin:(rMax+1),cMin:(cMax+1)]
+                            tmpData = numpy.zeros((1, rMax-rMin+1,cMax-cMin+1))
+                            for i in range(self._stack.data.shape[0]):
+                                tmpData[0:1,:,:] = self._stack.data[i:i+1,rMin:(rMax+1),cMin:(cMax+1)]
+                                #multiplication is faster than selection
+                                mcaData[i] = (tmpData[0]*tmpMask).sum(dtype=numpy.float)
+                        if 0:
+                            tmpData = numpy.zeros((1, self._stack.data.shape[1],self._stack.data.shape[2]))
+                            for i in range(self._stack.data.shape[0]):
+                                tmpData[0, :, :] = self._stack.data[i:i+1,:,:]
+                                #multiplication is faster than selection
+                                #tmpData[arrayMask].sum() in my machine
+                                mcaData[i] = (tmpData[0]*arrayMask).sum(dtype=numpy.float)                        
                 elif self.mcaIndex == 2:
                     if isinstance(self._stack.data, numpy.ndarray):
                         for r, c in cleanMask:
                             mcaData += self._stack.data[r,c,:]
                     else:
                         if DEBUG:
-                            print "Dynamic loading case 3"
+                            print("Dynamic loading case 3")
                         #try to minimize access to the file
                         row_dict = {}
                         for r, c in cleanMask:
@@ -454,23 +537,23 @@ class StackBase(object):
                             r = int(key)
                             tmpMcaData = self._stack.data[r:r+1, row_dict[key],:]
                             tmpMcaData.shape = 1, -1
-                            mcaData += numpy.sum(tmpMcaData,0)
+                            mcaData += numpy.sum(tmpMcaData,axis=0,dtype=numpy.float)
                 else:
-                    raise IndexError, "Wrong combination of indices. Case 1"
+                    raise IndexError("Wrong combination of indices. Case 1")
             elif self.fileIndex == 0:
                 if self.mcaIndex == 1:
                     if isinstance(self._stack.data, numpy.ndarray):
                         for r, c in cleanMask:
                             mcaData += self._stack.data[r,:,c]
                     else:
-                        raise IndexError, "Dynamic loading case 4"
+                        raise IndexError("Dynamic loading case 4")
                 elif self.mcaIndex == 2:
                     if isinstance(self._stack.data, numpy.ndarray):
                         for r, c in cleanMask:
                             mcaData += self._stack.data[r,c,:]
                     else:
                         if DEBUG:
-                            print "Dynamic loading case 5"
+                            print("Dynamic loading case 5")
                         #try to minimize access to the file
                         row_dict = {}
                         for r, c in cleanMask:
@@ -482,15 +565,16 @@ class StackBase(object):
                             r = int(key)
                             tmpMcaData = self._stack.data[r:r+1, row_dict[key],:]
                             tmpMcaData.shape = 1, -1
-                            mcaData += numpy.sum(tmpMcaData,0)
+                            mcaData += numpy.sum(tmpMcaData,axis=0,dtype=numpy.float)
                 else:
-                    raise IndexError, "Wrong combination of indices. Case 2"
+                    raise IndexError("Wrong combination of indices. Case 2")
             else:
-                raise IndexError, "File index undefined"
+                raise IndexError("File index undefined")
         if DEBUG:
-            print "Mca sum elapsed = ", time.time() - t0
-        if n_nonselected < npixels:
-            mcaData = self._mcaData0.y[0] - mcaData
+            print("Mca sum elapsed = %f" % (time.time() - t0))
+        if goodData:
+            if n_nonselected < npixels:
+                mcaData = self._mcaData0.y[0] - mcaData
 
         if normalize:
             mcaData = mcaData/npixels
@@ -514,7 +598,7 @@ class StackBase(object):
             imiddle = int(0.5 * (i1 + i2))
 
         if i1 == i2:
-            dummy = self._stackImageData * 0.0
+            dummy = numpy.zeros(self._stackImageData.shape, numpy.float)
             imageDict = {'ROI': dummy,
                       'Maximum': dummy,
                       'Minimum': dummy,
@@ -523,7 +607,7 @@ class StackBase(object):
                       'Right': dummy,
                       'Background':dummy}
             return imageDict
-
+        
         if self.fileIndex == 0:
             if self.mcaIndex == 1:
                 leftImage = self._stack.data[:,i1,:]
@@ -533,7 +617,7 @@ class StackBase(object):
                 maxImage = numpy.max(dataImage, 1)
                 minImage = numpy.min(dataImage, 1)
                 background =  0.5 * (i2-i1) * (leftImage+rightImage)                    
-                roiImage = numpy.sum(dataImage,1)
+                roiImage = numpy.sum(dataImage, axis=1, dtype=numpy.float)
             else:
                 if DEBUG:
                     t0 = time.time()
@@ -545,7 +629,7 @@ class StackBase(object):
                     maxImage = numpy.max(dataImage, 2)
                     minImage = numpy.min(dataImage, 2)
                     background =  0.5 * (i2-i1) * (leftImage+rightImage)
-                    roiImage = numpy.sum(dataImage,2)
+                    roiImage = numpy.sum(dataImage, axis=2, dtype=numpy.float)
                 else:
                     shape = self._stack.data.shape
                     roiImage = self._stackImageData * 0
@@ -559,7 +643,7 @@ class StackBase(object):
                     for i in range(shape[0]):
                         tmpData = self._stack.data[i:i+step,:, i1:i2] * 1
                         numpy.add(roiImage[i:i+step,:],
-                              numpy.sum(tmpData, 2),
+                              numpy.sum(tmpData, axis=2,dtype=numpy.float),
                               roiImage[i:i+step,:])
                         numpy.add(minImage[i:i+step,:],
                                   numpy.min(tmpData, 2),
@@ -572,7 +656,8 @@ class StackBase(object):
                         rightImage[i:i+step, :]  += tmpData[:, :,-1]                                                   
                     background = 0.5*(i2-i1)*(leftImage+rightImage)
                 if DEBUG:
-                    print "ROI image calculation elapsed = ", time.time() - t0
+                    print("ROI image calculation elapsed = %f "%\
+                          (time.time() - t0))
         elif self.fileIndex == 1:
             if self.mcaIndex == 0:
                 if isinstance(self._stack.data, numpy.ndarray):
@@ -583,7 +668,7 @@ class StackBase(object):
                     maxImage = numpy.max(dataImage, 0)
                     minImage = numpy.min(dataImage, 0)
                     background =  0.5 * (i2-i1) * (leftImage+rightImage)
-                    roiImage = numpy.sum(dataImage, 0)
+                    roiImage = numpy.sum(dataImage, axis=0, dtype=numpy.float)
                 else:
                     shape = self._stack.data.shape
                     roiImage = self._stackImageData * 0
@@ -615,7 +700,8 @@ class StackBase(object):
                         elif i == (i2-1):
                             rightImage = tmpData
                     if DEBUG:
-                        print "Dynamic ROI elapsed = ", time.time() - t0
+                        print("Dynamic ROI elapsed = %f" %\
+                              (time.time() - t0))
                     if i2 > i1:
                         background = (leftImage + rightImage) * 0.5 * (i2-i1)
             else:
@@ -629,7 +715,7 @@ class StackBase(object):
                     maxImage = numpy.max(dataImage, 2)
                     minImage = numpy.min(dataImage, 2)
                     background =  0.5 * (i2-i1) * (leftImage+rightImage)
-                    roiImage = numpy.sum(dataImage,2)
+                    roiImage = numpy.sum(dataImage, axis=2,dtype=numpy.float)
                 else:
                     shape = self._stack.data.shape
                     roiImage = self._stackImageData * 0
@@ -643,7 +729,7 @@ class StackBase(object):
                     for i in range(shape[0]):
                         tmpData = self._stack.data[i:i+step,:, i1:i2] * 1
                         numpy.add(roiImage[i:i+step,:],
-                              numpy.sum(tmpData, 2),
+                              numpy.sum(tmpData, axis=2, dtype=numpy.float),
                               roiImage[i:i+step,:])
                         numpy.add(minImage[i:i+step,:],
                                   numpy.min(tmpData, 2),
@@ -656,7 +742,8 @@ class StackBase(object):
                         rightImage[i:i+step, :]  += tmpData[:, :,-1]                                                        
                     background = 0.5*(i2-i1)*(leftImage+rightImage)
                 if DEBUG:
-                    print "ROI image calculation elapsed = ", time.time() - t0
+                    print("ROI image calculation elapsed = %f" %\
+                          (time.time() - t0))
         else:
             #self.fileIndex = 2
             if self.mcaIndex == 0:
@@ -667,7 +754,7 @@ class StackBase(object):
                 dataImage = self._stack.data[i1:i2,:,:]
                 minImage = numpy.min(dataImage, 0)
                 maxImage = numpy.max(dataImage, 0)
-                roiImage = numpy.sum(dataImage,0)
+                roiImage = numpy.sum(dataImage, axis=0, dtype=numpy.float)
             else:
                 leftImage = self._stack.data[:,i1,:]
                 middleImage = self._stack.data[:,imidle,:]
@@ -676,7 +763,7 @@ class StackBase(object):
                 dataImage = self._stack.data[:,i1:i2,:]
                 minImage = numpy.min(dataImage, 1)
                 maxImage = numpy.max(dataImage, 1)
-                roiImage = numpy.sum(dataImage,1)
+                roiImage = numpy.sum(dataImage, axis=1, dtype=numpy.float)
 
         imageDict = {'ROI': roiImage,
                      'Maximum': maxImage,
@@ -690,33 +777,40 @@ class StackBase(object):
 
     def setSelectionMask(self, mask):
         if DEBUG:
-            print "setSelectionMask called"
-        self._selectionMask = mask
+            print("setSelectionMask called")
+        goodData = numpy.isfinite(self._mcaData0.y[0].sum())
+
+        if goodData:
+            self._selectionMask = mask
+        else:
+            self._selectionMask = mask * numpy.isfinite(self._stackImageData)
+            
         for key in self.pluginInstanceDict.keys():
             self.pluginInstanceDict[key].selectionMaskUpdated()
 
     def getSelectionMask(self):
         if DEBUG:
-            print "getSelectionMask called"
+            print("getSelectionMask called")
+        return self._selectionMask
 
     def addImage(self, image, name, info=None, replace=False, replot=True):
         """
         Add image data to the RGB correlator
         """
-        print "Add image data not implemented"
+        print("Add image data not implemented")
 
     def removeImage(self, name, replace=True):
         """
         Remove image data from the RGB correlator
         """
-        print "Remove image data not implemented"
+        print("Remove image data not implemented")
 
 
     def addCurve(self, x, y, legend=None, info=None, replace=False, replot=True):
         """
         Add the 1D curve given by x an y to the graph.
         """
-        print "addCurve not implemented"
+        print("addCurve not implemented")
         return None
 
     def removeCurve(self, legend, replot=True):
@@ -724,7 +818,7 @@ class StackBase(object):
         Remove the curve associated to the supplied legend from the graph.
         The graph will be updated if replot is true.
         """
-        print "removeCurve not implemented"
+        print("removeCurve not implemented")
         return None
     
     def getActiveCurve(self):
@@ -742,7 +836,7 @@ class StackBase(object):
             The legend of the active curve (or None) is returned.
         """
         if DEBUG:
-            print "getActiveCurve default implementation"
+            print("getActiveCurve default implementation")
         info = {}
         info['xlabel'] = 'Channel'
         info['ylabel'] = 'Counts'
@@ -751,12 +845,12 @@ class StackBase(object):
 
     def getGraphXLimits(self):
         if DEBUG:
-            print "getGraphXLimits default implementation"
+            print("getGraphXLimits default implementation")
         return self._mcaData0.x[0].min(), self._mcaData0.x[0].max()
 
     def getGraphYLimits(self):
         if DEBUG:
-            print "getGraphYLimits default implementation"
+            print("getGraphYLimits default implementation")
         return self._mcaData0.y[0].min(), self._mcaData0.y[0].max()
 
     def getStackDataObject(self):
@@ -775,14 +869,16 @@ def test():
     nchannels = 1024
     a = numpy.ones((nrows, ncols), numpy.float)
     stackData = numpy.zeros((nrows, ncols, nchannels), numpy.float)
-    for i in xrange(nchannels):
+    for i in range(nchannels):
         stackData[:, :, i] = a * i
     stack = StackBase()
     
     stack.setStack(stackData, mcaindex=2)
-    print "This should be 0 = ",  stack.calculateROIImages(0, 0)['ROI'].sum()
-    print "This should be 0 = ",  stack.calculateROIImages(0, 1)['ROI'].sum()
-    print stackData[:,:,0:10].sum(), "should be =", stack.calculateROIImages(0, 10)['ROI'].sum()
+    print("This should be 0 = %f" %  stack.calculateROIImages(0, 0)['ROI'].sum())
+    print("This should be 0 = %f" % stack.calculateROIImages(0, 1)['ROI'].sum())
+    print("%f should be = %f" %\
+          (stackData[:,:,0:10].sum(),
+           stack.calculateROIImages(0, 10)['ROI'].sum()))
 
 if __name__ == "__main__":
     test()
