@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 #/*##########################################################################
-# Copyright (C) 2004-2010 European Synchrotron Radiation Facility
+# Copyright (C) 2004-2012 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMCA X-ray Fluorescence Toolkit developed at
 # the ESRF by the Beamline Instrumentation Software Support (BLISS) group.
@@ -36,7 +36,9 @@ from PyMca import OpusDPTMap
 from PyMca import LuciaMap
 from PyMca import SupaVisioMap
 from PyMca import AifiraMap
-from PyMca.QEDFStackWidget import QSpecFileStack, QStack
+from PyMca import TextImageStack
+from PyMca import TiffStack
+from PyMca.QEDFStackWidget import QStack, QSpecFileStack
 try:
     from PyMca import QHDF5Stack1D
     import h5py
@@ -46,6 +48,8 @@ except ImportError:
     pass
 
 QTVERSION = qt.qVersion()
+DEBUG = 0
+
 class StackSelector(object):
     def __init__(self, parent=None):
         self.parent = parent
@@ -70,10 +74,15 @@ class StackSelector(object):
         aifirafile = False
         if len(filelist):
             PyMcaDirs.inputDir = os.path.dirname(filelist[0])
-            f = open(filelist[0], 'rb')
-            #read 10 characters
-            line = f.read(10)
-            f.close()
+            #if we are dealing with HDF5, no more tests needed
+            if not filefilter.upper().startswith('HDF5'):
+                f = open(filelist[0], 'rb')
+                #read 10 characters
+                if sys.version < '3.0':
+                    line = f.read(10)
+                else:
+                    line = str(f.read(10).decode())
+                f.close()
             omnicfile = False
             if filefilter.upper().startswith('HDF5'):
                 stack = QHDF5Stack1D.QHDF5Stack1D(filelist)
@@ -88,12 +97,26 @@ class StackSelector(object):
             elif filefilter.upper().startswith("SUPAVISIO"):
                 stack = SupaVisioMap.SupaVisioMap(filelist[0])
                 omnicfile = True
+            elif filefilter.upper().startswith("TEXTIMAGE"):
+                imagestack = True
+                fileindex  = 0
+                stack = TextImageStack.TextImageStack(imagestack=True)
+            elif filefilter.upper().startswith("IMAGE") and\
+                 (filelist[0].upper().endswith("TIF") or\
+                  filelist[0].upper().endswith("TIFF")):
+                stack = TiffStack.TiffStack(imagestack=True)                
+            elif filefilter == "" and\
+                 (filelist[0].upper().endswith("TIF") or\
+                  filelist[0].upper().endswith("TIFF")):
+                stack = TiffStack.TiffStack(imagestack=True)                
             elif filefilter.upper().startswith("IMAGE"):
                 imagestack = True
                 fileindex  = 0
                 stack = QStack(imagestack=True)
             elif line[0] == "{":
                 stack = QStack(imagestack=imagestack)
+            elif line[0:2] in ["II", "MM"]:
+                stack = QStack(imagestack=True)
             elif line.startswith('Spectral'):
                 stack = OmnicMap.OmnicMap(filelist[0])
                 omnicfile = True
@@ -106,6 +129,11 @@ class StackSelector(object):
             elif filelist[0][-3:].upper() in ["RBS"]:
                 stack = SupaVisioMap.SupaVisioMap(filelist[0])
                 omnicfile = True
+            elif filelist[0][-3:].upper() in ["SPE"] and\
+                 (line[0] not in ['$']):
+                #Roper Scientific format
+                #handle it as MarCCD stack
+                stack = QStack(imagestack=True)
             else:
                 stack = QSpecFileStack()
 
@@ -122,6 +150,8 @@ class StackSelector(object):
                         msg.exec_loop()
                     else:
                         msg.exec_()
+                    if DEBUG:
+                        raise
         elif len(filelist):
             if not omnicfile:
                 try:
@@ -134,6 +164,8 @@ class StackSelector(object):
                         msg.exec_loop()
                     else:
                         msg.exec_()
+                    if DEBUG:
+                        raise
         if aifirafile:
             masterStack = DataObject.DataObject()
             masterStack.info = copy.deepcopy(stack.info)
@@ -149,11 +181,11 @@ class StackSelector(object):
             return stack
     
     def getStackFromPattern(self, filepattern, begin, end, increment=None,
-                            imagestack=False, fileindex=0):
+                            imagestack=None, fileindex=0):
         #get the first filename
         filename =  filepattern % tuple(begin)
         if not os.path.exists(filename):
-            raise IOError, "Filename %s does not exist." % filename
+            raise IOError("Filename %s does not exist." % filename)
         #get the file list
         args = self.getFileListFromPattern(filepattern, begin, end, increment=increment)
 
@@ -165,15 +197,23 @@ class StackSelector(object):
 
         specfile = False
         omnicfile = False
+        marCCD = False
+        if line.startswith("II") or line.startswith("MM"):
+            marCCD= True
         if line[0] == "\n":
             line = line[1:]
-        if line[0] == "{":
+        if (line[0] == "{") or marCCD:           
+            if imagestack is None:
+                if marCCD:
+                    imagestack = True
             if imagestack:
                 #prevent any modification
                 fileindex = 0
             if filepattern is not None:
-                if len(begin) != 1:
-                    raise IOError, "EDF stack redimensioning not supported yet"
+                #this dows not seem to put any trouble
+                #(because of no redimensioning attempt)
+                if False and (len(begin) != 1):
+                    raise IOError("EDF stack redimensioning not supported yet")
             stack = QStack(imagestack=imagestack)
         elif line.startswith('Spectral'):
             stack = OmnicMap.OmnicMap(args[0])
@@ -189,7 +229,8 @@ class StackSelector(object):
             omnicfile = True
         elif args[0][-3:].lower() in [".h5", "nxs", "hdf"]:
             if not HDF5:
-                raise IOError, "No HDF5 support while trying to read an HDF5 file"  
+                raise IOError(\
+                    "No HDF5 support while trying to read an HDF5 file")  
             stack = QHDF5Stack1D.QHDF5Stack1D(args)
             omnicfile = True
         else:
@@ -265,7 +306,10 @@ class StackSelector(object):
                 fdialog = qt.QFileDialog(self.parent)
                 fdialog.setModal(True)
                 fdialog.setWindowTitle(message)
-                strlist = qt.QStringList()
+                if hasattr(qt, "QStringList"):
+                    strlist = qt.QStringList()
+                else:
+                    strlist = []
                 for filetype in fileTypeList:
                     strlist.append(filetype)
                 fdialog.setFilters(strlist)
@@ -289,16 +333,18 @@ class StackSelector(object):
                         return [], filterused
                     else:
                         return []
-        try:
-            filelist = map(str, filelist)
-        except UnicodeEncodeError:
-            filelist = map(unicode, filelist)
+        if sys.version < '3.0':
+            try:
+                filelist = [str(x) for x in filelist]
+            except UnicodeEncodeError:
+                filelist = [unicode(x) for x in filelist]
         if not(len(filelist)): return []
         PyMcaDirs.inputDir = os.path.dirname(filelist[0])
         if PyMcaDirs.outputDir is None:
             PyMcaDirs.outputDir = os.path.dirname(filelist[0])
-            
-        filelist.sort()
+
+        #This should not be there in order to allow the user other choices
+        #filelist.sort()
         if getfilter:
             return filelist, filterused
         else:
@@ -316,7 +362,9 @@ class StackSelector(object):
                         "HDF5 Files (*.nxs *.hdf *.h5)", 
                         "AIFIRA Files (*DAT)",
                         "SupaVisio Files (*pige *pixe *rbs)",
-                        "Image Files (*edf)",
+                        "Image Files (*edf *ccd)",
+                        "Image Files (*tif *tiff *TIF *TIFF)",
+                        "TextImage Files (*txt)",
                         "All Files (*)"]
         if not HDF5:
             idx = fileTypeList.index("HDF5 Files (*.nxs *.hdf *.h5)") 
@@ -330,13 +378,15 @@ class StackSelector(object):
         if type(end) == type(1):
             end = [end]
         if len(begin) != len(end):
-            raise ValueError, "Begin list and end list do not have same length"
+            raise ValueError(\
+                "Begin list and end list do not have same length")
         if increment is None:
             increment = [1] * len(begin)
         elif type(increment) == type(1):
             increment = [increment]
         if len(increment) != len(begin):
-            raise ValueError, "Increment list and begin list do not have same length"
+            raise ValueError(\
+                "Increment list and begin list do not have same length")
         fileList = []
         if len(begin) == 1:
             for j in range(begin[0], end[0]+increment[0], increment[0]):
@@ -346,13 +396,13 @@ class StackSelector(object):
                 for k in range(begin[1], end[1]+increment[1], increment[1]):
                     fileList.append(pattern % (j, k))
         elif len(begin) == 3:
-            raise ValueError, "Cannot handle three indices yet."
+            raise ValueError("Cannot handle three indices yet.")
             for j in range(begin[0], end[0]+increment[0], increment[0]):
                 for k in range(begin[1], end[1]+increment[1], increment[1]):
                     for l in range(begin[2], end[2]+increment[2], increment[2]):
                         fileList.append(pattern % (j, k, l))
         else:
-            raise ValueError, "Cannot handle more than three indices."
+            raise ValueError("Cannot handle more than three indices.")
         return fileList
 
 
@@ -368,8 +418,8 @@ if __name__ == "__main__":
                      sys.argv[1:],
                      options,
                      longoptions)
-    except getopt.error,msg:
-        print msg
+    except:
+        print(sys.exc_info()[1])
         sys.exit(1)
     fileindex = 0
     filepattern=None
@@ -380,17 +430,17 @@ if __name__ == "__main__":
     for opt, arg in opts:
         if opt in '--begin':
             if "," in arg:
-                begin = map(int,arg.split(","))
+                begin = [int (x) for x in arg.split(",")]
             else:
                 begin = [int(arg)]
         elif opt in '--end':
             if "," in arg:
-                end = map(int,arg.split(","))
+                end = [int(x) for x in arg.split(",")]
             else:
                 end = int(arg)
         elif opt in '--increment':
             if "," in arg:
-                increment = map(int,arg.split(","))
+                increment = [int(x) for x in arg.split(",")]
             else:
                 increment = int(arg)
         elif opt in '--filepattern':
@@ -407,7 +457,8 @@ if __name__ == "__main__":
                 PyMcaDirs.nativeFileDialogs=False
     if filepattern is not None:
         if (begin is None) or (end is None):
-            raise ValueError, "A file pattern needs at least a set of begin and end indices"
+            raise ValueError(\
+                "A file pattern needs at least a set of begin and end indices")
     app = qt.QApplication([])
     widget = QStackWidget.QStackWidget()
     w = StackSelector(widget)
