@@ -110,7 +110,7 @@ class XiaEdfCountFile:
                 raise XiaEdfError("Cannot read data in <%s>"%self.filename)
 
     def getDetList(self):
-	return self.detList
+        return self.detList
 
     def getData(self, detector=-1):
         # --- WARNING: first index is channels
@@ -133,8 +133,8 @@ class XiaEdfCountFile:
             return self.statArray[(idx*XiaStatNb):((idx+1)*XiaStatNb)]
 
     def correct(self, deadtime=1, livetime=0):
-	message= []
-	corrflag= int(self.header.get("xcorr", 0))
+        message= []
+        corrflag= int(self.header.get("xcorr", 0))
         if livetime and corrflag&2:
             raise XiaEdfError("<%s> seems already livetime corrected"%self.filename)
 
@@ -146,40 +146,40 @@ class XiaEdfCountFile:
 
         if livetime:
             lvt= Numeric.zeros((self.nbDet,1), Numeric.Float)
-	    derr= []
+            derr= []
             for idx in range(len(self.detList)):
                 lvt[idx]= self.statArray[idx*XiaStatNb + XiaStatIndex["lt"]] / 1000.0
                 if lvt[idx]==0.:
-		    lvt[idx]= 1.
-		    derr.append("#%02d"%self.detList[idx])
-	    if len(derr):
-		message.append("Null livetime on det %s"%string.join(derr))
+                    lvt[idx]= 1.
+                    derr.append("#%02d"%self.detList[idx])
+            if len(derr):
+                message.append("Null livetime on det %s"%string.join(derr))
 
             self.data[1:,:]= self.data[1:,:] / lvt
-	    self.header["xcorr"]= corrflag|2
+            self.header["xcorr"]= corrflag|2
 
         if deadtime:
             rate= Numeric.zeros((self.nbDet,1), Numeric.Float)
             for idx in range(len(self.detList)):
-		derr= []
+                derr= []
                 try:
                     rate[idx]= float(self.statArray[idx*XiaStatNb + XiaStatIndex["icr"]]) / \
                             float(self.statArray[idx*XiaStatNb + XiaStatIndex["ocr"]])
                 except:
-		    rate[idx]= 1.
-		    derr.append("#%02d"%idx)
-	    if len(derr):
-		message.append("Null OCR on det %s"%string.join(derr))
+                    rate[idx]= 1.
+                    derr.append("#%02d"%idx)
+            if len(derr):
+                message.append("Null OCR on det %s"%string.join(derr))
                 
             self.data[1:,:]= self.data[1:,:] * rate
             self.header["xcorr"]= corrflag|1
 
-	return message
+        return message
 
     def sum(self, sums=[], deadtime=0, livetime=0, average=0):
-	message= []
-	if not len(sums):
-	    return message
+        message= []
+        if not len(sums):
+            return message
 
         self.__readData()
 
@@ -188,43 +188,43 @@ class XiaEdfCountFile:
         else:
             self.data= self.data.astype(Numeric.Float)
 
-	sumdata= Numeric.zeros((len(sums), self.data.shape[1]), Numeric.Float)
+        sumdata= Numeric.zeros((len(sums), self.data.shape[1]), Numeric.Float)
 
-	for idx in range(len(sums)):
-	    if not len(sums[idx]):
-		sumdata[idx,:]= Numeric.sum(self.data[1:,], 0)
-		xdet= self.detList
-	    else:
-		mask= Numeric.zeros((self.nbDet+1,1), Numeric.Int)
-		xdet= []
-		for det in sums[idx]:
-		    if det in self.detList:
-			detidx= self.detList.index(det)
-			mask[detidx+1]= 1
-			xdet.append(det)
-		sumdata[idx,:]= Numeric.sum(self.data*mask, 0)
+        for idx in range(len(sums)):
+            if not len(sums[idx]):
+                sumdata[idx,:]= Numeric.sum(self.data[1:,], 0)
+                xdet= self.detList
+            else:
+                mask= Numeric.zeros((self.nbDet+1,1), Numeric.Int)
+                xdet= []
+                for det in sums[idx]:
+                    if det in self.detList:
+                        detidx= self.detList.index(det)
+                        mask[detidx+1]= 1
+                        xdet.append(det)
+                sumdata[idx,:]= Numeric.sum(self.data*mask, 0)
 
-	    self.header["xcorr%d"%idx]= self.header.get("xcorr", 0)
-	    self.header["xdet%d"%idx]= string.join([str(det) for det in xdet], " ")
+            self.header["xcorr%d"%idx]= self.header.get("xcorr", 0)
+            self.header["xdet%d"%idx]= string.join([str(det) for det in xdet], " ")
 
-	if average:
-	    self.data= sumdata / len(xdet)
-	else:
-	    self.data= sumdata
-	
-	for key in self.header.keys():
-	    if key[0]=='x':
-		try:
-		    det= int(key[-2:])
-		    del self.header[key]
-		except:
-		    pass
+        if average:
+            self.data= sumdata / len(xdet)
+        else:
+            self.data= sumdata
 
-	dataflag= int(self.header.get("xdata", 0))
-	self.header["xdata"]= dataflag | (1<<2)
-	self.header["xnb"]= len(sums)
+        for key in self.header.keys():
+            if key[0]=='x':
+                try:
+                    det= int(key[-2:])
+                    del self.header[key]
+                except:
+                    pass
 
-	return message
+        dataflag= int(self.header.get("xdata", 0))
+        self.header["xdata"]= dataflag | (1<<2)
+        self.header["xnb"]= len(sums)
+
+        return message
                 
     def save(self, filename, force=0):
         edf= openEdf(filename, write=1, force=force)
@@ -271,8 +271,6 @@ class XiaEdfScanFile:
         return self.nbDet
 
     def __readData(self, detector):
-        print "detector = ", detector
-        print "self.detector = ", self.detector
         if detector!=self.detector:
             self.detector= None
             self.data= None
@@ -309,7 +307,7 @@ class XiaEdfScanFile:
                 raise XiaEdfError("Cannot read data on det #%02d"%detector)
 
     def getDetList(self):
-	return self.detList
+        return self.detList
 
     def getData(self, detector):
         self.__readData(detector)
@@ -325,11 +323,11 @@ class XiaEdfScanFile:
             return self.statArray[:,(idx*XiaStatNb):((idx+1)*XiaStatNb)]
 
     def correct(self, detector, deadtime=1, livetime=0):
-	message= []
+        message= []
         if detector!=self.detector:
             self.__readData(detector)
 
-	corrflag= int(self.header.get("xcorr", 0))
+        corrflag= int(self.header.get("xcorr", 0))
         if livetime and corrflag&2:
             raise XiaEdfError("det #%02d seems already livetime corrected"%detector)
 
@@ -338,15 +336,15 @@ class XiaEdfScanFile:
         
         self.data= self.data.astype(Numeric.Float)
         idx= self.detList.index(detector)
-	pts= self.statArray.shape[0]
+        pts= self.statArray.shape[0]
 
         if livetime:
             lvt= Numeric.zeros((pts, 1), Numeric.Float)
             lvt[:,0]= self.statArray[:,((XiaStatNb*idx)+XiaStatIndex["lt"])] / 1000.0
 
-	    perr= self.__checkNullLivetime(lvt, pts)
-	    if len(perr):
-		message.append("Null livetime on det #%02d points %s"%(detector, self.__pointRange(perr)))
+            perr= self.__checkNullLivetime(lvt, pts)
+            if len(perr):
+                message.append("Null livetime on det #%02d points %s"%(detector, self.__pointRange(perr)))
 
             self.data= self.data / lvt
             self.header["xcorr"]= corrflag|2
@@ -355,85 +353,85 @@ class XiaEdfScanFile:
             rate= Numeric.zeros((self.statArray.shape[0], 1), Numeric.Float)
             count= Numeric.zeros((self.statArray.shape[0], 2), Numeric.Float)
 
-	    count[:,0]= self.statArray[:, (XiaStatNb*idx)+XiaStatIndex["ocr"]]
-	    count[:,1]= self.statArray[:, (XiaStatNb*idx)+XiaStatIndex["icr"]]
+            count[:,0]= self.statArray[:, (XiaStatNb*idx)+XiaStatIndex["ocr"]]
+            count[:,1]= self.statArray[:, (XiaStatNb*idx)+XiaStatIndex["icr"]]
 
-	    perr= self.__checkNullCount(count, pts)
-	    if len(perr):
-		message.append("Null ICR|OCR on det #%02d points %s"%(detector, self.__pointRange(perr)))
+            perr= self.__checkNullCount(count, pts)
+            if len(perr):
+                message.append("Null ICR|OCR on det #%02d points %s"%(detector, self.__pointRange(perr)))
 
-	    perr= []
-	    for ipt in range(pts):
-		if count[ipt,0]>0 and count[ipt,1]>0:
-		    rate[ipt,0]= count[ipt,1]/count[ipt,0]
-	        else:
-		    rate[ipt,0]= 1.
-		    perr.append(ipt)
+            perr= []
+            for ipt in range(pts):
+                if count[ipt,0]>0 and count[ipt,1]>0:
+                    rate[ipt,0]= count[ipt,1]/count[ipt,0]
+                else:
+                    rate[ipt,0]= 1.
+                    perr.append(ipt)
 
-	    if len(perr):
-		message.append("No DeadTime correction perfomed on det #%02d points %s"%(detector, self.__pointRange(perr)))
+            if len(perr):
+                message.append("No DeadTime correction perfomed on det #%02d points %s"%(detector, self.__pointRange(perr)))
 
             self.data= self.data * rate
             self.header["xcorr"]= corrflag|1
 
-	return message
+        return message
 
     def __checkNullCount(self, count, pts):
-	perr= []
-	check= Numeric.sum(Numeric.greater(count,0.), 1)
-	for ipt in range(pts):
-	    if check[ipt]!=2:
-		perr.append(ipt)
-		if (ipt!=0 and check[ipt-1]==2) and (ipt!=pts-1 and check[ipt+1]==2):
-		    count[ipt,:]= (count[ipt-1,:]+count[ipt+1,:])/2.
-		elif (ipt!=0 and check[ipt-1]==2):
-		    count[ipt,:]= count[ipt-1,:]
+        perr= []
+        check= Numeric.sum(Numeric.greater(count,0.), 1)
+        for ipt in range(pts):
+            if check[ipt]!=2:
+                perr.append(ipt)
+                if (ipt!=0 and check[ipt-1]==2) and (ipt!=pts-1 and check[ipt+1]==2):
+                    count[ipt,:]= (count[ipt-1,:]+count[ipt+1,:])/2.
+                elif (ipt!=0 and check[ipt-1]==2):
+                    count[ipt,:]= count[ipt-1,:]
                 elif (ipt!=pts-1 and check[ipt+1]==2):
                     count[ipt,:]= count[ipt+1,:]
-	        else:
-		    count[ipt,:]= -1
-	return perr
+                else:
+                    count[ipt,:]= -1
+        return perr
 
     def __checkNullLivetime(self, lvt, pts):
-	perr= []
-	check= Numeric.greater(lvt, 0.)
-	for ipt in range(pts):
-	    if check[ipt]==0:
-		perr.append(ipt)
+        perr= []
+        check= Numeric.greater(lvt, 0.)
+        for ipt in range(pts):
+            if check[ipt]==0:
+                perr.append(ipt)
                 if (ipt!=0 and check[ipt-1]==1) and (ipt!=pts-1 and check[ipt+1]==1):
-		     lvt[ipt,0]= (lvt[ipt+1]+lvt[ipt-1])/2.
+                     lvt[ipt,0]= (lvt[ipt+1]+lvt[ipt-1])/2.
                 elif (ipt!=0 and check[ipt-1]==1):
                      lvt[ipt,0]= lvt[ipt-1,0]
                 elif (ipt!=pts-1 and check[ipt+1]==1):
-		     lvt[ipt,0]= lvt[ipt+1,0]
+                     lvt[ipt,0]= lvt[ipt+1,0]
                 else:
-		     lvt[ipt,0]= 1.
-	return perr
+                     lvt[ipt,0]= 1.
+        return perr
 
     def __pointRange(self, ptlist):
-	nb= len(ptlist)
-	ptdiff= []
-	for idx in range(nb-1):
-	    ptdiff.append(((ptlist[idx+1]-ptlist[idx])==1))
-	ptdiff.append(0)
+        nb= len(ptlist)
+        ptdiff= []
+        for idx in range(nb-1):
+            ptdiff.append(((ptlist[idx+1]-ptlist[idx])==1))
+        ptdiff.append(0)
 
-	ptrange= []
-	curr= None
-	for idx in range(nb):
-	    if ptdiff[idx]:
-		if curr is None:
-		    curr= ptlist[idx]
+        ptrange= []
+        curr= None
+        for idx in range(nb):
+            if ptdiff[idx]:
+                if curr is None:
+                    curr= ptlist[idx]
             else:
-		if curr is None:
-		    ptrange.append(str(ptlist[idx]))
+                if curr is None:
+                    ptrange.append(str(ptlist[idx]))
                 else:
-		    ptrange.append("%d-%d"%(curr,ptlist[idx]))
-		curr= None
+                    ptrange.append("%d-%d"%(curr,ptlist[idx]))
+                curr= None
 
-	return "["+string.join(ptrange, ",")+"]"
+        return "["+string.join(ptrange, ",")+"]"
 		
     def sum(self, detectors=[], deadtime=0, livetime=0, average=0):
-	message= []
+        message= []
         if not len(detectors):
             sumdet= self.detList
         else:
@@ -452,17 +450,17 @@ class XiaEdfScanFile:
             else:
                 sumdata= sumdata + self.data
 
-	if average:
-	    self.data= sumdata / len(sumdet)
-	else:
-	    self.data= sumdata
+        if average:
+            self.data= sumdata / len(sumdet)
+        else:
+            self.data= sumdata
 
-	dataflag= int(self.header.get("xdata", 0))
-	self.header["xdata"]= dataflag | (1<<2)
-	self.header["xnb"]= 1
-	self.header["xdet"]= string.join([str(det) for det in sumdet], " ")
+        dataflag= int(self.header.get("xdata", 0))
+        self.header["xdata"]= dataflag | (1<<2)
+        self.header["xnb"]= 1
+        self.header["xdet"]= string.join([str(det) for det in sumdet], " ")
 
-	return message
+        return message
         
     def save(self, filename, force=0):
         if self.data is None:
@@ -478,53 +476,53 @@ class XiaFilename:
             self.__parseFilename(filename)
 
     def setType(self, type, det=None):
-	self.type= type
-	self.det= det
+        self.type= type
+        self.det= det
 	
     def getType(self):
-	return self.type
+        return self.type
 
     def isValid(self):
         return self.type is not None 
 
     def isCount(self):
-	return (self.type=="ct" or (self.type=="sum" and self.det==-1))
+        return (self.type=="ct" or (self.type=="sum" and self.det==-1))
 
     def isScan(self):
         return (self.type=="det" or self.type=="st" or (self.type=="sum" and self.det>0))
 
     def isSum(self):
-	return (self.type=="sum")
+        return (self.type=="sum")
 
     def isStat(self):
         return (self.type=="st")
 
     def findStatFile(self):
-	xf= XiaFilename(self.get())
-	xf.setType("st")
-	if os.path.isfile(xf.get()):
-	    return xf
-	else:
-	    return None
+        xf= XiaFilename(self.get())
+        xf.setType("st")
+        if os.path.isfile(xf.get()):
+            return xf
+        else:
+            return None
 
     def isGroupedWith(self, other):
-	if (self.isScan() and other.isScan()) or (self.isCount() and other.isCount()): 
-	    file1= "%s/%s"%(self.dir is None and "." or self.dir, self.prefix is None and "" or self.prefix)
-	    file2= "%s/%s"%(other.dir is None and "." or other.dir, other.prefix is None and "" or other.prefix)
-	    res= cmp(file1, file2)
-	    if res!=0: return 0
+        if (self.isScan() and other.isScan()) or (self.isCount() and other.isCount()): 
+            file1= "%s/%s"%(self.dir is None and "." or self.dir, self.prefix is None and "" or self.prefix)
+            file2= "%s/%s"%(other.dir is None and "." or other.dir, other.prefix is None and "" or other.prefix)
+            res= cmp(file1, file2)
+            if res!=0: return 0
 
-	    res= cmp(self.index, other.index)
-	    if res!=0: return 0
+            res= cmp(self.index, other.index)
+            if res!=0: return 0
 
-	    file1= "%s.%s"%(self.suffix is None and "" or self.suffix, self.ext is None and "" or self.ext)
-	    file2= "%s.%s"%(other.suffix is None and "" or other.suffix, other.ext is None and "" or other.ext)
-	    res= cmp(file1, file2)
-	    if res!=0: return 0
+            file1= "%s.%s"%(self.suffix is None and "" or self.suffix, self.ext is None and "" or self.ext)
+            file2= "%s.%s"%(other.suffix is None and "" or other.suffix, other.ext is None and "" or other.ext)
+            res= cmp(file1, file2)
+            if res!=0: return 0
 
-	    return 1
-	else:
-	    return 0
+            return 1
+        else:
+            return 0
 
     def setDirectory(self, dirname):
         if dirname is None:
@@ -593,15 +591,15 @@ class XiaFilename:
             if type=="ct" or type=="st":
                 self.type= type
             elif type[0]=='S':
-		self.type= "sum"
-		if type[1]=='N':
-		    self.det= -1
-		else:
-		    try:
-			self.det= int(type[1])
-		    except:
-			self.type= None
-	    else:
+                self.type= "sum"
+                if type[1]=='N':
+                    self.det= -1
+                else:
+                    try:
+                        self.det= int(type[1])
+                    except:
+                        self.type= None
+            else:
                 try:
                     self.type= "det"
                     self.det= int(type)
@@ -618,25 +616,25 @@ class XiaFilename:
                 xia= "xiact"
             elif self.type=="st":
                 xia= "xiast"
-	    elif self.type=="sum":
-		if self.det==-1:
-		    xia= "xiaSN"
-		else:
-		    xia= "xiaS%01d"%self.det
+            elif self.type=="sum":
+                if self.det==-1:
+                    xia= "xiaSN"
+                else:
+                    xia= "xiaS%01d"%self.det
             elif self.type=="det":
                 xia= "xia%02d"%self.det
-	    elif self.type is not None:
-		xia= "xia%s"%self.type
-		
+            elif self.type is not None:
+                xia= "xia%s"%self.type
+                
             if xia is not None:
                 self.file= "%s_%s"%(self.file, xia)
-    
+
             for idx in self.index:
                 self.file= "%s_%04d"%(self.file, idx)
-    
+
             if self.suffix is not None:
                 self.file= "%s_%s"%(self.file, self.suffix)
-    
+
             if self.ext is not None:
                 self.file= "%s.%s"%(self.file, self.ext)
 
@@ -686,21 +684,21 @@ def testScan():
         ])
 
     x.sum([1,10])
-    print x.header
+    print(x.header)
     x.save("test_sum.edf")
     #for det in [1, 2, 3, 4, 5, 6]:
     #    x.correct(det, livetime=1)
     #    x.save(det, "scan_corr_xia%02d.edf"%det)
 
 def testAcq(infile, outfile=None):
-        print "Reading ", infile
+        print("Reading ", infile)
         x= XiaEdfCountFile(infile)
         #print "DeadTime Correction ..."
         #x.correct()
         x.sum([1,10])
         if outfile is not None:
-            print x.header
-            print "Saving ", outfile
+            print(x.header)
+            print("Saving %s" % outfile)
             x.save(outfile)
     
 if __name__=="__main__": 
@@ -710,7 +708,7 @@ if __name__=="__main__":
     sys.exit(0)
 
     if len(sys.argv)<2:
-        print "%s <ct_filename> [<output_filename>]"%sys.argv[0]
+        print("%s <ct_filename> [<output_filename>]" % sys.argv[0])
         sys.exit(0)
     else:
         infile= sys.argv[1]
