@@ -1,6 +1,6 @@
 /****************************************************************************
 *
-*   Copyright (c) 1998-2010 European Synchrotron Radiation Facility (ESRF)
+*   Copyright (c) 1998-2011 European Synchrotron Radiation Facility (ESRF)
 *
 *   The software contained in this file "sps_py.c" is designed to interface
 *   the shared-data structures used and defined by the CSS "spec" package
@@ -235,7 +235,7 @@ static PyObject *sps_attach(PyObject *self, PyObject *args)
 {
   char *spec_version, *array_name;
   int rows, cols, type, flag;
-  int dims[2];
+  npy_intp dims[2];
   int ptype, stype;
   PyArrayObject *arrobj;
   void *data;
@@ -265,7 +265,7 @@ static PyObject *sps_attach(PyObject *self, PyObject *args)
     return NULL;
   }
 
-  if ((arrobj = (PyArrayObject*) PyArray_FromDimsAndData(2, dims, ptype, data))
+  if ((arrobj = (PyArrayObject*) PyArray_SimpleNewFromData(2, dims, ptype, data))
       == NULL) {
     SPS_ReturnDataPointer(data);
     PyErr_SetString(SPSError, "Could not create mathematical array");
@@ -334,7 +334,7 @@ static PyObject *sps_create(PyObject *self, PyObject *args)
     return NULL;
   }
 
-  if ((arrobj = (PyArrayObject*) PyArray_FromDimsAndData(2, dims, ptype, data))
+  if ((arrobj = (PyArrayObject*) PyArray_SimpleNewFromData(2, dims, ptype, data))
       == NULL) {
     /* Should delete the array  - don't have a lib function !!! FIXTHIS */
     PyErr_SetString(SPSError, "Could not create mathematical array");
@@ -344,6 +344,23 @@ static PyObject *sps_create(PyObject *self, PyObject *args)
   return (PyObject*) arrobj;
 }
 
+static PyObject *sps_getshmid(PyObject *self, PyObject *args)
+{
+  char *spec_version, *array_name;
+  int rows, cols, type, flag;
+  int shmid;
+  if (!PyArg_ParseTuple(args, "ss", &spec_version, &array_name)) {
+     return NULL;
+   }
+  if (SPS_GetArrayInfo(spec_version, array_name, &rows, &cols, &type, &flag)) {
+    PyErr_SetString(SPSError, "Error getting array info");
+    return NULL;
+  }
+  shmid = SPS_GetShmId(spec_version, array_name);
+
+  return Py_BuildValue("i", shmid);
+}
+
 static PyObject *sps_getdata(PyObject *self, PyObject *args)
 {
   char *spec_version, *array_name;
@@ -448,7 +465,7 @@ static PyObject *sps_getdatacol(PyObject *self, PyObject *args)
   dims[0] = (in_row == 0) ? rows : in_row;
 
   ptype = sps_type2py(type);
-  if ((arrobj_nc = (PyArrayObject*) PyArray_FromDims(1, dims, ptype))
+  if ((arrobj_nc = (PyArrayObject*) PyArray_SimpleNew(1, dims, ptype))
       == NULL) {
     PyErr_SetString(SPSError, "Could not create mathematical array");
     return NULL;
@@ -603,6 +620,7 @@ static PyMethodDef SPSMethods[] = {
   { "getenv",        sps_getenvstr,  METH_VARARGS},
   { "putenv",        sps_putenvstr,  METH_VARARGS},
   { "getkeylist",    sps_getkeylist, METH_VARARGS},
+  { "getshmid",      sps_getshmid,   METH_VARARGS},
   { "getdata",       sps_getdata,    METH_VARARGS},
   { "getdatarow",    sps_getdatarow, METH_VARARGS},
   { "getdatacol",    sps_getdatacol, METH_VARARGS},
